<?php
//
// Copyright (C) 2001-2002 System Consultants Co.,Ltd. All Rights Reserved.
//
// $Id: importcsvdata_owner.php 1226 2004-09-14 09:16:50Z hideki-h $
//

/**
 * CSVデータを取り仕切るクラス
 *
 * @author hiroki KAWAMURA <hiroki@syscon.co.jp>
 * @author yuji TAKAHASHI <yu-ji@syscon.co.jp>
 */



include_once($_ROOT_DIR_ . "admin/csvimport/class/errorinfoowner.php");
include_once($_ROOT_DIR_ . "admin/csvimport/class/myfile.php");
include_once($_ROOT_DIR_ . "admin/csvimport/class/importcsvdata.php");


class ImportCsvDataOwner
{
	var $importCsvData;				// CSVデータの配列
	var $importCsvFileName;			// インポートするTSVファイルのパス
	var $delimiter;					// デリミタ
	var $csvFileObj;				// TSVファイルのファイルオブジェクト
	var $tableName;					// インポートするテーブル名

	var $errorInfoOwner;			// エラー情報クラス


	// コンストラクタ
	function ImportCsvDataOwner()
	{
		$this->errorInfoOwner = new ErrorInfoOwner();
		$this->csvFileObj = new MyFile();
	}


	// importCsvDataの取得
	function getImportCsvData()
	{
		return $this->importCsvData;
	}

	// importCsvDataの設定
	function setImportCsvData($importCsvData)
	{
		$this->importCsvData = $importCsvData;
	}

	// importCsvFileNameの取得
	function getImportCsvFileName()
	{
		return $this->importCsvFileName;
	}

	// importCsvFileNameの設定
	function setImportCsvFileName($importCsvFileName)
	{
		$this->importCsvFileName = $importCsvFileName;
	}

	// delimiterの取得
	function getDelimiter()
	{
		// タブ区切りをデフォルトにする
		if ($this->delimiter == "")
		{
			$this->delimiter = "\t";
		}

		return $this->delimiter;
	}

	// delimiterの設定
	function setDelimiter($delimiter)
	{
		$this->delimiter = $delimiter;
	}

	// csvFileObjの取得
	function getCsvFileObj()
	{
		return $this->csvFileObj;
	}

	// csvFileObjの設定
	function setCsvFileObj($csvFileObj)
	{
		$this->csvFileObj = $csvFileObj;
	}

	// errorInfoOwnerの取得
	function getErrorInfoOwner()
	{
		return $this->errorInfoOwner;
	}

	// errorInfoOwnerの設定
	function setErrorInfoOwner($errorInfoOwner)
	{
		$this->errorInfoOwner = $errorInfoOwner;
	}


	// インポートするTSVファイルを開く
	function openImportCsvFile()
	{
		if (!$this->csvFileObj->open($this->getImportCsvFileName()))
		{
			echo $this->csvFileObj->errorInfoOwner->outputAllErrorInfo();

			return False;
		}

		return True;
	}


	// インポートするTSVファイルを閉じる
	function closeImportCsvFile()
	{
		if (!$this->csvFileObj->close())
		{
			echo $this->csvFileObj->errorInfoOwner->outputAllErrorInfo();

			return False;
		}

		return True;
	}


	// TSVファイルの解析
	function analyze()
	{
		if (!$this->openImportCsvFile())
		{
			exit;
		}

		$lineCount = 1;
		$isError = False;

		$delimiter = $this->getDelimiter();

		while ($csvArray = fgetcsv($this->csvFileObj->getFilePointer(), 99999, $delimiter))
		{
			// 行頭に // がある行はコメントとして無視する
			// 空行は無視する
			if (!ereg("^\/\/", $csvArray[0]) && !ereg("^$", $csvArray[0]))
			{
				$csvDataTemp = array();
				for ($i = 0; $i < count($csvArray); $i++)
				{
					$this->convert2Eucjp($csvArray[$i]);
					$this->convertKana($csvArray[$i]);
					$this->escapeSql($csvArray[$i]);
					$csvDataTemp[] = $csvArray[$i];
				}

				if (!$isError)
				{
					$this->add($csvDataTemp, $lineCount);
				}
			}

			$lineCount++;
		}

		if (!$this->openImportCsvFile())
		{
			exit;
		}

		if ($isError)
		{
			$this->clear();

			return False;
		}

		return True;
	}


	// 配列に追加
	function add($csvDataArray, $lineNum)
	{
		$importCsvData = new ImportCsvData();

		$countCsvData = count($csvDataArray);
		for ($i = 0; $i < $countCsvData; $i++)
		{
			$importCsvData->add($csvDataArray[$i]);
			$importCsvData->setLineNum($lineNum);
		}

		$importCsvDataTemp = $this->getImportCsvData();
		$importCsvDataTemp[] = $importCsvData;
		$this->setImportCsvData($importCsvDataTemp);
	}


	// 配列のクリア
	function clear()
	{
		$this->setImportCsvData("");
	}


	// EUC-JPにコンバート
	function convert2Eucjp(&$str)
	{
		if (mb_detect_encoding($str, "auto") != "UTF-8")
		{
			$str = mb_convert_encoding($str, "UTF-8", "auto");
		}
	}

	// 半角カナ→全角カナ
	function convertKana(&$str)
	{
		$str = mb_convert_kana($str);
	}

	// SQL用エスケープ
	function escapeSql(&$str)
	{
		$str = addslashes($str);
	}
}
?>