<?php
//
// Copyright (C) 2001-2002 System Consultants Co.,Ltd. All Rights Reserved.
//
// $Id: verification.php 1226 2004-09-14 09:16:50Z hideki-h $
//

/**
 * テーブル定義とインポートCSVデータを比較検証するクラス
 *
 * @author hiroki KAWAMURA <hiroki@syscon.co.jp>
 * @author yuji TAKAHASHI <yu-ji@syscon.co.jp>
 */



include_once($_ROOT_DIR_ . "admin/csvimport/class/errorinfoowner.php");
include_once($_ROOT_DIR_ . "admin/csvimport/class/table_definitionowner.php");
include_once($_ROOT_DIR_ . "admin/csvimport/class/importcsvdata_owner.php");
include_once($_ROOT_DIR_ . "admin/csvimport/class/databasecsv.php");


class Verification
{
	var $tableDefinitionOwner;		// テーブル定義クラス
	var $importCsvDataOwner;		// インポートするCSVデータクラス
	var $databaseCsv;				// データベースクラス

	var $tableDefinitionFileName;	// テーブル定義ファイルパス
	var $importCsvFileName;			// インポートするTSVファイルパス

	var $delimiter;					// デリミタ
	var $tableName;					// テーブル名

	var $conn;						// DBコネクション
	var $dbSqlObj;					// SQLオブジェクト
	var $dbExecObj;					// Execオブジェクト

	var $errorInfoOwner;			// エラー情報クラス


	// コンストラクタ
	function Verification()
	{
		$this->errorInfoOwner = new ErrorInfoOwner();
		$this->tableDefinitionOwner = new TableDefinitionOwner();
		$this->importCsvDataOwner = new ImportCsvDataOwner();

		$this->delimiter = "\t";
	}


	// tableDefinitionOwnerの取得
	function getTableDefinitionOwner()
	{
		return $this->tableDefinitionOwner;
	}

	// tableDefinitionOwnerの設定
	function setTableDefinitionOwner($tableDefinitionOwner)
	{
		$this->tableDefinitionOwner = $tableDefinitionOwner;
	}

	// importCsvDataの取得
	function getImportCsvDataOwner()
	{
		return $this->importCsvDataOwner;
	}

	// importCsvDataOwnerの設定
	function setImportCsvDataOwner($importCsvDataOwner)
	{
		$this->importCsvDataOwner = $importCsvDataOwner;
	}

	// tableDefinitionFileNameの取得
	function getTableDefinitionFileName()
	{
		return $this->tableDefinitionFileName;
	}

	// tableDefinitionFileNameの設定
	function setTableDefinitionFileName($tableDefinitionFileName)
	{
		$this->tableDefinitionFileName = $tableDefinitionFileName;
	}

	// importCsvFileNameの取得
	function getImportCsvFileName()
	{
		return $this->importCsvFileName;
	}

	// importCsvFileNameの設定
	function setImportCsvFileName($importCsvFileName)
	{
		$this->importCsvFileName = $importCsvFileName;
	}

	// delimiterの取得
	function getDelimiter()
	{
		return $this->delimiter;
	}

	// delimiterの設定
	function setDelimiter($delimiter)
	{
		$this->delimiter = $delimiter;
	}

	// tableNameの取得
	function getTableName()
	{
		return $this->tableName;
	}

	// tableNameの設定
	function setTableName($tableName)
	{
		$this->tableName = $tableName;
	}

	// connの取得
	function getConn()
	{
		return $this->conn;
	}

	// connの設定
	function setConn($conn)
	{
		$this->conn = $conn;
	}

	// dbSqlObjの取得
	function getDbSqlObj()
	{
		return $this->dbSqlObj;
	}

	// dbSqlObjの設定
	function setDbSqlObj($dbSqlObj)
	{
		$this->dbSqlObj = $dbSqlObj;
	}

	// dbExecObjの取得
	function getDbExecObj()
	{
		return $this->dbExecObj;
	}

	// dbExecObjの設定
	function setDbExecObj($dbExecObj)
	{
		$this->dbExecObj = $dbExecObj;
	}


	// errorInfoの取得
	function getErrorInfo()
	{
		return $this->errorInfo;
	}

	// errorInfoの設定
	function setErrorInfo($errorInfo)
	{
		$this->errorInfo = $errorInfo;
	}


	// 検証
	function verify()
	{
		// テーブル定義オブジェクトの設定
		$tableDefinitionTemp = $this->getTableDefinitionOwner();
		$tableDefinitionTemp->setTableDefinitionFileName($this->getTableDefinitionFileName());
		$tableDefinitionTemp->setDelimiter($this->getDelimiter());
		$tableDefinitionTemp->setTableName($this->getTableName());
		$tableDefinitionTemp->setConn($this->getConn());
		$tableDefinitionTemp->setDbSqlObj($this->getDbSqlObj());
		$tableDefinitionTemp->setDbExecObj($this->getDbExecObj());

		if (!$tableDefinitionTemp->analyze())
		{
			echo $tableDefinitionTemp->errorInfoOwner->outputAllErrorInfo();
			exit;
		}

		$this->setTableDefinitionOwner($tableDefinitionTemp);

		// インポートCSVオブジェクトの設定
		$importCsvDataTemp = $this->getImportCsvDataOwner();
		$importCsvDataTemp->setImportCsvFileName($this->getImportCsvFileName());
		$importCsvDataTemp->setDelimiter($this->getDelimiter());

		if (!$importCsvDataTemp->analyze())
		{
			echo $importCsvDataTemp->errorInfoOwner->outputAllErrorInfo();
			exit;
		}

		$this->setImportCsvDataOwner($importCsvDataTemp);

		// 比較
		if (!$this->compare())
		{
			echo $this->errorInfoOwner->outputAllErrorInfo();

			return False;
		}

		return True;
	}


	// 比較
	function compare()
	{
		$tableDefinitionTemp = $this->getTableDefinitionOwner();
		$tableDefinition = $tableDefinitionTemp->getTableDefinition();

		$importCsvDataTemp = $this->getImportCsvDataOwner();
		$importCsvData = $importCsvDataTemp->getImportCsvData();

		$isError = False;

		$countImportCsvData = count($importCsvData);

		for ($i = 0; $i < $countImportCsvData; $i++)
		{
			$countTableDefinition = count($tableDefinition);

			for ($k = 0; $k < $countTableDefinition; $k++)
			{
				// 行数, k番目のカラムのデータ, k番目のカラムのテーブル定義
				if (!$this->individualCompare($importCsvData[$i]->getLineNum(), $importCsvData[$i]->arrayValue[$k], $tableDefinition[$k], $i))
				{
					$isError = True;
				}
			}
		}

		if ($isError)
		{
			return False;
		}

		$importCsvDataTemp->setImportCsvData($importCsvData);
		$this->setImportCsvDataOwner($importCsvDataTemp);

		return True;
	}


	// 個々のデータの検証
	// 参照テーブルがあったら、その名前があるかチェックし、あったらそのコードと置き換える。
	// 名前が無かったらエラー。
	function individualCompare($lineNum, &$data, $definition, $dataNum)
	{
		$isError = False;

		$relationTableName = $definition->getRelationTableName();
		$columnName = $definition->getColumnName();

		if ($relationTableName != "")
		{
			if (!$this->isRelationDataExist($lineNum, $data, $definition, $dataNum))
			{
				$isError = True;
			}
		}

		// タイプのチェック(数値のみのタイプ)
		if (eregi("^integer$", $definition->getType()) || eregi("^smallint$", $definition->getType()))
		{
			if (ereg("[^0-9]", $data))
			{
				$this->errorInfoOwner->add("インポートTSVファイルの" . $lineNum . "行目のカラム名" . $columnName . "の値は数値のみです。");
				$isError = True;
			}
		}

		// 長さのチェック
		if ($definition->getLength() != "")
		{
			if ($definition->getLength() < strlen($data))
			{
				$this->errorInfoOwner->add("インポートTSVファイルの" . $lineNum . "行目のカラム名" . $columnName . "の長さが不正です。");
				$isError = True;
			}
		}

		// NotNullのチェック
		if ($definition->isNotNull() == "t" || $definition->isNotNull() == "notnull")
		{
			if (0 == strlen($data))
			{
				$this->errorInfoOwner->add("インポートTSVファイルの" . $lineNum . "行目のカラム名" . $columnName . "が空欄です。");
				$isError = True;
			}
		}

		if ($isError)
		{
			return False;
		}

		return True;
	}


	// 参照先にデータが存在するかチェック
	function isRelationDataExist($lineNum, &$data, $definition, $dataNum)
	{
		if (eregi("^(integer|smallint)$", $definition->getType()))
		{
			$isNumeric = True;
		}
		else
		{
			$isNumeric = False;
		}

		$sql = $this->dbSqlObj->selectFromRelationTable($data, $definition->getRelationTableName(), $definition->getRelationColumnCode(), $definition->getRelationColumnName(), $isNumeric);

		$result = $this->dbExecObj->exeSql($this->conn, $sql);

		if (!$result)
		{
			$this->errorInfoOwner->add("インポートTSVファイルの" . $lineNum . "行目のカラム名" . $definition->getColumnName() . "の参照先のデータ存在チェックの際、データベースエラーが発生しました。実行したSQL:" . $sql);
			$isError = True;
		}

		if ($this->dbExecObj->getNumRows($result) == 0)
		{
			$this->errorInfoOwner->add("インポートTSVファイルの" . $lineNum . "行目のカラム名" . $definition->getColumnName() . "の参照先データが存在しませんでした。");
			$isError = True;
		}
		else
		{
			$data = $this->dbExecObj->getResult($result, 0, $columnName);
		}

		if ($isError)
		{
			return False;
		}

		return True;
	}


	// DBの登録
	function doInsert($A_PHP_AUTH_USER)
	{
//		echo "データベースに登録中・・・<br>\n";

		$this->databaseCsv->setImportCsvDataOwner($this->getImportCsvDataOwner());
		$this->databaseCsv->setConn($this->getConn());
		$this->databaseCsv->setDbSqlObj($this->getDbSqlObj());
		$this->databaseCsv->setDbExecObj($this->getDbExecObj());

		if (!$this->databaseCsv->doInsert($A_PHP_AUTH_USER))
		{
			echo $this->databaseCsv->errorInfoOwner->outputAllErrorInfo();
			return False;
		}

		return True;
	}

}
?>