<?php
/**
 *イベント用日付管理クラス
 *
 * @author hideki HARANAKA <hideki-h@syscon.co.jp>
 */
class ScheduleDateInfo {

  /**
   *クラス名称
   */
  var $classname = "ScheduleDateInfo";

  /**
   *スケジュールコード
   */
  var $schedule_cd;
  
  /**
   * スケジュール日付コード
   */
  var $schedule_date_cd;

  /**
   * 開始日
   * @see dateinfo
   */
  var $startDateInfo;

  /**
   *終了日
   * @see dateinfo
   */
  var $endDateInfo;

  /**
   * 日付処理モード
   * <ul>
   * 	<li>0:日にち指定</li>
   * 	<li>1:曜日指定</li>
   * 	<li>2:週指定</li>
   * 	<li>3:月日指定</li>
   * 	<li>4:期間指定</li>
   * </ul>
   */
  var $date_mode;
  
  /**
   * 日付配列
   * 指定日付モードにより日付配列を作成する
   */
  var $scheduleDateArray = array();
   
  var $scheduleEventInfo;
  
  /**
   * 曜日配列
   */
  var $week_day = array();

  /**
   * 日付指定
   */
  var $month_of_day;
  
  /**
   * 週指定
   */
  var $month_of_week = array();

  /**
   * スケジュール日付コード配列
   */
  var $schedule_date_cd_array = array();

  /**
   * 曜日配列を取得する
   */
  function getWeek_day(){
	return $this->week_day;
  }

  /**
   * 月単位の日付を取得する
   */
  function getMonth_of_day(){
	return $this->month_of_day;
  }

  /**
   * 週指定の配列を取得する
   */
  function getMonth_of_week(){
  	return $this->month_of_week;
  }

  /**
   * 曜日配列を設定する
   */
  function setWeek_day($week_day){
	$this->week_day = $week_day;
  }

  /**
   * 月単位の日付を設定する
   */
  function setMonth_of_day($month_of_day){
	$this->month_of_day = $month_of_day;
  }

  /**
   * 週指定の配列を設定する
   */
  function setMonth_of_week($month_of_week){
  	$this->month_of_week = $month_of_week;
  }

  /**
   * スケジュールコードを設定する
   */
  function setSchedule_cd($schedule_cd){
  	$this->schedule_cd = $schedule_cd;
  }
  
  /**
   *スケジュールコードを取得する
   *
   *@return int スケジュールコード
   */
  function  getSchedule_cd() {
    return $this->schedule_cd;
  }

  /**
   * 日付処理モードを設定する
   * @param date_mode 
   */
  function setDate_mode($date_mode){
	$this->date_mode = $date_mode;
  }
  
  /**
   *開始DateInfoを設定する
   *
   *@param schedule_cd スケジュールコード
   */
  function  setStartDateInfo( $startDateInfo) {
  	$this->startDateInfo = $startDateInfo;
  }

  /**
   *終了DateInfoを設定する
   *
   *@param schedule_cd スケジュールコード
   */
  function  setEndDateInfo( $endDateInfo) {
  	$this->endDateInfo = $endDateInfo;
  }

  /**
   * スケジュール日付配列設定
   */
  function setSchedule_date_cd_array($schedule_date_cd_array){
	$this->schedule_date_cd_array = $schedule_date_cd_array;
  }
  
  /**
   *開始日を取得する
   *
   *@return String 開始日
   */
  function  getStartDateInfo() {
    return $this->startDateInfo;
  }

  /**
   *終了日を取得する
   *
   *@return String 終了日
   */
  function  getEndDateInfo() {
    return $this->endDateInfo;
  }
  
  /**
   * 開始年を取得する
   */
  function getStartYear(){
  	return $this->startDateInfo->getYear();
  }

  /**
   * 終了年を取得する
   */
  function getEndYear(){
  	return $this->endDateInfo->getYear();
  }
  
  /**
   * 開始月を取得する
   */
  function getStartMonth(){
  	return $this->startDateInfo->getMonth();
  }

  /**
   * 終了月を取得する
   */
  function getEndMonth(){
  	return $this->endDateInfo->getMonth();
  }

  /**
   * 開始日を取得する
   */
  function getStartDay(){
  	return $this->startDateInfo->getDay();
  }

  /**
   * 終了日を取得する
   */
  function getEndDay(){
  	return $this->endDateInfo->getDay();
  }

  /**
   * 開始時を取得する
   */
  function getStartHour(){
  	return $this->startDateInfo->getHour();
  }

  /**
   * 終了時を取得する
   */
  function getEndHour(){
  	return $this->endDateInfo->getHour();
  }

  /**
   * 開始分を取得する
   */
  function getStartMinute(){
  	return $this->startDateInfo->getMinute();
  }

  /**
   * 終了分を取得する
   */
  function getEndMinute(){
  	return $this->endDateInfo->getMinute();
  }
  
  /**
   * 指定月の最終日を取得する
   * @param String dayFlg  s:開始月 e:終了月
   * @return String rtnValue
   */
  function getLastMonth($dayFlg){
  	$rtnValue = "";
  	switch($dayFlg){
  		case "s":
  			$rtnValue = $this->startDateInfo->getLastMonth();
  			break;
  		case "e":
  			$rtnValue = $this->endDateInfo->getLastMonth();
  			break;
  		default:
  			$rtnValue = $this->startDateInfo->getLastMonth();
  			break;
  	}
  	return $rtnValue;
  }
  
  /**
   * 開始日を取得する
   * @return String startDate YYYY-MM-DD
   */
  function getStartDate(){
  	if($this->getStartYear() != "" and $this->getStartMonth() != "" and $this->getStartDay() != ""){
	  	$tmpStartDate = $this->getStartYear() . "-" . $this->getStartMonth() . "-" . $this->getStartDay();
  	}
  	else{
  		$tmpStartDate = "";
  	}
  	return $tmpStartDate;
  }

  /**
   * 終了日を取得する
   * @return String endDate YYYY-MM-DD
   */
  function getEndDate(){
  	if($this->getEndYear() != "" and $this->getEndMonth() != "" and $this->getEndDay() != ""){
	  	$tmpEndDate = $this->getEndYear() . "-" . $this->getEndMonth() . "-" . $this->getEndDay();
  	}
  	else{
  		$tmpEndDate = "";
  	}
  	return $tmpEndDate;
  }
  
  /**
   * 開始時間を取得する
   * @return String startTime HH:MI
   */
  function getStartTime(){
  	$tmpTime =  $this->getStartHour() . ":" . $this->getStartMinute();

	if ($tmpTime != "" and $this->getStartHour() != "" and $this->getStartMinute() != "")
	{
		$tmpTime = $tmpTime . ":00";
	}
	elseif ($tmpTime != "" and $this->getStartHour() != "" and $this->getStartMinute() == "")
	{
		$tmpTime = $this->getStartHour() . ":00:00";
	}
	else
	{
		$tmpTime = "";
	}
	
	return $tmpTime;
  }

  /**
   * 終了時間を取得する
   * @return String endTime HH:MI
   */
  function getEndTime(){
  	$tmpTime = $this->getEndHour() . ":" . $this->getEndMinute();

	if ($tmpTime != "" and $this->getEndHour() != "" and $this->getEndMinute() != "")
	{
		$tmpTime = $tmpTime . ":00";
	}
	elseif ($tmpTime != "" and $this->getEndHour() != "" and $this->getEndMinute() == "")
	{
		$tmpTime = $this->getEndHour() . ":00:00";
	}
	else
	{
		$tmpTime = "";
	}
	
	return $tmpTime;
  }
  
  /**
   * 日付配列を取得する
   */
  function getScheduleDateArray(){
  	return $this->scheduleDateArray;
  }
  
  /**
   * 日付コード配列より日付配列を作成する
   */
  function createUpdateScheduleDateArray($conn, $dbSqlObj, $dbExecObj){
    $strSql = $dbSqlObj->selectScheduleDate($this->getSchedule_cd(), $this->schedule_date_cd_array);
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
        $this->errMsg = "日付選択処理中に障害が発生しました。\\n";
	
		return false;
	}
	if($dbExecObj->getNumRows($result) == 0){
		return false;
	}
	
    for ($i = 0; $i < $dbExecObj->getNumRows($result); $i++)
    {
	  	$tmpDateInfo = array();
	  	$tmpDateInfo['year'] = $dbExecObj->getResult($result, $i, "year");
	  	$tmpDateInfo['month'] = $dbExecObj->getResult($result, $i, "month");
	  	$tmpDateInfo['day'] = $dbExecObj->getResult($result, $i, "day");
	  	$tmpDateInfo['hour_s'] = $dbExecObj->getResult($result, $i, "shour");
	  	$tmpDateInfo['minute_s'] = $dbExecObj->getResult($result, $i, "smin");
	  	$tmpDateInfo['hour_e'] =  $dbExecObj->getResult($result, $i, "ehour");
	  	$tmpDateInfo['minute_e'] = $dbExecObj->getResult($result, $i, "emin");
	  	$tmpDateInfo['schedule_date_cd']  = $dbExecObj->getResult($result, $i, "schedule_date_cd");
	  	
	  	array_push($this->scheduleDateArray, $tmpDateInfo);
    }	
    return true;
  }

  /**
   * スケジュールコードより日付配列を作成する
   */
  function createUpdateAllScheduleDateArray($conn, $dbSqlObj, $dbExecObj){
  	unset($this->scheduleDateArray);
  	$this->scheduleDateArray = array();
    $strSql = $dbSqlObj->selectAllScheduleDate($this->getSchedule_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
        $this->errMsg = "日付選択処理中に障害が発生しました。\\n";
	
		return false;
	}
    for ($i = 0; $i < $dbExecObj->getNumRows($result); $i++)
    {
	  	$tmpDateInfo = array();
	  	$tmpDateInfo['year'] = $dbExecObj->getResult($result, $i, "year");
	  	$tmpDateInfo['month'] = $dbExecObj->getResult($result, $i, "month");
	  	$tmpDateInfo['day'] = $dbExecObj->getResult($result, $i, "day");
	  	$tmpDateInfo['hour_s'] = $dbExecObj->getResult($result, $i, "shour");
	  	$tmpDateInfo['minute_s'] = $dbExecObj->getResult($result, $i, "smin");
	  	$tmpDateInfo['hour_e'] =  $dbExecObj->getResult($result, $i, "ehour");
	  	$tmpDateInfo['minute_e'] = $dbExecObj->getResult($result, $i, "emin");
	  	$tmpDateInfo['schedule_date_cd']  = $dbExecObj->getResult($result, $i, "schedule_date_cd");
	  	
	  	array_push($this->scheduleDateArray, $tmpDateInfo);
    }	
  }

  /**
   * 日付配列を作成する
   */
  function createScheduleDateArray(){
  	switch($this->date_mode){
  		case 0:
  			$this->createScheduleDateArray0();
  			break;
  		case 1:
  			$this->createScheduleDateArray1();
  			break;
  		case 2:
  			$this->createScheduleDateArray2();
  			break;
  		case 3:
  			$this->createScheduleDateArray3();
  			break;
  		case 4:
  			$this->createScheduleDateArray4();
  			break;
  		case 5:
  			$this->createScheduleDateArray5();
  			break;
  	}
  }
  
  /**
   * 日にち指定時の配列を作成する
   */
  function createScheduleDateArray0(){
  	$tmpDateInfo = array();
  	$tmpDateInfo['date'] = $this->getStartDate();
  	$tmpDateInfo['time_s'] = $this->getStartTime();
  	$tmpDateInfo['time_e'] = $this->getEndTime();
  	
  	array_push($this->scheduleDateArray, $tmpDateInfo);
  }
  
  /**
   * 曜日指定の配列を作成する
   */
  function createScheduleDateArray1()
  {
    $secs = 60 * 60 * 24;
    
    foreach($this->week_day as $key => $value){
		$time = 0;	
	    $stime = mktime(0,0,0,$this->getStartMonth(),$this->getStartDay(),$this->getStartYear());
	    $etime = mktime(0,0,0,$this->getEndMonth(),$this->getEndDay(),$this->getEndYear());
	    $info = getdate($stime);
	    $time = (($value - $info["wday"] + 7) % 7) * $secs + $stime;
	
	    $diff = 7 * $secs;

		while($time <= $etime){
		    $tmpDateInfo = array();
			$tmpDateInfo['date'] = date("Y-m-d",$time);
			$tmpDateInfo['time_s'] = $this->getStartTime();
			$tmpDateInfo['time_e'] = $this->getEndTime();
	        array_push($this->scheduleDateArray, $tmpDateInfo);
	        $time += $diff;
		}
    }
  }

  /**
   * 週指定の配列を作成する
   */
  function createScheduleDateArray2()
  {
    $secs = 60 * 60 * 24;
    
    foreach($this->week_day as $key => $value){
		$time = 0;	
	    $stime = mktime(0,0,0,$this->getStartMonth(),$this->getStartDay(),$this->getStartYear());
	    $etime = mktime(0,0,0,$this->getEndMonth(),$this->getEndDay(),$this->getEndYear());
	    $info = getdate($stime);
	    $time = (($value - $info["wday"] + 7) % 7) * $secs + $stime;
	
	    $diff = 7 * $secs;

		while($time <= $etime){
			if($this->ceckWeekOfMonth($time)){
			    $tmpDateInfo = array();
				$tmpDateInfo['date'] = date("Y-m-d",$time);
				$tmpDateInfo['time_s'] = $this->getStartTime();
				$tmpDateInfo['time_e'] = $this->getEndTime();
		        array_push($this->scheduleDateArray, $tmpDateInfo);
			}
	        $time += $diff;
		}
    }
  }

  /**
   * 月単位での日付指定の配列を作成する
   */
  function createScheduleDateArray3()
  {
    $stime = mktime(0,0,0,$this->getStartMonth(),$this->getStartDay(),$this->getStartYear());
    $etime = mktime(0,0,0,$this->getEndMonth(),$this->getEndDay(),$this->getEndYear());
    
    $time = $stime;
    
    $curMonth = $this->getStartDay();
    $curYear = $this->getStartYear();
    
    
	while($time <= $etime){
		$curMonth = date("m", $time);
		$curYear = date("Y", $time);
		if($stime <= mktime(0,0,0,$curMonth,$this->month_of_day,$curYear) &&
			mktime(0,0,0,$curMonth,$this->month_of_day,$curYear) <= $etime &&
			checkdate($curMonth, $this->month_of_day, $curYear)){
			
		    $tmpDateInfo = array();
			$tmpDateInfo['date'] = $curYear . "-" . $curMonth . "-" . $this->month_of_day;
			$tmpDateInfo['time_s'] = $this->getStartTime();
			$tmpDateInfo['time_e'] = $this->getEndTime();
	        array_push($this->scheduleDateArray, $tmpDateInfo);
	    }
	    
        $time = mktime(0,0,0,$curMonth + 1,$this->month_of_day,$curYear);
	}
  }
  
  /**
   * 期間指定時の配列を作成する
   */
  function createScheduleDateArray4(){	
	//開始日のUNIXタイムスタンプ取得
	$startTimeStamp = mktime(0,0,0, $this->getStartMonth(), $this->getStartDay(), $this->getStartYear());
	//秒を日数に変換する
	$startDate = $startTimeStamp / 60 / 60 / 24;
	$startDate = (int)$startDate;
	//終了日のUNIXタイムスタンプ取得
	$endTimeStamp = mktime(0,0,0, $this->getEndMonth(), $this->getEndDay(), $this->getEndYear());
	$endDate = $endTimeStamp / 60 / 60 / 24;
	$endDate = (int)$endDate;
	
	$diffDate = $endDate - $startDate;
	
  	$tmpDateInfo = array();
  	$tmpDateInfo['date'] = $this->getStartDate();
  	$tmpDateInfo['time_s'] = "";
  	$tmpDateInfo['time_e'] = "";

  	//$tmpDateInfo['time_s'] = $this->getStartTime();
  	//$tmpDateInfo['time_e'] = "23:50:00";
  	
  	array_push($this->scheduleDateArray, $tmpDateInfo);	
	
	for($i = 1; $i < $diffDate; $i++){
	  	$tmpDateInfo = array();
		$tmpTimeStamp = $startTimeStamp + ($i * 60 * 60 * 24);
		$tmpDateInfo['date'] = date("Y-m-d",$tmpTimeStamp);
	  	$tmpDateInfo['time_s'] = "";
	  	$tmpDateInfo['time_e'] = "";
	  	//$tmpDateInfo['time_s'] = "00:00:00";
	  	//$tmpDateInfo['time_e'] = "23:50:00";
	  	array_push($this->scheduleDateArray, $tmpDateInfo);	
	}
  	
  	if($diffDate > 0){
	  	$tmpDateInfo = array();
	  	$tmpDateInfo['date'] = $this->getEndDate();
	  	$tmpDateInfo['time_s'] = "";
	  	$tmpDateInfo['time_e'] = "";
	  	//$tmpDateInfo['time_s'] = "00:00:00";
	  	//$tmpDateInfo['time_e'] = $this->getEndTime();
	  	array_push($this->scheduleDateArray, $tmpDateInfo);
  	}
  }
  
  /**
   * 期間・時間指定時の配列を作成する
   */
  function createScheduleDateArray5(){	
	//開始日のUNIXタイムスタンプ取得
	$startTimeStamp = mktime(0,0,0, $this->getStartMonth(), $this->getStartDay(), $this->getStartYear());
	//秒を日数に変換する
	$startDate = $startTimeStamp / 60 / 60 / 24;
	$startDate = (int)$startDate;
	//終了日のUNIXタイムスタンプ取得
	$endTimeStamp = mktime(0,0,0, $this->getEndMonth(), $this->getEndDay(), $this->getEndYear());
	$endDate = $endTimeStamp / 60 / 60 / 24;
	$endDate = (int)$endDate;
	
	$diffDate = $endDate - $startDate;
	
  	$tmpDateInfo = array();
  	$tmpDateInfo['date'] = $this->getStartDate();
  	$tmpDateInfo['time_s'] = $this->getStartTime();
  	$tmpDateInfo['time_e'] = $this->getEndTime();

  	//$tmpDateInfo['time_s'] = $this->getStartTime();
  	//$tmpDateInfo['time_e'] = "23:50:00";
  	
  	array_push($this->scheduleDateArray, $tmpDateInfo);	
	
	for($i = 1; $i < $diffDate; $i++){
	  	$tmpDateInfo = array();
		$tmpTimeStamp = $startTimeStamp + ($i * 60 * 60 * 24);
		$tmpDateInfo['date'] = date("Y-m-d",$tmpTimeStamp);
	  	$tmpDateInfo['time_s'] = $this->getStartTime();
	  	$tmpDateInfo['time_e'] = $this->getEndTime();
	  	//$tmpDateInfo['time_s'] = "00:00:00";
	  	//$tmpDateInfo['time_e'] = "23:50:00";
	  	array_push($this->scheduleDateArray, $tmpDateInfo);	
	}
  	
  	if($diffDate > 0){
	  	$tmpDateInfo = array();
	  	$tmpDateInfo['date'] = $this->getEndDate();
	  	$tmpDateInfo['time_s'] = $this->getStartTime();
	  	$tmpDateInfo['time_e'] = $this->getEndTime();
	  	//$tmpDateInfo['time_s'] = "00:00:00";
	  	//$tmpDateInfo['time_e'] = $this->getEndTime();
	  	array_push($this->scheduleDateArray, $tmpDateInfo);
  	}
  }
  
  /**
   * 指定週目であるかどうかをチェックする
   */
  function ceckWeekOfMonth($time){
    $secs = 60 * 60 * 24;
    $diff = 7 * $secs;
  	foreach($this->month_of_week as $key => $value){
  		$tmpTime = $time;
  		$tmpETime = mktime(0,0,0,date("m", $time), 1, date("Y",$time));
  		$i = 0;
  		if($value == 6){ //最終週
			$tmpTime = mktime(0,0,0,date("m", $tmpTime), date("j",$tmpTime) + 7, date("Y",$tmpTime));
			if(date("d",$time) >= date("d", $tmpTime)){
				return true;
			}  			
  		}
  		else{
	  		while($tmpTime >= $tmpETime){
				$tmpTime -= $diff;	
				$i += 1;
	  		}
	  		if($i == $value){
				return true;
	  		}  			
  		}
  	}
  	return false;
  }
}

?>
