<?php
/**
 *イベント管理クラス
 *
 * @author hideki HARANAKA <hideki-h@syscon.co.jp>
 * @since 1.4 - 2005/05/17
 */
class ScheduleEventInfo {

  /**
   *クラス名称
   */
  var $classname = "ScheduleEventInfo";

  /**
   *スケジュールコード
   */
  var $schedule_cd;
  
  /**
   * 日付コード
   */
  var $schedule_date_cd;

  /**
   *予定
   */
  var $plan;

  /**
   *場所
   */
  var $place;

  /**
   * 参加通知フラグ
   */
  var $compulsion;
  /**
   *備考
   */
  var $remark;

  /**
   *公開／非公開<br>
   *<br>
   *イベントのメンバーに自分以外の人が<br>
   *登録されている場合は、常に公開となる<br>
   *<ul>
   *<li>true 公開</li>
   *<li>false 非公開</li>
   *</ul>
   */
  var $public;

  /**
   *社外／社内<br>
   *<br>
   *<ul>
   *<li>true 社外</li>
   *<li>false 社内</li>
   *</ul>
   */
  var $outdoor;

  /**
   *イベントの状態を表すフラグ<br>
   *
   *<ol>
   *<li>自分のスケジュールのみ登録</li>
   *<li>自分のスケジュールと施設予約</li>
   *<li>自分のスケジュールとメンバーのスケジュール</li>
   *<li>自分のスケジュールと施設予約・メンバーのスケジュール</li>
   *</ol>
   */
  var $event_mode;

  /**
   *イベント登録者
   */
  var $owner_emp_cd;
  
  /**
   * イベント登録者氏名
   */
  var $owner_emp_name;

  /**
   *イベント日付管理配列
   *
   *@see ScheduleDateInfo
   */
  var $scheduleDateInfoArray = array();

  /**
   *イベントメンバー管理配列
   *
   *@see ScheduleMemberInfo
   */
  var $scheduleMemberInfoArray = array();

  /**
   *イベント施設管理配列
   *
   *@see ScheduleFacilityInfo
   */
  var $scheduleFacilityInfoArray = array();

  /**
   * 予約時にエラーのあった施設情報
   * String
   */
  var $errMsg = "";
  /**
   * 予約時にエラーのあった施設情報
   */
  var $errFacilityInfoArray = array();

  var $scheduleMemberInfo;

  var $scheduleInfoOwner;

  var $scheduleFacilityInfo;
  
  /**
   * 不参加メンバー表示用JavaScriptオブジェクト
   */
  var $objJavaScriptSelect_DivEmpScheduleMember;

  /**
   * 未使用施設表示用JavaScriptオブジェクト
   */
  var $objJavaScriptSelect_CatFacScheduleFacility;

  function ScheduleEventInfo() {
  }

  /** 
   * 不参加メンバー表示用JavaScriptオブジェクト設定
   * @param String division 部門情報
   */
  function setJavaScriptSelect_DivEmpScheduleMember($division,$conn,$dbSqlObj,$dbExecObj) {
	require_once($_ROOT_URL_ . "class/javascriptselect_div_emp_schedule_member.php");
	$this->objJavaScriptSelect_DivEmpScheduleMember = new JavaScriptSelect_DivEmpScheduleMember($division,$this->getOwner_emp_cd(),$conn,$dbSqlObj,$dbExecObj,$this->getOwner_emp_cd());
  }

  /** 
   * 不参加メンバー表示用JavaScriptオブジェクト取得
   * @param String division 部門情報
   */
  function getJavaScriptSelect_DivEmpScheduleMember() {
	return $this->objJavaScriptSelect_DivEmpScheduleMember;
  }

  /** 
   * 未使用施設表示用JavaScriptオブジェクト設定
   * @param String fac_cat_cd 施設カテゴリ情報
   */
  function setJavaScriptSelect_CatFacScheduleFacility($fac_cat_cd,$conn,$dbSqlObj,$dbExecObj) {
	require_once($_ROOT_URL_ . "class/javascriptselect_cat_fac_schedule_facility.php");
	$this->objJavaScriptSelect_CatFacScheduleFacility = new JavaScriptSelect_CatFacScheduleFacility($fac_cat_cd,"",$this->getOwner_emp_cd(), $this->getScheduleFacilityInfoArray(), $conn,$dbSqlObj,$dbExecObj);
  }

  /** 
   * 未使用施設表示用JavaScriptオブジェクト取得
   * @param String division 部門情報
   */
  function getJavaScriptSelect_CatFacScheduleFacility() {
	return $this->objJavaScriptSelect_CatFacScheduleFacility;
  }
  
  /**
   *スケジュールコードを取得する
   *
   *@return int スケジュールコード
   */
  function  getSchedule_cd() {
    return $this->schedule_cd;
  }

  /**
   *スケジュールコードを設定する
   *
   *@param schedule_cd スケジュールコード
   */
  function  setSchedule_cd( $schedule_cd) {
  	$this->schedule_cd = $schedule_cd;
  }
  
  /**
   * スケジュール日付コードを設定する
   */
  function setScheduleDate_cd($schedule_date_cd){
  	$this->schedule_date_cd = $schedule_date_cd;
  }
  
  /**
   * スケジュール日付コードを取得する
   */
  function getScheduleDate_cd(){
  	return $this->schedule_date_cd;
  }

  /**
   *予定を取得する
   *
   *@return String 予定
   */
  function  getPlan() {
    return $this->plan;
  }

  /**
   *計画を設定する
   *
   *@param plan 計画
   */
  function  setPlan($plan) {
  	$this->plan = $plan;
  }

  /**
   *場所を取得する
   *
   *@return String 場所
   */
  function  getPlace() {
    return $this->place;
  }

  /**
   *場所を設定する
   *
   *@param place 場所
   */
  function  setPlace( $place) {
  	$this->place = $place;
  }

  /**
   *備考を取得する
   *
   *@return String 備考
   */
  function  getRemark() {
    return $this->remark;
  }

  /**
   *備考を設定する
   *
   *@param remark 備考
   */
  function  setRemark( $remark) {
  	$this->remark = $remark;
  }

  /**
   *公開/非公開を取得する
   *
   *@return boolean true:公開 false:非公開
   */
  function isPublic() {
    return $this->public;
  }

  /**
   *公開/非公開を設定する
   *
   *@param public true:公開 false:非公開
   */
  function  setPublic( $public ) {
  	$this->public = $public;
  }

  /**
   *社外/社内を取得する
   *
   *@return boolean true:社外 false:社内
   */
  function isOutdoor() {
    return $this->outdoor;
  }

  /**
   *社外/社内を設定する
   *
   *@param public true:社外 false:社内
   */
  function  setOutdoor( $outdoor ) {
  	$this->outdoor = $outdoor;
  }

  /**
   * 参加通知フラグを設定する
   * @param int compulsion 参加通知フラグ
   */
  function setCompulsion($compulsion){
	$this->compulsion = $compulsion;
  }

  /**
   * 参加フラグを取得する
   * @return int compulsion 参加通知フラグ
   */
  function getMemberEnabled(){
  	$rtnValue = 0;
	switch($this->compulsion){
		case 1:
			$rtnValue = 2;
			break;
		case 2:
		case 3:
		default:
			$rtnValue = 1;
	}
	return $rtnValue;
  }

  /**
   * 参加通知フラグを取得する
   * @return int compulsion 参加通知フラグ
   */
  function getCompulsion(){
	return $this->compulsion;
  }
  
  /**
   *イベントモードを取得する
   *
   *@return int <ol>
   *<li>自分のスケジュールのみ登録</li>
   *<li>自分のスケジュールと施設予約</li>
   *<li>自分のスケジュールとメンバーのスケジュール</li>
   *<li>自分のスケジュールと施設予約・メンバーのスケジュール</li>
   *</ol>
   */
  function  getEvent_mode() {
    return $this->event_mode;
  }

  /**
   *イベントモードを設定する
   *
   *@param event_mode <ol>
   *<li>自分のスケジュールのみ登録</li>
   *<li>自分のスケジュールと施設予約</li>
   *<li>自分のスケジュールとメンバーのスケジュール</li>
   *<li>自分のスケジュールと施設予約・メンバーのスケジュール</li>
   *</ol>
   */
  function  setEvent_mode($event_mode) {
  	$this->event_mode = $event_mode;
  }

  /**
   *イベント登録者を取得する
   *
   *@return String イベント登録者
   */
  function  getOwner_emp_cd() {
    return $this->owner_emp_cd;
  }

  /**
   *イベント登録者を設定する
   *
   *@param emp_cd イベント登録者
   */
  function  setOwner_emp_cd( $emp_cd) {
  	$this->owner_emp_cd = $emp_cd;
  }

  /**
   *イベント登録者を取得する
   *
   *@return String イベント登録者
   */
  function  getOwner_emp_name() {
    return $this->owner_emp_name;
  }

  /**
   *イベント登録者を設定する
   *
   *@param emp_name イベント登録者
   */
  function  setOwner_emp_name( $emp_name) {
  	$this->owner_emp_name = $emp_name;
  }

  /**
   *イベント日付管理配列を取得する
   */
  function  getScheduleDateInfoArray() {
    return $this->scheduleDateInfoArray;
  }

  /**
   *イベントメンバー管理配列を取得する
   */
  function   getScheduleMemberInfoArray() {
    return $this->scheduleMemberInfoArray;
  }

  /**
   *イベント施設管理配列を取得する
   */
  function  getScheduleFacilityInfoArray() {
    return $this->scheduleFacilityInfoArray;
  }

  /**
   * 
   */
   function getErrFacilityInfoArray(){
   	return $this->errFacilityInfoArray;
   }
  /**
   *イベント日付をテーブル(event_date)に保存する
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleDateInfo
   *@see event_date(table)
   */
  function  doInsertDateQuery($InitialDate_cd,  $conn,  $dbSqlObj,  $dbExecObj) {
	$i = $InitialDate_cd;
	$this->setScheduleDate_cd($i);
	foreach($this->scheduleDateInfoArray as $key => $tmpDateInfo){
        $strSql = $dbSqlObj->insertScheduleDate($this->getSchedule_cd(), $i,$tmpDateInfo["date"],$tmpDateInfo["time_s"],$tmpDateInfo["time_e"],$this->getRemark());
		$result = $dbExecObj->exeSql($conn, $strSql);
		if (!$result) {
			//echo "<FONT COLOR=\"red\">メンバー登録処理中に障害が発生しました。</FONT><br>\n";
			//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
			//exit;
	        $this->errMsg = "日付登録処理中に障害が発生しました。\\n";
		
			return false;
		}
		$i = $i + 1;
  	}

  	return true;
  }

  /**
   *指定したイベント日付をテーブル(event_date)に保存する
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleDateInfo
   *@see event_date(table)
   */
  function  doUpdateDateQuery($schedule_date_cd_array, $conn,  $dbSqlObj,  $dbExecObj) {
    $strSql = $dbSqlObj->updateScheduleDate($this->getSchedule_cd(), $schedule_date_cd_array, $this->getRemark());
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
		//echo "<FONT COLOR=\"red\">メンバー登録処理中に障害が発生しました。</FONT><br>\n";
		//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
		//exit;
        $this->errMsg = "日付更新処理中に障害が発生しました。\\n";
	
		return false;
	}
  	
  	return true;
  }

  /**
   *指定したイベント日付をテーブル(event_date)に保存する
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   */
  function  doUpdateDateDateQuery($schedule_date_cd_array, $conn,  $dbSqlObj,  $dbExecObj, $year, $month, $day, $shour, $sminute, $ehour, $eminute) {
  	if($year != "" or $month != "" or $day != ""){
		$date = $year . "-" . $month . "-" . $day;
  	}
	else{
        $this->errMsg = "日付更新処理中に障害が発生しました。\\n";
	
		return false;
	}
  	if($shour != "" and $sminute != ""){
		$stime = $shour . ":" . $sminute . ":" . "00";
  	}
	else{
		$stime = "";
	}
  	if($ehour != "" and $eminute != ""){
		$etime = $ehour . ":" . $eminute . ":" . "00";
  	}
	else{
		$etime = "";
	}
    $strSql = $dbSqlObj->updateScheduleDateDate($this->getSchedule_cd(), $schedule_date_cd_array, $this->getRemark(), $date, $stime, $etime);
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
		//echo "<FONT COLOR=\"red\">メンバー登録処理中に障害が発生しました。</FONT><br>\n";
		//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
		//exit;
        $this->errMsg = "日付更新処理中に障害が発生しました。\\n";
	
		return false;
	}
	
	$this->scheduleDateInfoArray[0]['year'] = $year;
	$this->scheduleDateInfoArray[0]['month'] = $month;
	$this->scheduleDateInfoArray[0]['day'] = $day;
	$this->scheduleDateInfoArray[0]['hour_s'] = $shour;
	$this->scheduleDateInfoArray[0]['minute_s'] = $sminute;
	$this->scheduleDateInfoArray[0]['hour_e'] = $ehour;
	$this->scheduleDateInfoArray[0]['minute_e'] = $eminute;
	
  	return true;
  }

  /**
   *イベント日付をscheduleDateInfoArrayに読み込む
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleDateInfo
   *@see event_date(table)
   */
  function  doSelectDateQuery( $conn,  $dbSqlObj,  $dbExecObj) {
  }
  
  /**
   *イベント日付件数を調べる
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleDateInfo
   *@see event_date(table)
   */
  function  doCheckDateQuery( $conn,  $dbSqlObj,  $dbExecObj) {
 	$strsql = $dbSqlObj->countScheduleDate($this->getSchedule_cd());
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール日付テーブルの件数取得に失敗しました";
      return false;
    }
    return $dbExecObj->getResult($result, 0, "count_date");
  }

  /**
   *イベントメンバー件数を調べる
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleDateInfo
   *@see event_date(table)
   */
  function  doCheckMemberQuery($schedule_date_cd_array, $conn,  $dbSqlObj,  $dbExecObj) {
 	$strsql = $dbSqlObj->countScheduleMember($this->getSchedule_cd(),$schedule_date_cd_array);
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール日付テーブルの件数取得に失敗しました";
      return false;
    }
    return $dbExecObj->getResult($result, 0, "count_member");
  }

  /**
   *イベント施設件数を調べる
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleDateInfo
   *@see event_date(table)
   */
  function  doCheckFacilityQuery($schedule_date_cd_array, $conn,  $dbSqlObj,  $dbExecObj) {
 	$strsql = $dbSqlObj->countScheduleFacility($this->getSchedule_cd(),$schedule_date_cd_array);
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール日付テーブルの件数取得に失敗しました";
      return false;
    }
    return $dbExecObj->getResult($result, 0, "count_facility");
  }

  /**
   *イベントメンバー件数を調べる
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleDateInfo
   *@see event_date(table)
   */
  function  doCheckAllMemberQuery( $conn,  $dbSqlObj,  $dbExecObj) {
 	$strsql = $dbSqlObj->countScheduleAllMember($this->getSchedule_cd());
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール日付テーブルの件数取得に失敗しました";
      return false;
    }
    return $dbExecObj->getResult($result, 0, "count_member");
  }

  /**
   *イベント施設件数を調べる
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleDateInfo
   *@see event_date(table)
   */
  function  doCheckAllFacilityQuery( $conn,  $dbSqlObj,  $dbExecObj) {
 	$strsql = $dbSqlObj->countScheduleAllFacility($this->getSchedule_cd());
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール日付テーブルの件数取得に失敗しました";
      return false;
    }
    return $dbExecObj->getResult($result, 0, "count_facility");
  }

  /**
   *イベント日付を削除する
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleDateInfo
   *@see event_date(table)
   */
  function  doDeleteDateQuery($conn, $dbSqlObj, $dbExecObj) {
  }

  /**
   *一時メンバーテーブル初期化削除
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleMemberInfo
   *@see tmp_event_member(table)
   */
  function  doDeleteTmpAllMemberQuery($conn, $dbSqlObj, $dbExecObj) {
 	$strsql = $dbSqlObj->deleteTmpEventMember($this->getOwner_emp_cd());
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュールユーザ一時テーブルの初期化に失敗しました";
      return false;
    }
    return true;
  }

  /**
   *一時メンバーテーブル初期化削除
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleMemberInfo
   *@see tmp_event_member(table)
   */
  function  doInitialTmpAllMemberQuery($conn, $dbSqlObj, $dbExecObj) {
	$strSql = $dbSqlObj->insertTmpInitialEventMember($this->getOwner_emp_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュールユーザ一時テーブルの初期化に失敗しました";
      return false;
    }
    return true;
  }

  /**
   *一時メンバーテーブル初期化削除
   *指定スケジュールの指定日に関するメンバーを一時テーブルに読み込む
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleMemberInfo
   *@see tmp_event_member(table)
   */
  function  doUpdateInitialTmpAllMemberQuery($conn, $dbSqlObj, $dbExecObj) {
	$strSql = $dbSqlObj->insertTmpEventMember($this->getOwner_emp_cd(), $this->getSchedule_cd(), $this->getScheduleDate_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュールユーザ一時テーブルの初期化に失敗しました";
      return false;
    }
    $tmpMember = array();

 	$strsql = $dbSqlObj->selectTmpEventMember_ListData($this->getOwner_emp_cd(), "1");
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュールメンバー一時テーブルの取得<br>\n";
      //exit;
      $this->errMsg = "スケジュールメンバー一時テーブルの取得失敗";
      return false;
    }

    for ($i = 0; $i < $dbExecObj->getNumRows($result); $i++)
    {
		array_push($tmpMember, $dbExecObj->getResult($result, $i, "emp_cd"));
    }

 	$strsql = $dbSqlObj->selectTmpEventMember_ListData($this->getOwner_emp_cd(), "2");
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュールメンバー一時テーブルの取得<br>\n";
      //exit;
      $this->errMsg = "スケジュールメンバー一時テーブルの取得失敗";
      return false;
    }

    for ($i = 0; $i < $dbExecObj->getNumRows($result); $i++)
    {
		array_push($tmpMember, $dbExecObj->getResult($result, $i, "emp_cd"));
    }
    
	$strSql = $dbSqlObj->insertTmpEventNotMember($this->getOwner_emp_cd(), $this->getSchedule_cd(), $tmpMember);
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュールユーザ一時テーブルの初期化に失敗しました";
      return false;
    }
    return true;
  }

  /**
   *一時イベントメンバーをscheduleMemberInfoArrayに読み込む
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleMemberInfo
   *@see tmp_event_member(table)
   */
  function  doSelectTmpMemberQuery($conn, $dbSqlObj, $dbExecObj) {
  	require_once("./class/ScheduleMemberInfo.php");
 	$strsql = $dbSqlObj->selectTmpEventMember_ListData($this->getOwner_emp_cd(), "1");
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュールメンバー一時テーブルの取得<br>\n";
      //exit;
      $this->errMsg = "スケジュールメンバー一時テーブルの取得失敗";
      return false;
    }

    for ($i = 0; $i < $dbExecObj->getNumRows($result); $i++)
    {
    	$tmpMemberInfo = new ScheduleMemberInfo();
		$tmpMemberInfo->setEmp_cd($dbExecObj->getResult($result, $i, "emp_cd"));
    	$tmpMemberInfo->setName($dbExecObj->getResult($result, $i, "emp_name"));
    	$tmpMemberInfo->setEnable("1");
    	$this->addScheduleMemberInfoArray($tmpMemberInfo);
    }

 	$strsql = $dbSqlObj->selectTmpEventMember_ListData($this->getOwner_emp_cd(), "2");
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュールメンバー一時テーブルの取得<br>\n";
      //exit;
      $this->errMsg = "スケジュールメンバー一時テーブルの取得失敗";
      return false;
    }

    for ($i = 0; $i < $dbExecObj->getNumRows($result); $i++)
    {
    	$tmpMemberInfo = new ScheduleMemberInfo();
		$tmpMemberInfo->setEmp_cd($dbExecObj->getResult($result, $i, "emp_cd"));
    	$tmpMemberInfo->setName($dbExecObj->getResult($result, $i, "emp_name"));
    	$tmpMemberInfo->setEnable("2");
    	$this->addScheduleMemberInfoArray($tmpMemberInfo);
    }
    return true;
  }

  /**
   *指定した一時イベントメンバーを指定の参加フラグに更新する
   *
   *@param Array $tmpMember メンバー
   *@param int enable 参加フラグ 0:不参加　1:参加　2:未定
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleMemberInfo
   *@see tmp_event_member(table)
   */
  function  doUpdateTmpMemberQuery($tmpMember, $enable, $conn, $dbSqlObj, $dbExecObj) {
 	$strsql = $dbSqlObj->updateTmpMember($this->getOwner_emp_cd(), $tmpMember, $enable);
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュールメンバー一時テーブルの更新に失敗<br>\n";
      //exit;
      $this->errMsg = "スケジュールメンバー一時テーブルの更新に失敗";
      return false;
    }
    return true;
  }

  /**
   *イベントメンバーをテーブル(wiz_event_member)に保存する
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleMemberInfo
   *@see wiz_event_member(table)
   */
  function  doInsertMemberQuery($InitialDate_cd, $conn, $dbSqlObj, $dbExecObj) {
  	$i = $InitialDate_cd;
	foreach($this->scheduleDateInfoArray as $key => $tmpDateInfo){
  		foreach($this->scheduleMemberInfoArray as $key => $tmpMember){
  			if($tmpMember->getEmp_cd() == $this->getOwner_emp_cd()){
	            $strSql = $dbSqlObj->insertScheduleMember($this->getSchedule_cd(), $i, $tmpMember->getEmp_cd(),1);
  			}
  			else{
	            $strSql = $dbSqlObj->insertScheduleMember($this->getSchedule_cd(), $i, $tmpMember->getEmp_cd(),$this->getMemberEnabled());
  			}
			$result = $dbExecObj->exeSql($conn, $strSql);
			if (!$result) {
				//echo "<FONT COLOR=\"red\">メンバー登録処理中に障害が発生しました。</FONT><br>\n";
				//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
				//exit;
		        $this->errMsg = "メンバー登録処理中に障害が発生しました。\\n";
			
				return false;
			}
  		}
  		
  		$i = $i + 1;
  	}

  	return true;
  }

  /**
   *イベントメンバーをテーブル(wiz_event_member)に保存する
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleMemberInfo
   *@see wiz_event_member(table)
   */
  function  doUpdateMemberQuery($schedule_date_cd_array, $conn, $dbSqlObj, $dbExecObj) {
    $strSql = $dbSqlObj->deleteScheduleMemberWithDateCdArray($this->getSchedule_cd(), $schedule_date_cd_array);
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
		//echo "<FONT COLOR=\"red\">メンバー登録処理中に障害が発生しました。</FONT><br>\n";
		//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
		//exit;
        $this->errMsg = "メンバー登録処理中に障害が発生しました。\\n";
	
		return false;
	}

	foreach($schedule_date_cd_array as $key => $value){
  		foreach($this->scheduleMemberInfoArray as $key => $tmpMember){
            $strSql = $dbSqlObj->insertScheduleMember($this->getSchedule_cd(), $value, $tmpMember->getEmp_cd(),$tmpMember->getEnable());
			$result = $dbExecObj->exeSql($conn, $strSql);
			if (!$result) {
				//echo "<FONT COLOR=\"red\">メンバー登録処理中に障害が発生しました。</FONT><br>\n";
				//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
				//exit;
		        $this->errMsg = "メンバー登録処理中に障害が発生しました。\\n";
			
				return false;
			}
  		}
  	}

  	return true;
  }
  
  /**
   *イベントメンバーをscheduleMemberInfoArrayに読み込む
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleMemberInfo
   *@see wiz_event_member(table)
   */
  function  doSelectMemberQuery($conn, $dbSqlObj, $dbExecObj) {
  }

  /**
   *イベントメンバーを削除する
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleMemberInfo
   *@see wiz_event_member(table)
   */
  function  doDeleteMemberQuery($conn, $dbSqlObj, $dbExecObj) {
  }

  /**
   *イベント日付を削除する
   *
   *@param $schedule_date_cd_array 日付コード配列
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleMemberInfo
   *@see wiz_event_member(table)
   */
  function doDeleteScheduleQuery($schedule_date_cd_array, $conn, $dbSqlObj, $dbExecObj){
  	//メンバー削除
  	$strSql = $dbSqlObj->deleteScheduleMemberWithDateCdArray($this->getSchedule_cd(),$schedule_date_cd_array);
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
		//echo "<FONT COLOR=\"red\">チェックに失敗しました。</FONT><br>\n";
		//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
		//exit;
		$this->errMsg = "メンバの削除に失敗しました。";
		return false;
	} 	
  	//予約削除
  	$strSql = $dbSqlObj->deleteScheduleReservationWithDateCdArray($this->getSchedule_cd(),$schedule_date_cd_array);
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
		//echo "<FONT COLOR=\"red\">チェックに失敗しました。</FONT><br>\n";
		//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
		//exit;
		$this->errMsg = "施設予約の削除に失敗しました。";
		return false;
	} 	
  	//日付削除
  	$strSql = $dbSqlObj->deleteScheduleWithDateCdArray($this->getSchedule_cd(),$schedule_date_cd_array);
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
		//echo "<FONT COLOR=\"red\">チェックに失敗しました。</FONT><br>\n";
		//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
		//exit;
		$this->errMsg = "スケジュール日付の削除に失敗しました。";
		return false;
	} 	
	return true;
  }

  /**
   *イベント施設をテーブル(reservation)に保存する
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *@param boolean rsvDoubleBooking 予約に重複ありかどうか OK:重複可 NG 重複不可
   *
   *@see ScheduleFacilityInfo
   *@see reservation(table)
   */
  function  doInsertFacilityQuery($InitialDate_cd, $conn, $dbSqlObj, $dbExecObj, $rsvDoubleBooking) {
  	$i = $InitialDate_cd;
	foreach($this->scheduleDateInfoArray as $key => $tmpDateInfo){
  		foreach($this->scheduleFacilityInfoArray as $key => $tmpFacility){

			$strSql = $dbSqlObj->selectReservationCountOfAllWithDateFacCd($tmpFacility->getFac_cd(),$tmpDateInfo["date"],$tmpDateInfo["time_s"],$tmpDateInfo["time_e"]);
			$result = $dbExecObj->exeSql($conn, $strSql);
			if (!$result) {
				//echo "<FONT COLOR=\"red\">チェックに失敗しました。</FONT><br>\n";
				//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
				//exit;
				$this->errMsg = "施設予約チェックに失敗しました。";
				return false;
    		} 	
			$checkdup = $dbExecObj->getResult($result, 0, "count_of_records");
			if($checkdup != 0){
				$tmpScheduleFacilityDateInfo = array();
				$tmpScheduleFacilityDateInfo["schedule_cd"] = $this->getSchedule_cd();
				$tmpScheduleFacilityDateInfo["fac_cd"] = $tmpFacility->getFac_cd();
				$tmpScheduleFacilityDateInfo["fac_name"] = $tmpFacility->getFac_name();
				$tmpScheduleFacilityDateInfo["date"] = $tmpDateInfo["date"];
				$tmpScheduleFacilityDateInfo["time_s"] = $tmpDateInfo["time_s"];
				$tmpScheduleFacilityDateInfo["time_e"] = $tmpDateInfo["time_e"];
				array_push($this->errFacilityInfoArray, $tmpScheduleFacilityDateInfo);
			}
			
			if((!isset($rsvDoubleBooking) || strtoupper($rsvDoubleBooking) == "NG") && $checkdup == 0){
	
	            $strSql = $dbSqlObj->insertReservation($tmpFacility->getFac_cd(),$this->getOwner_emp_cd(),$this->getSchedule_cd(), $i);
				$result = $dbExecObj->exeSql($conn, $strSql);
				if (!$result) {
					//echo "<FONT COLOR=\"red\">予約処理中に障害が発生しました。</FONT><br>\n";
					//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
					//exit;
					$this->errMsg = "予約処理中に障害が発生しました。";
					return false;
				}
			}
			elseif(strtoupper($rsvDoubleBooking) == "OK"){
	            $strSql = $dbSqlObj->insertReservation($tmpFacility->getFac_cd(),$this->getOwner_emp_cd(),$this->getSchedule_cd(), $i);
				$result = $dbExecObj->exeSql($conn, $strSql);
				if (!$result) {
					//echo "<FONT COLOR=\"red\">予約処理中に障害が発生しました。</FONT><br>\n";
					//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
					//exit;
					$this->errMsg = "予約処理中に障害が発生しました。";
					return false;
				}
			}
  		}
  		
  		$i = $i + 1;
  	}
  	return true;
  }

  /**
   *イベント施設をテーブル(reservation)に保存する
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *@param boolean rsvDoubleBooking 予約に重複ありかどうか OK:重複可 NG 重複不可
   *
   *@see ScheduleFacilityInfo
   *@see reservation(table)
   */
  function  doUpdateFacilityQuery($schedule_date_cd_array, $conn, $dbSqlObj, $dbExecObj, $rsvDoubleBooking) {
    $strSql = $dbSqlObj->deleteScheduleReservationWithDateCdArray($this->getSchedule_cd(), $schedule_date_cd_array);
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
		//echo "<FONT COLOR=\"red\">メンバー登録処理中に障害が発生しました。</FONT><br>\n";
		//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
		//exit;
        $this->errMsg = "施設予約更新処理中に障害が発生しました。\\n";
	
		return false;
	}
	foreach($this->scheduleDateInfoArray as $key => $tmpDateInfo){
  		foreach($this->scheduleFacilityInfoArray as $key => $tmpFacility){
			$tmpDate = $tmpDateInfo["year"] . "-" . $tmpDateInfo["month"] . "-" . $tmpDateInfo["day"];
			$tmpStime = $tmpDateInfo["hour_s"] . ":" . $tmpDateInfo["minute_s"] . ":00";
			$tmpEtime = $tmpDateInfo["hour_e"] . ":" . $tmpDateInfo["minute_e"] . ":00";
			$strSql = $dbSqlObj->selectReservationCountOfAllWithDateFacCd($tmpFacility->getFac_cd(),$tmpDate,$tmpStime,$tmpEtime);
			$result = $dbExecObj->exeSql($conn, $strSql);
			if (!$result) {
				//echo "<FONT COLOR=\"red\">チェックに失敗しました。</FONT><br>\n";
				//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
				//exit;
				$this->errMsg = "施設予約チェックに失敗しました。";
				return false;
    		} 	
			$checkdup = $dbExecObj->getResult($result, 0, "count_of_records");
			if($checkdup != 0){
				$tmpScheduleFacilityDateInfo = array();
				$tmpScheduleFacilityDateInfo["schedule_cd"] = $this->getSchedule_cd();
				$tmpScheduleFacilityDateInfo["fac_cd"] = $tmpFacility->getFac_cd();
				$tmpScheduleFacilityDateInfo["fac_name"] = $tmpFacility->getFac_name();
				$tmpScheduleFacilityDateInfo["date"] = $tmpDate;
				$tmpScheduleFacilityDateInfo["time_s"] = $tmpStime;
				$tmpScheduleFacilityDateInfo["time_e"] = $tmpEtime;
				array_push($this->errFacilityInfoArray, $tmpScheduleFacilityDateInfo);
			}
			
			if((!isset($rsvDoubleBooking) || strtoupper($rsvDoubleBooking) == "NG") && $checkdup == 0){
	            $strSql = $dbSqlObj->insertReservation($tmpFacility->getFac_cd(),$this->getOwner_emp_cd(),$this->getSchedule_cd(), $tmpDateInfo["schedule_date_cd"]);
				$result = $dbExecObj->exeSql($conn, $strSql);
				if (!$result) {
					//echo "<FONT COLOR=\"red\">予約処理中に障害が発生しました。</FONT><br>\n";
					//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
					//exit;
					$this->errMsg = "予約処理中に障害が発生しました。";
					return false;
				}
			}
			elseif(strtoupper($rsvDoubleBooking) == "OK"){
	            $strSql = $dbSqlObj->insertReservation($tmpFacility->getFac_cd(),$this->getOwner_emp_cd(),$this->getSchedule_cd(), $tmpDateInfo["schedule_date_cd"]);
				$result = $dbExecObj->exeSql($conn, $strSql);
				if (!$result) {
					//echo "<FONT COLOR=\"red\">予約処理中に障害が発生しました。</FONT><br>\n";
					//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
					//exit;
					$this->errMsg = "予約処理中に障害が発生しました。";
					return false;
				}
			}
  		}
  	}
  	return true;
  }

  /**
   *イベント施設をテーブル(reservation)に保存する
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *@param boolean rsvDoubleBooking 予約に重複ありかどうか OK:重複可 NG 重複不可
   *
   *@see ScheduleFacilityInfo
   *@see reservation(table)
   */
  function  doUpdateOneFacilityQuery($schedule_date_cd_array, $conn, $dbSqlObj, $dbExecObj, $rsvDoubleBooking, 
									$year_s, $month_s, $day_s, $hour_s, $minute_s, $hour_e, $minute_e) {
    $strSql = $dbSqlObj->deleteScheduleReservationWithDateCdArray($this->getSchedule_cd(), $schedule_date_cd_array);
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
		//echo "<FONT COLOR=\"red\">メンバー登録処理中に障害が発生しました。</FONT><br>\n";
		//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
		//exit;
        $this->errMsg = "施設予約更新処理中に障害が発生しました。\\n";
	
		return false;
	}
	foreach($this->scheduleFacilityInfoArray as $key => $tmpFacility){
		$tmpDate = $year_s . "-" . $month_s . "-" . $day_s;
		$tmpStime = $hour_s . ":" . $minute_s . ":00";
		$tmpEtime = $hour_e . ":" . $minute_e . ":00";
		$tmpScheduleDateCd = $schedule_date_cd_array[0];
		$strSql = $dbSqlObj->selectReservationCountOfAllWithDateFacCd($tmpFacility->getFac_cd(),$tmpDate,$tmpStime,$tmpEtime);
		$result = $dbExecObj->exeSql($conn, $strSql);
		if (!$result) {
			//echo "<FONT COLOR=\"red\">チェックに失敗しました。</FONT><br>\n";
			//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
			//exit;
			$this->errMsg = "施設予約チェックに失敗しました。";
			return false;
		} 	
		$checkdup = $dbExecObj->getResult($result, 0, "count_of_records");
		if($checkdup != 0){
			$tmpScheduleFacilityDateInfo = array();
			$tmpScheduleFacilityDateInfo["schedule_cd"] = $this->getSchedule_cd();
			$tmpScheduleFacilityDateInfo["fac_cd"] = $tmpFacility->getFac_cd();
			$tmpScheduleFacilityDateInfo["fac_name"] = $tmpFacility->getFac_name();
			$tmpScheduleFacilityDateInfo["date"] = $tmpDate;
			$tmpScheduleFacilityDateInfo["time_s"] = $tmpStime;
			$tmpScheduleFacilityDateInfo["time_e"] = $tmpEtime;
			array_push($this->errFacilityInfoArray, $tmpScheduleFacilityDateInfo);
		}

		if((!isset($rsvDoubleBooking) || strtoupper($rsvDoubleBooking) == "NG") && $checkdup == 0){

            $strSql = $dbSqlObj->insertReservation($tmpFacility->getFac_cd(),$this->getOwner_emp_cd(),$this->getSchedule_cd(), $tmpScheduleDateCd);
			$result = $dbExecObj->exeSql($conn, $strSql);
			if (!$result) {
				//echo "<FONT COLOR=\"red\">予約処理中に障害が発生しました。</FONT><br>\n";
				//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
				//exit;
				$this->errMsg = "予約処理中に障害が発生しました。";
				return false;
			}
		}
		elseif(strtoupper($rsvDoubleBooking) == "OK"){
            $strSql = $dbSqlObj->insertReservation($tmpFacility->getFac_cd(),$this->getOwner_emp_cd(),$this->getSchedule_cd(), $tmpScheduleDateCd);
			$result = $dbExecObj->exeSql($conn, $strSql);
			if (!$result) {
				//echo "<FONT COLOR=\"red\">予約処理中に障害が発生しました。</FONT><br>\n";
				//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
				//exit;
				$this->errMsg = "予約処理中に障害が発生しました。";
				return false;
			}
		}
  	}
  	return true;
  }
  /**
   *イベント施設をscheduleFacilityInfoArrayに読み込む
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleFacilityInfo
   *@see reservation(table)
   */
  function  doSelectFacilityQuery($conn, $dbSqlObj, $dbExecObj) {
  }

  /**
   *イベント施設を削除する
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleFacilityInfo
   *@see reservation(table)
   */
  function  doDeleteFacilityQuery($conn, $dbSqlObj, $dbExecObj) {
  }

  /**
   *一時施設テーブル初期化削除
   *指定スケジュールの指定日に関する施設ーを一時テーブルに読み込む
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleMemberInfo
   *@see tmp_event_member(table)
   */
  function  doUpdateInitialTmpAllFacilityQuery($conn, $dbSqlObj, $dbExecObj) {
	$strSql = $dbSqlObj->insertTmpEventFacility($this->getOwner_emp_cd(), $this->getSchedule_cd(), $this->getScheduleDate_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      //echo "スケジュール施設一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール施設一時テーブルの初期化に失敗しました";
      return false;
    }
    return true;
  }

  /**
   *一時イベント施設をscheduleFacilityInfoArrayに読み込む
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleFacilityInfo
   *@see tmp_reservation(table)
   */
  function  doSelectTmpFacilityQuery($conn, $dbSqlObj, $dbExecObj) {
  	require_once("./class/ScheduleFacilityInfo.php");
 	$strsql = $dbSqlObj->selectTmpFacFacNameOrderByFacNameFac_cd($this->getOwner_emp_cd());
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュール施設一時テーブルの取得<br>\n";
      //exit;
	  $this->errMsg = "スケジュール施設一時テーブルの取得処理中に障害が発生しました。";
	  
      return false;
    }

    for ($i = 0; $i < $dbExecObj->getNumRows($result); $i++)
    {
    	$tmpFacilityInfo = new ScheduleFacilityInfo();
		$tmpFacilityInfo->setFac_cd($dbExecObj->getResult($result, $i, "fac_cd"));
    	$tmpFacilityInfo->setFac_name($dbExecObj->getResult($result, $i, "fac_name"));
    	$this->addScheduleFacilityInfoArray($tmpFacilityInfo);
    }
    return true;
    
  }

  /**
   *一時イベント施設に配列で与えられた施設を追加する
   *
   *@param facilityArray 施設一覧
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see tmp_reservation(table)
   */
  function  doInsertTmpFacilityQuery($tmpFacilities, $conn, $dbSqlObj, $dbExecObj) {
	foreach($tmpFacilities as $key => $value){
	 	$strsql = $dbSqlObj->insertTmpFac($this->getOwner_emp_cd(), $value);
	    $result = $dbExecObj->exeSql($conn,$strsql);
	    if (!$result)
	    {
	      //echo "スケジュール施設一時テーブルの削除に失敗<br>\n";
	      //exit;
	      $this->errMsg = "スケジュール施設一時テーブルの削除に失敗。";
	      
	      return false;
	    }
	}
	return true;
  	
  }

  /**
   *一時イベント施設から配列で与えられた施設を削除する
   *
   *@param facilityArray 施設一覧
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see tmp_reservation(table)
   */
  function  doDeleteTmpFacilityQuery($tmpFacilities, $conn, $dbSqlObj, $dbExecObj) {
 	$strsql = $dbSqlObj->deleteTmpFac($tmpFacilities, $this->getOwner_emp_cd());
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュール施設一時テーブルの削除に失敗<br>\n";
      //exit;
      $this->errMsg = "スケジュール施設一時テーブルの削除に失敗。";
      return false;
    }
    return true;
  }

  /**
   *一時施設テーブル初期化
   *
   *@param conn データベースセッション管理オブジェクト
   *@param dbSqlObj SQL作成オブジェクト
   *@param dbExecObj データベース操作オブジェクト
   *
   *@see ScheduleMemberInfo
   *@see tmp_reservation(table)
   */
  function  doDeleteTmpAllFacilityQuery($conn, $dbSqlObj, $dbExecObj) {
 	$strsql = $dbSqlObj->deleteTmpEventFacility($this->getOwner_emp_cd());
    $result = $dbExecObj->exeSql($conn,$strsql);
    if (!$result)
    {
      //echo "スケジュール施設一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール施設一時テーブルの初期化に失敗しました";
      return false;
    } 	
    return true;
  }

  function  doSelectEventQuery($conn, $dbSqlObj, $dbExecObj) {
  }

  /**
   * イベントを削除する
   */
  function  doDeleteEventQuery($conn, $dbSqlObj, $dbExecObj) {
  	//メンバー削除
  	$strSql = $dbSqlObj->deleteScheduleAllMemberWithScheduleCd($this->getSchedule_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
		//echo "<FONT COLOR=\"red\">チェックに失敗しました。</FONT><br>\n";
		//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
		//exit;
		$this->errMsg = "メンバの削除に失敗しました。";
		return false;
	} 	
  	//予約削除
  	$strSql = $dbSqlObj->deleteScheduleAllReservationWithScheduleCd($this->getSchedule_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
		//echo "<FONT COLOR=\"red\">チェックに失敗しました。</FONT><br>\n";
		//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
		//exit;
		$this->errMsg = "施設予約の削除に失敗しました。";
		return false;
	} 	
  	//日付削除
  	$strSql = $dbSqlObj->deleteScheduleAllWithScheduleCd($this->getSchedule_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
		//echo "<FONT COLOR=\"red\">チェックに失敗しました。</FONT><br>\n";
		//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
		//exit;
		$this->errMsg = "スケジュール日付の削除に失敗しました。";
		return false;
	}
	
	//イベント削除
	$strSql = $dbSqlObj->deleteScheduleEvent($this->getSchedule_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
	if (!$result) {
		//echo "<FONT COLOR=\"red\">チェックに失敗しました。</FONT><br>\n";
		//echo "<A HREF=\"javascript:history.back()\">[BACK]</A>\n";
		//exit;
		$this->errMsg = "スケジュールの削除に失敗しました。";
		return false;
	}
	
	$this->errMsg = "スケジュールを削除しました";
	return true;
  }
  
  /**
   * イベントを登録する
   */
  function doInsertEventQuery($conn, $dbSqlObj, $dbExecObj){
  	//include_once("./include/serial.func");
	//$schedule_cd = getSerialCode("schedule_cd", $conn, $dbSqlObj, $dbExecObj);
	//$this->setSchedule_cd($schedule_cd);
	
//	$sqlStr = $dbSqlObj->insertScheduleInfo($this->getSchedule_cd(), $this->getOwner_emp_cd(), $this->getPlan(), $this->getPlace(), $this->getRemark(),'f',$this->isPublic());
	$sqlStr = $dbSqlObj->insertScheduleInfo($this->getSchedule_cd(), $this->getOwner_emp_cd(), $this->getPlan(), $this->getPlace(), $this->getRemark(),'f',$this->isPublic(),$this->isOutdoor());
								
	$result = $dbExecObj->exeSql($conn, $sqlStr);	
    if (!$result)
    {
      //echo "スケジュール登録に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール登録に失敗しました";
      return false;
    } 	
	
	return true;
  }

  /**
   * イベントを更新する
   */
  function doUpdateEventQuery($conn, $dbSqlObj, $dbExecObj){
	$strRemark = "";
	
	foreach($this->errFacilityInfoArray as $key => $value){
		$strRemark .= $value["date"] . "　" . $value["fac_name"] . "の予約が重複しています\\n";
		//$strRemark .= $value["date"] . "　" . $value["time_s"] . "　" . $value["time_e"] . "　" . $value["fac_name"] . "の予約に失敗しました\\n";
	}
//	$sqlStr = $dbSqlObj->updateScheduleInfo($this->getSchedule_cd(), $this->getPlan(), $strRemark,'f',$this->isPublic());
	$sqlStr = $dbSqlObj->updateScheduleInfo($this->getSchedule_cd(), $this->getPlan(), $strRemark,'f',$this->isPublic(),$this->isOutdoor());
	$result = $dbExecObj->exeSql($conn, $sqlStr);	
    if (!$result)
    {
      //echo "スケジュール登録に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール登録に失敗しました";
      return false;
    } 	
    $this->errMsg = $strRemark;
	return true;
  }

  /**
   * イベントを更新する
   */
  function doUpdateScheduleQuery($conn, $dbSqlObj, $dbExecObj){
//	$sqlStr = $dbSqlObj->updateScheduleInfo($this->getSchedule_cd(), $this->getPlan(), $this->getRemark(),'f',$this->isPublic());
	$sqlStr = $dbSqlObj->updateScheduleInfo($this->getSchedule_cd(), $this->getPlan(), $this->getRemark(),'f',$this->isPublic(),$this->isOutdoor());
	$result = $dbExecObj->exeSql($conn, $sqlStr);	
    if (!$result)
    {
      //echo "スケジュール登録に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール登録に失敗しました";
      return false;
    } 	
	return true;
  }

  /**
   * イベントの予定を更新する
   */
  function doUpdateSchedulePlanQuery($conn, $dbSqlObj, $dbExecObj){
	$sqlStr = $dbSqlObj->updateSchedulePlanInfo($this->getSchedule_cd(), $this->getPlan());
	$result = $dbExecObj->exeSql($conn, $sqlStr);	
    if (!$result)
    {
      //echo "スケジュール登録に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール登録に失敗しました";
      return false;
    } 	
	return true;
  }

  /**
   * 登録されているスケジュールメンバーと施設情報から初期EventCdを設定する
   */
  function doSelectInitialEventMode($conn, $dbSqlObj, $dbExecObj){
	$strSql = $dbSqlObj->countEventFacility($this->getSchedule_cd(), $this->getScheduleDate_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュールユーザ一時テーブルの初期化に失敗しました";
      return false;
    }
	$cntFacility = $dbExecObj->getResult($result, 0, "facility_count");

	$strSql = $dbSqlObj->countTmpEventMember($this->getOwner_emp_cd(), $this->getSchedule_cd(), $this->getScheduleDate_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュールユーザ一時テーブルの初期化に失敗しました";
      return false;
    }
	$cntMember = $dbExecObj->getResult($result, 0, "member_count");

	if($cntFacility == 0 && $cntMember == 0){
		$this->event_mode = 1;
	}
	elseif($cntFacility >= 1 && $cntMember == 0){
		$this->event_mode = 2;
	}
	elseif($cntFacility == 0 && $cntMember >= 1){
		$this->event_mode = 3;
	}
	else{
		$this->event_mode = 4;
	}
    return true;

  }

  /**
   * 登録されているスケジュールメンバーと施設情報から初期EventCdを設定する
   */
  function doSelectInitialEventModeWithoutOwner($conn, $dbSqlObj, $dbExecObj){
	$strSql = $dbSqlObj->countEventFacility($this->getSchedule_cd(), $this->getScheduleDate_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュールユーザ一時テーブルの初期化に失敗しました";
      return false;
    }
	$cntFacility = $dbExecObj->getResult($result, 0, "facility_count");

	$strSql = $dbSqlObj->countTmpEventMemberWithoutOwner($this->getSchedule_cd(), $this->getScheduleDate_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュールユーザ一時テーブルの初期化に失敗しました";
      return false;
    }
	$cntMember = $dbExecObj->getResult($result, 0, "member_count");

	if($cntFacility == 0 && $cntMember == 0){
		$this->event_mode = 1;
	}
	elseif($cntFacility >= 1 && $cntMember == 0){
		$this->event_mode = 2;
	}
	elseif($cntFacility == 0 && $cntMember >= 1){
		$this->event_mode = 3;
	}
	else{
		$this->event_mode = 4;
	}
    return true;

  }

  /**
   * 指定日のスケジュールコードデータを読み込む
   */
  function doSelectInitialEventInfo($conn, $dbSqlObj, $dbExecObj){
  	$strSql = $dbSqlObj->selectScheduleInfoDetail($this->getOwner_emp_cd(), $this->getSchedule_cd(), $this->getScheduleDate_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール情報取得に失敗しました";
      return false;
    }
	$this->plan = $dbExecObj->getResult($result, 0, "scdl_plan");
	$this->place = $dbExecObj->getResult($result, 0, "scdl_place");
	$this->remark = $dbExecObj->getResult($result, 0, "scdl_remarks");
	$this->public = $dbExecObj->getResult($result, 0, "flg_pub");
	$this->outdoor = $dbExecObj->getResult($result, 0, "flg_out");
  }
  
  function doSelectInitialEventDetailInfo($conn, $dbSqlObj, $dbExecObj){
  	$strSql = $dbSqlObj->selectScheduleDetailInfoDetail($this->getOwner_emp_cd(), $this->getSchedule_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール情報取得に失敗しました";
      return false;
    }
	$this->plan = $dbExecObj->getResult($result, 0, "scdl_plan");
	$this->place = $dbExecObj->getResult($result, 0, "scdl_place");
	$this->remark = $dbExecObj->getResult($result, 0, "scdl_remarks");
	$this->public = $dbExecObj->getResult($result, 0, "flg_pub");
	$this->outdoor = $dbExecObj->getResult($result, 0, "flg_out");
  }
  
  /**
   * ユーザが参照できるスケジュール化を確認する
   */
  function doCheckSchedulePermit($emp_cd, $conn, $dbSqlObj, $dbExecObj){
	$rtnValue = 0;
  	$strSql = $dbSqlObj->selectBolSchedulePermit($emp_cd, $this->getSchedule_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
      //exit;
      $this->errMsg = "スケジュール情報取得に失敗しました";
      return false;
    }
	$rtnValue = $dbExecObj->getResult($result, 0, "permit");
	
	if($rtnValue == 0){
	  	$strSql = $dbSqlObj->selectBolScheduleOwnerPermit($emp_cd, $this->getSchedule_cd());
		$result = $dbExecObj->exeSql($conn, $strSql);
	    if (!$result)
	    {
	      //echo "スケジュールユーザ一時テーブルの初期化に失敗しました<br>\n";
	      //exit;
	      $this->errMsg = "スケジュール情報取得に失敗しました";
	      return false;
	    }
		$rtnValue = $dbExecObj->getResult($result, 0, "permit");	
	}
		
	if($rtnValue == 0){
		return false;
	}
	else{
		return true;
	}
	
	return true;
  }

  /**
   * ScheduleDateInfoArray を設定する
   * @param Array scheduleDateInfoArray スケジュール日付
   *
   */
  function  setScheduleDateInfoArray( $scheduleDateInfoArray) {
	$this->scheduleDateInfoArray = $scheduleDateInfoArray;
  }

  /**
   * ScheduleFacilityInfoArray を設定する
   * @param Array scheduleFacilityInfoArray 施設配列
   *
   */
  function  setScheduleFacilityInfoArray( $scheduleFacilityInfoArray) {
	$this->scheduleFacilityInfoArray = $scheduleFacilityInfoArray;
  }

  /**
   * ScheduleMemberInfoArray を設定する
   * @param Array scheduleMemberInfoArray メンバー配列
   *
   */
  function  setScheduleMemberInfoArray( $scheduleMemberInfoArray) {
	$this->scheduleMemberInfoArray = $scheduleMemberInfoArray;
  }

  /**
   *ScheduleMemberInfo を ScheduleMemberInfoArray に追加する
   *@param ScheduleMemberInfo scheduleMemberInfo スケジュールメンバー
   *
   */
  function  addScheduleMemberInfoArray( $scheduleMemberInfo) {
  	array_push($this->scheduleMemberInfoArray, $scheduleMemberInfo);
  }

  /**
   *ScheduleFacilityInfo を ScheduleFacilityInfoArray に追加する
   *@param ScheduleFacilityInfo scheduleFacilityInfo スケジュール施設
   *
   */
  function  addScheduleFacilityInfoArray( $scheduleFacilityInfo) {
  	array_push($this->scheduleFacilityInfoArray, $scheduleFacilityInfo);
  }

  /**
   * エラーメッセージ取得
   */
  function getErrMsg(){
 	return $this->errMsg;
  }
  
  /**
   * 回覧板用情報を取得する
   */
  function getNoticeData($emp_name, &$title, &$body, &$member){
  	$title = ($emp_name) . "様よりスケジュール情報が登録されています";
  	$body = "[スケジュール登録者：]<br>\n";
  	$body .= htmlSpecialEscape($emp_name) . "<br>\n";
  	$body .= "<br>\n";

	$body .= "[スケジュール日：]<br>\n";
	
	foreach($this->getScheduleDateInfoArray() as $key => $tmpDateInfo){
		$body .= $tmpDateInfo["date"] . "　" . 
				$tmpDateInfo["time_s"] . 
				($tmpDateInfo["time_s"] == "" && $tmpDateInfo["time_e"] == "" ? "" : "-") . 
				$tmpDateInfo["time_e"] . "<br>\n";
	}  	

  	$body .= "<br>\n";

	if(count($this->getScheduleFacilityInfoArray()) > 0){
		$body .= "[場所：]<br>\n";
		foreach($this->getScheduleFacilityInfoArray() as $key => $tmpFacilityInfo){
			$body .= htmlSpecialEscape($tmpFacilityInfo->getFac_name()) . "<br>\n";
		}
	}

  	$body .= "<br>\n";
	
	$body .= "[内容：]<br>\n";
	$body .= htmlSpecialEscape($this->getPlan()) . "<br>\n";

  	$body .= "<br>\n";
	
	if($this->getRemark() != ""){
		$body .= "[備考：]<br>\n";
		$body .= htmlSpecialEscape($this->getRemark());
	}	
	
  	$body .= "<br>\n";

	if(count($this->getScheduleMemberInfoArray()) > 0){
		foreach($this->getScheduleMemberInfoArray() as $key => $tmpMember){
			array_push($member, $tmpMember->getEmp_cd());
		}
	}
	
  }

  /**
   * 回覧板用情報を取得する
   */
  function getUpdateNoticeData($emp_name, &$title, &$body, &$member){
  	$title = ($emp_name) . "様よりスケジュール情報が更新されています";
  	$body = "[スケジュール更新者：]<br>\n";
  	$body .= htmlSpecialEscape($emp_name) . "<br>\n";
  	$body .= "<br>\n";
  	
	$body .= "[スケジュール日：]<br>\n";

	foreach($this->getScheduleDateInfoArray() as $key => $tmpDateInfo){
		$tmpDate = $tmpDateInfo["year"] . "-" . $tmpDateInfo["month"] . "-" . $tmpDateInfo["day"];
		if($tmpDateInfo["hour_s"] == "" || !isset($tmpDateInfo["hour_s"]) ||
			$tmpDateInfo["minute_s"] == "" || !isset($tmpDateInfo["minute_s"])){
			
			$tmpStime = "";
		}
		else {
			$tmpStime = $tmpDateInfo["hour_s"] . ":" . $tmpDateInfo["minute_s"] . ":00";
		}
		if($tmpDateInfo["hour_e"] == "" || !isset($tmpDateInfo["hour_e"]) ||
			$tmpDateInfo["minute_e"] == "" || !isset($tmpDateInfo["minute_e"])){
			
			$tmpEtime = "";
		}
		else {
			$tmpEtime = $tmpDateInfo["hour_e"] . ":" . $tmpDateInfo["minute_e"] . ":00";
		}
		$body .= $tmpDate . "　" . $tmpStime . ($tmpStime == "" && $tmpEtime == "" ? "" : "-") . $tmpEtime . "<br>\n";
	}  	

  	$body .= "<br>\n";

	if(count($this->getScheduleFacilityInfoArray()) > 0){
		$body .= "[場所：]<br>\n";
		foreach($this->getScheduleFacilityInfoArray() as $key => $tmpFacilityInfo){
			$body .= htmlSpecialEscape($tmpFacilityInfo->getFac_name()) . "<br>\n";
		}
	}

  	$body .= "<br>\n";
	
	$body .= "[内容：]<br>\n";
	$body .= htmlSpecialEscape($this->getPlan()) . "<br>\n";
	
  	$body .= "<br>\n";

	if($this->getRemark() != ""){
		$body .= "[備考：]<br>\n";
		$body .= htmlSpecialEscape($this->getRemark());
	}	

  	$body .= "<br>\n";

	if(count($this->getScheduleMemberInfoArray()) > 0){
		foreach($this->getScheduleMemberInfoArray() as $key => $tmpMember){
			array_push($member, $tmpMember->getEmp_cd());
		}
	}
  }

  /**
   * 日時のないイベントが登録されていないかチェック
   * メンバーも施設もないイベントが登録されていないかチェック
   */
  function checkEventData($conn, $dbSqlObj, $dbExecObj){
  	/*日時のないイベントが登録されていないかチェック*/
  	$strSql = $dbSqlObj->countEventDateWithScdlcd($this->getSchedule_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      $this->errMsg = "スケジュール日付テーブルのチェックに失敗しました";
      return false;
    }
	$cntDate = $dbExecObj->getResult($result, 0, "date_count");
	
	if($cntDate == 0){
		return false;
	}
  	
  	/*メンバーも施設もないイベントが登録されていないかチェック*/
	$strSql = $dbSqlObj->countEventFacilityWithScdlcd($this->getSchedule_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      $this->errMsg = "スケジュール施設テーブルのチェックに失敗しました";
      return false;
    }
	$cntFacility = $dbExecObj->getResult($result, 0, "facility_count");

	$strSql = $dbSqlObj->countTmpEventMemberWithScdlcd($this->getSchedule_cd());
	$result = $dbExecObj->exeSql($conn, $strSql);
    if (!$result)
    {
      $this->errMsg = "スケジュールユーザテーブルのチェックに失敗しました";
      return false;
    }
	$cntMember = $dbExecObj->getResult($result, 0, "member_count");
	
	if(($cntFacility + $cntMember) == 0){
		return false;
	}

    return true;

  }

}

?>