<?php
/**
 *イベント管理表示用クラス
 *
 * @author hideki HARANAKA <hideki-h@syscon.co.jp>
 */
class ScheduleEventView {

  /**
   *クラス名称
   */
  var $classname = "ScheduleEventView";

  /**
   *イベントの状態を表すフラグ<br>
   *
   *<ol>
   *<li>自分のスケジュールのみ登録</li>
   *<li>自分のスケジュールと施設予約</li>
   *<li>自分のスケジュールとメンバーのスケジュール</li>
   *<li>自分のスケジュールと施設予約・メンバーのスケジュール</li>
   *</ol>
   */
  var $event_mode;

  /**
   * 日付の登録モード
   *
   * @param int date_mode <ul>
   * <li>0：日にち指定</li>
   * <li>1：曜日指定</li>
   * <li>2：週指定</li>
   * <li>3：月日指定</li>
   * <li>4：期間指定</li>
   * <li>5：期間と時間指定</li>
   * </ul>
   */
  var $date_mode;

  /**
   * 日付情報クラス
   * @see DateInfo
   */
  var $dateInfo;

  /**
   *イベント管理クラス
   *
   *@see ScheduleEventInfo
   */
  var  $scheduleEventInfo;
  
  /**
   * <ul>
   * 	<li>addScreen スケジュール登録</li>
   * 	<li>updateScreen 更新画面</li>
   * 	<li>updateDetailScreen 詳細画面</li>
   * </ul>
   */
  var $subScreenMode;
  var $originScreenMode;

  /**
   * 呼び出し元のページ
   */
  var $refPage;
  
  /**
   * 参照配列番号
   */
  var $arrayIndexN;
  
  /**
   * 呼び出しもとのアプリケーション
   */
  var $refApplication;

  /**
   *コンストラクタ
   */
  function  ScheduleEventView() {
  }

  /**
   * refPage 設定
   */
  function setRefPage($refPage){
  	$this->refPage = $refPage;
  	switch($refPage){
  		case "scdlMonth":
  		case "scdlWeek":
  		case "scdlDay":
  			$this->refApplication = "schedule2.php";
  			break;
  		default:
  			$this->refApplication = "reserve.php";  		
  	}
  }
  
  /**
   * 参照配列番号設定
   */
  function setArrayIndexN($arrayIndexN){
	$this->arrayIndexN = $arrayIndexN;
  }
  
  /**
   * ScreenModeを設定する
   */
  function setSubScreenMode($subScreenMode){
  	$this->originScreenMode = $subScreenMode;
  	if($subScreenMode == "updateScreen"){
  		$subScreenMode = "updateScreen2";
  	}
  	$this->subScreenMode = $subScreenMode;
  }
   
  /**
   *イベントモードを取得する
   */
  function  getEvent_mode() {
    return $this->event_mode;
  }

  /**
   *イベントモードを設定する
   */
  function  setEvent_mode( $event_mode) {
    $this->event_mode = $event_mode;
  }

  /**
   * 日付の登録モード
   *
   * @param int date_mode <ul>
   * <li>0：日にち指定</li>
   * <li>1：曜日指定</li>
   * <li>2：週指定</li>
   * <li>3：月日指定</li>
   * <li>4：期間指定</li>
   * <li>5：期間と時間指定</li>
   * </ul>
   */
  function setDate_mode($date_mode){
    $this->date_mode = $date_mode;
  }

  /**
   * 日付の登録モード
   *
   * @return int date_mode <ul>
   * <li>0：日にち指定</li>
   * <li>1：曜日指定</li>
   * <li>2：週指定</li>
   * <li>3：月日指定</li>
   * <li>4：期間指定</li>
   * <li>5：期間と時間指定</li>
   * </ul>
   */
  function getDate_mode(){
    return $this->date_mode;
  }

  /**
   * 日付情報クラス設定
   * @param DateInfo dateInfo 日付情報クラスインスタンス
   */
  function setDateInfo($dateInfo){
    $this->dateInfo = $dateInfo;
  }

  function setScheduleEventInfo($scheduleEventInfo){
        $this->scheduleEventInfo = $scheduleEventInfo;
//      print_r($this->scheduleEventInfo);
  }

  function  printEventView($monthTab, $weekTab, $dayTab) {
    require_once("./gw.php");

	if($this->refApplication == "schedule2.php"){
?>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr> 
                  <td valign="bottom"> <a href="<?php echo $this->refApplication . "?sub=monthScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/<?php echo $monthTab ?>" width="240" height="29" alt="月で表示" border="0"></a></td>
                  <td valign="bottom"> 
                    <div align="center"><a href="<?php echo $this->refApplication . "?sub=weekScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/<?php echo $weekTab ?>" width="240" height="29" alt="週で表示" border="0"></a></div>
                  </td>
                  <td valign="bottom"> 
                    <div align="right"><a href="<?php echo $this->refApplication . "?sub=dayScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/<?php echo $dayTab ?>" width="240" height="29" alt="日で表示" border="0"></a></div>
                  </td>
                </tr>
              </table>
            </td>
          </tr>
          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="15" alt=""></td>
            <td class="yellow">　</td>
            <td class="yellow">　</td>
          </tr>

          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="5" alt=""></td>
            <td></td>
            <td></td>
          </tr>
<?php
	}
	else{
?>
			</td>
          </tr>

          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="5" alt=""></td>
            <td></td>
            <td></td>
          </tr>

<?php
	}
?>
          <tr> 
            <td>　</td>
            <td colspan="2">
                <form name="schedule_date_frm" method="post" action="<?php echo $_ROOT_URL_ . $this->refApplication ?>">
                  <INPUT TYPE="hidden" NAME="trans_id" VALUE="<? echo mt_rand(); ?>">
                  <input type="hidden" name="emp_cd" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getOwner_emp_cd()) ?>">
				  <input type="hidden" name="n" value="<?php echo htmlSpecialEscape($this->arrayIndexN) ?>">
				  <input type="hidden" name="refPage" value="<?php echo htmlSpecialEscape($this->refPage) ?>">
				  <input type="hidden" name="originScreenMode" value="<?php echo htmlSpecialEscape($this->originScreenMode) ?>">

                  <!-- ↓スケジュール入力テーブル -->
                  <table border="0" cellspacing="2" cellpadding="0">
                    <tr>
                      <td>
                        <span class="fBlack10150"><b>■スケジュール登録</b></span>
                      </td>
                    </tr>

<?php
$this->printInsertDate();

$this->printInsertNaiyou();

if($this->scheduleEventInfo->getEvent_mode() == "2" or $this->scheduleEventInfo->getEvent_mode() == "4"){
        $this->printInsertFacility();
}
if($this->scheduleEventInfo->getEvent_mode() == "3" or $this->scheduleEventInfo->getEvent_mode() == "4"){
        $this->printInsertMember();
}

$this->printInsertOption();
?>


                  </table>
                  <!-- ↑スケジュール入力テーブル -->
                  <img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="10" alt=""><br>

<?php
$this->printButton();
?>

                </form>
              </td>
            </tr>
<?php

  }
  
  /**
   *日付を入力する画面を表示する
   */
  function  printInsertDate() {
        require_once("./gw.php");

	if($this->subScreenMode != "addScreen"){
?>
                          <tr>
                            <td align="left">
                              <span class="fBlack10100"><b>日時：</b></span>
                            </td>
                            <td align="right">
                            </td>
                          </tr>
<?php
	}
?>
                          <tr>
                            <td colspan="2">
                      <script language="JavaScript">
                    <!--
                      function setTable()
                      {
                        document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                        document.schedule_date_frm.action = "<?php echo $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
                        document.schedule_date_frm.submit();
                      }
                    -->
                  </script>
                              <select name="date_mode" onChange="setTable()">
                                <option <?php echo $this->getDate_mode() == "0" ? "selected" : "" ?> value="0">当日のみ</option>
                                <option <?php echo $this->getDate_mode() == "1" ? "selected" : "" ?> value="1">曜日指定</option>
                                <option <?php echo $this->getDate_mode() == "2" ? "selected" : "" ?> value="2">週指定</option>
                                <option <?php echo $this->getDate_mode() == "3" ? "selected" : "" ?> value="3">日にち指定</option>
                                <option <?php echo $this->getDate_mode() == "4" ? "selected" : "" ?> value="4">期間指定</option>
                                <option <?php echo $this->getDate_mode() == "5" ? "selected" : "" ?> value="5">期間と時間指定</option>
                              </select>
                            </td>
                          </tr>
                          <tr>
                            <td colspan="2" align="center">
<?php
    switch($this->getDate_mode()){
    case 0:
?>
                              <table id="tbl1" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">日付：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日

<?php $this->printSelect("hour_s", $this->dateInfo->getStartHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_s", $this->dateInfo->getStartMinute(), 5, 0, 55,true); ?>分
〜
<?php $this->printSelect("hour_e", $this->dateInfo->getEndHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_e", $this->dateInfo->getEndMinute(), 5, 0, 55,true); ?>分
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>


<?php
        break;
    case 1:
?>
                              <table id="tbl2" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">日付：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日
〜
                                            <input type="text" name="year_e" size="4" maxlength="4" value="<?php echo $this->dateInfo->getEndYear() ?>">年
<?php $this->printSelect("month_e", $this->dateInfo->getEndMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("e");
$this->printSelect("day_e", $this->dateInfo->getEndDay(), 1, 1, 31,true); 
?>日
                                          </span>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">時間：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
<?php $this->printSelect("hour_s", $this->dateInfo->getStartHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_s", $this->dateInfo->getStartMinute(), 5, 0, 55,true); ?>分
〜
<?php $this->printSelect("hour_e", $this->dateInfo->getEndHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_e", $this->dateInfo->getEndMinute(), 5, 0, 55,true); ?>分
                                          </span>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100" valign="top">
                                          <span class="fBlack10100">曜日：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
<?php 
$arrWkCheckbox = array();
$arrWkCheckbox = $this->dateInfo->getWeek_day();
$flgCheck = array(0=>false, 1=>false, 2=>false, 3=>false, 4=>false, 5=>false, 6=>false );
if(is_array($arrWkCheckbox)){
	foreach($arrWkCheckbox as $key => $value){
		$flgCheck[$value] = true;
	}
}
?>
                                            <input type="checkbox" name="week_day[]" value="1" <?php echo ($flgCheck[1] ? "checked" : ""); ?>>月
                                            <input type="checkbox" name="week_day[]" value="2" <?php echo ($flgCheck[2] ? "checked" : ""); ?>>火
                                            <input type="checkbox" name="week_day[]" value="3" <?php echo ($flgCheck[3] ? "checked" : ""); ?>>水
                                            <input type="checkbox" name="week_day[]" value="4" <?php echo ($flgCheck[4] ? "checked" : ""); ?>>木
                                            <input type="checkbox" name="week_day[]" value="5" <?php echo ($flgCheck[5] ? "checked" : ""); ?>>金
                                            <input type="checkbox" name="week_day[]" value="6" <?php echo ($flgCheck[6] ? "checked" : ""); ?>>土
                                            <input type="checkbox" name="week_day[]" value="0" <?php echo ($flgCheck[0] ? "checked" : ""); ?>>日
                                            <br>
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>

<?php
        break;
    case 2:
?>
                              <table id="tbl3" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">日付：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日
〜
                                            <input type="text" name="year_e" size="4" maxlength="4" value="<?php echo $this->dateInfo->getEndYear() ?>">年
<?php $this->printSelect("month_e", $this->dateInfo->getEndMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("e");
$this->printSelect("day_e", $this->dateInfo->getEndDay(), 1, 1, 31,true); 
?>日
                                          </span>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">時間：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
<?php $this->printSelect("hour_s", $this->dateInfo->getStartHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_s", $this->dateInfo->getStartMinute(), 5, 0, 55,true); ?>分
〜
<?php $this->printSelect("hour_e", $this->dateInfo->getEndHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_e", $this->dateInfo->getEndMinute(), 5, 0, 55,true); ?>分
                                          </span>
                                        </td>
                                      </tr>

                                      <tr>
                                        <td width="100" valign="top">
                                          <span class="fBlack10100">週指定：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
<?php 
$arrWkCheckbox = array();
$arrWkCheckbox = $this->dateInfo->getMonth_of_week();
$flgCheck = array(0=>false, 1=>false, 2=>false, 3=>false, 4=>false, 5=>false, 6=>false );
if(is_array($arrWkCheckbox)){
	foreach($arrWkCheckbox as $key => $value){
		$flgCheck[$value] = true;
	}
}
?>
                                            <input type="checkbox" name="month_of_week[]" value="1" <?php echo ($flgCheck[1] ? "checked" : ""); ?>>第１
                                            <input type="checkbox" name="month_of_week[]" value="2" <?php echo ($flgCheck[2] ? "checked" : ""); ?>>第２
                                            <input type="checkbox" name="month_of_week[]" value="3" <?php echo ($flgCheck[3] ? "checked" : ""); ?>>第３
                                            <input type="checkbox" name="month_of_week[]" value="4" <?php echo ($flgCheck[4] ? "checked" : ""); ?>>第４
                                            <input type="checkbox" name="month_of_week[]" value="5" <?php echo ($flgCheck[5] ? "checked" : ""); ?>>第５
                                            <input type="checkbox" name="month_of_week[]" value="6" <?php echo ($flgCheck[6] ? "checked" : ""); ?>>最終
<?php
$arrWkCheckbox = array();
$arrWkCheckbox = $this->dateInfo->getWeek_day();
$flgCheck = array(0=>false, 1=>false, 2=>false, 3=>false, 4=>false, 5=>false, 6=>false );
if(is_array($arrWkCheckbox)){
	foreach($arrWkCheckbox as $key => $value){
		$flgCheck[$value] = true;
	}
}
?>
                                            <select name="week_day[]">
                                              <option value="1" <?php echo ($flgCheck[1] ? "selected" : ""); ?>>月</option>
                                              <option value="2" <?php echo ($flgCheck[2] ? "selected" : ""); ?>>火</option>
                                              <option value="3" <?php echo ($flgCheck[3] ? "selected" : ""); ?>>水</option>
                                              <option value="4" <?php echo ($flgCheck[4] ? "selected" : ""); ?>>木</option>
                                              <option value="5" <?php echo ($flgCheck[5] ? "selected" : ""); ?>>金</option>
                                              <option value="6" <?php echo ($flgCheck[6] ? "selected" : ""); ?>>土</option>
                                              <option value="0" <?php echo ($flgCheck[0] ? "selected" : ""); ?>>日</option>
                                            </select>曜日
                                          </span>
                                        </td>
                                      </tr>

                                    </table>
                                  </td>
                                </tr>
                              </table>

<?php
        break;
    case 3:
?>
                              <table id="tbl4" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                       <td width="100">
                                          <span class="fBlack10100">日付：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日
〜
                                            <input type="text" name="year_e" size="4" maxlength="4" value="<?php echo $this->dateInfo->getEndYear() ?>">年
<?php $this->printSelect("month_e", $this->dateInfo->getEndMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("e");
$this->printSelect("day_e", $this->dateInfo->getEndDay(), 1, 1, 31,true); 
?>日
                                          </span>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">時間：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
<?php $this->printSelect("hour_s", $this->dateInfo->getStartHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_s", $this->dateInfo->getStartMinute(), 5, 0, 55,true); ?>分
〜
<?php $this->printSelect("hour_e", $this->dateInfo->getEndHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_e", $this->dateInfo->getEndMinute(), 5, 0, 55,true); ?>分
                                          </span>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100" valign="top">
                                          <span class="fBlack10100">日にち指定：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">毎月
<?php $this->printSelect("month_of_day", $this->dateInfo->getMonth_of_day(), 1, 1, 31,false); ?>日
                                           </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>

<?php
        break;
    case 4:
?>
                              <table id="tbl4" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">日付範囲：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日
〜
                                            <input type="text" name="year_e" size="4" maxlength="4" value="<?php echo $this->dateInfo->getEndYear() ?>">年
<?php $this->printSelect("month_e", $this->dateInfo->getEndMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("e");
$this->printSelect("day_e", $this->dateInfo->getEndDay(), 1, 1, 31,true); 
?>日
                                          </span>
                                        </td>
                                      </tr>

                                    </table>
                                  </td>
                                </tr>
                              </table>

<?php
        break;
    case 5:
?>
                              <table id="tbl4" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                       <td width="100">
                                          <span class="fBlack10100">日付：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true);
?>日
〜
                                            <input type="text" name="year_e" size="4" maxlength="4" value="<?php echo $this->dateInfo->getEndYear() ?>">年
<?php $this->printSelect("month_e", $this->dateInfo->getEndMonth(), 1, 1, 12,true); ?>月
<?php
$tmpLastMonth = $this->dateInfo->getLastMonth("e");
$this->printSelect("day_e", $this->dateInfo->getEndDay(), 1, 1, 31,true);
?>日
                                          </span>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">時間：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
<?php $this->printSelect("hour_s", $this->dateInfo->getStartHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_s", $this->dateInfo->getStartMinute(), 5, 0, 55,true); ?>分
〜
<?php $this->printSelect("hour_e", $this->dateInfo->getEndHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_e", $this->dateInfo->getEndMinute(), 5, 0, 55,true); ?>分
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>

<?php
        break;
    default:
?>
                              <table id="tbl1" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">日付：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日

<?php $this->printSelect("hour_s", $this->dateInfo->getStartHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_s", $this->dateInfo->getStartMinute(), 5, 0, 55,true); ?>分
〜
<?php $this->printSelect("hour_e", $this->dateInfo->getEndHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_e", $this->dateInfo->getEndMinute(), 5, 0, 55,true); ?>分
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>


<?php
    }
    
?>

                            </td>
                          </tr>
                          <tr>
                            <td colspan="2">
                            <?php /*
                              <img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="10" alt="">
							*/ ?>
                            </td>
                          </tr>

<?php
  }

  /**
   *日付を参照する画面を表示する
   */
  function  printDetailDate() {
  }

  /**
   *内容を入力する画面を表示する
   */
  function  printInsertNaiyou() {
?>

                          <tr>
                            <td colspan="2" align="center">
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100" valign="top"> <span class="fBlack10100">予定：</span></td>
                                        <td width="550">
                                          <textarea name="plan" cols="64" rows="1" wrap="VIRTUAL"><?php echo htmlSpecialEscape(stripslashes($this->scheduleEventInfo->getPlan())) ?></textarea>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100" valign="top"> <span class="fBlack10100">備考：</span></td>
                                        <td width="550">
                                          <textarea name="remark" cols="64" rows="3" wrap="VIRTUAL"><?php echo htmlSpecialEscape(stripslashes($this->scheduleEventInfo->getRemark())) ?></textarea>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

                          <tr>
                            <td colspan="2">
                            <?php /*
                              <img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="10" alt="">
							*/ ?>
                            </td>
                          </tr>


<?php
  }

  /**
   *施設を登録する画面を表示する
   */
  function  printInsertFacility() {
  	require_once("./gw.php");
?>

                          <tr>
                            <td colspan="2" align="center">
                             <script language="JavaScript">
                              <!--
<?php

        require_once($_ROOT_URL_ . "class/javascriptselect_cat_fac_schedule_facility.php");

        $JavaScriptSelect_CatFacScheduleFacility = $this->scheduleEventInfo->getJavaScriptSelect_CatFacScheduleFacility();
		if(count($JavaScriptSelect_CatFacScheduleFacility->getMainElementArray()) >= 1){
	        $JavaScriptSelect_CatFacScheduleFacility->printInitSelectFunction();
		    $JavaScriptSelect_CatFacScheduleFacility->printChangeSelectFunction();
		}
?>
                              function cmdAddFacilities(numOperation){
                                document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                                document.schedule_date_frm.facilityOperate.value = numOperation;
                                document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
                                document.schedule_date_frm.submit();
                              }
                              //-->
                              </script>
                              <table width="650" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td valign="top" width="100">
                                          <span class="fBlack10100">施設：</span>
                                        </td>
                                        <td width="200">
                                          <select name="fac_cat_cd" onChange="changeSelectFac(document.schedule_date_frm)">
<?php $JavaScriptSelect_CatFacScheduleFacility->printDefaultMainOption(); ?>
                                          </select><br>
<?php
if($JavaScriptSelect_CatFacScheduleFacility->getSelectedSubElementIndex() == 0){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="facilities1[]" size="5" multiple <?php echo $selectStyle ?>>
<?php $JavaScriptSelect_CatFacScheduleFacility->printDefaultSubOption(); ?>
                                          </select>
                                        </td>
                                        <td valign="middle" width="50">
                                          <input type="button" name="cmdAddFacility" value="   追加 →" onClick="cmdAddFacilities(1)">

                                          <input type="button" name="cmdAddFacility" value="← 削除   " onClick="cmdAddFacilities(2)">
                                        </td>
                                        <td valign="top" width="100">
                                          <span class="fBlack10100">予約施設：</span>
                                        </td>
                                        <td width="200">
<?php
$tmpFacilityInfoArray = $this->scheduleEventInfo->getScheduleFacilityInfoArray();
if(count($tmpFacilityInfoArray) == 0){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="facilities2[]" multiple size="5" <?php echo $selectStyle ?>>
<?php
if(count($tmpFacilityInfoArray) != 0){
	foreach($tmpFacilityInfoArray as $key => $tmpFacilityInfo){
		echo "<option value=\"" . $tmpFacilityInfo->getFac_cd() . "\">" . htmlSpecialEscape($tmpFacilityInfo->getFac_name()) . "</option>\n";
	}
}
?>
                                          </select>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                              <input type="hidden" name="facilityOperate">
                              <script language="JavaScript">
                              <!--
<?php
		if(count($JavaScriptSelect_CatFacScheduleFacility->getMainElementArray()) >= 1){
?>
                                initSelectFac(document.schedule_date_frm);
<?php
		}
?>
                              //-->
                              </script>
                            </td>
                          </tr>

                          <tr>
                            <td colspan="2">
                            <?php /*
                              <img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="10" alt="">
							*/ ?>
                            </td>
                          </tr>
<?php
  }

  /**
   *施設を参照する画面を表示する
   */
  function  printDetailFacility() {
  }

  /**
   *メンバーを登録する画面を表示する
   *@param String division 部門情報
   */
  function  printInsertMember() {
	require_once("./gw.php");
?>

                          <tr>
                            <td colspan="2" align="center">
                              <script language="JavaScript">
                              <!--
<?php

        require_once($_ROOT_URL_ . "class/javascriptselect_div_emp_schedule_member.php");

        $JavaScriptSelect_DivEmpScheduleMember = $this->scheduleEventInfo->getJavaScriptSelect_DivEmpScheduleMember();
		if(count($JavaScriptSelect_DivEmpScheduleMember->getSubElementArray()) >= 1){
	        $JavaScriptSelect_DivEmpScheduleMember->printInitSelectFunction();
	        $JavaScriptSelect_DivEmpScheduleMember->printChangeSelectFunction();
		}
?>
                              function cmdAddMembers(numOperation){
                                document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                                document.schedule_date_frm.memberOperate.value = numOperation;
                                document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
                                document.schedule_date_frm.submit();
                              }
                              //-->
                              </script>
                              <table width="650" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td valign="top" width="100">
                                          <span class="fBlack10100">非参加者：</span>
                                        </td>
                                        <td width="200">
                                          <select name="division" onChange="changeSelectMem(document.schedule_date_frm)">
<?php $JavaScriptSelect_DivEmpScheduleMember->printDefaultMainOption(); ?>
                                          </select><br>
<?php
if($JavaScriptSelect_DivEmpScheduleMember->getSelectedSubElementIndex() == 0){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="group_member1[]" size="5" multiple <?php echo $selectStyle; ?>>
<?php $JavaScriptSelect_DivEmpScheduleMember->printDefaultSubOption(); ?>
                                          </select>
                                        </td>
                                        <td valign="middle" width="50">
                                          <input type="button" name="cmdAddMenber" value="   追加 →" onClick="cmdAddMembers(1)">

                                          <input type="button" name="cmdAddMenber" value="← 削除   " onClick="cmdAddMembers(2)">
                                        </td>
                                        <td valign="top" width="100">
                                          <span class="fBlack10100">召集者：</span>
                                        </td>
                                        <td width="200">
<?php
$tmpMemberInfoArray = $this->scheduleEventInfo->getScheduleMemberInfoArray();
if(count($tmpMemberInfoArray) == 0){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="group_member2[]" multiple size="5" <?php echo $selectStyle; ?>>
<?php
if(count($tmpMemberInfoArray) != 0){
	foreach($tmpMemberInfoArray as $key => $tmpMemberInfo){
		if($tmpMemberInfo->getEnable() == "1"){
			echo "<option value=\"" . htmlSpecialEscape($tmpMemberInfo->getEmp_cd()) . "\">" . htmlSpecialEscape($tmpMemberInfo->getName()) . "</option>\n";
		}
	}
}
?>
                                          </select>
                                          <input type="hidden" name="memberOperate">
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                              <script language="JavaScript">
                              <!--
<?php
		if(count($JavaScriptSelect_DivEmpScheduleMember->getSubElementArray()) >= 1){
?>
                                initSelectMem(document.schedule_date_frm);
<?php
		}
?>
                              //-->
                              </script>
                              
                            </td>
                          </tr>

                          <tr>
                            <td colspan="2">
                            <?php /*
                              <img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="10" alt="">
							*/ ?>
                            </td>
                          </tr>
<?php
  }

  /**
   *メンバーを編集する画面を表示する
   *@param String division 部門情報
   */
  function  printUpdateMember() {
	require_once("./gw.php");
?>


                          <tr>
                            <td colspan="2" align="center">
                              <script language="JavaScript">
                              <!--
<?php

        require_once($_ROOT_URL_ . "class/javascriptselect_div_emp_schedule_member.php");

        $JavaScriptSelect_DivEmpScheduleMember = $this->scheduleEventInfo->getJavaScriptSelect_DivEmpScheduleMember();
		if(count($JavaScriptSelect_DivEmpScheduleMember->getSubElementArray()) >= 1){
	        $JavaScriptSelect_DivEmpScheduleMember->printInitSelectFunction();
	        $JavaScriptSelect_DivEmpScheduleMember->printChangeSelectFunction();
		}
?>
                              function cmdAddMembers(numOperation){
                                document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                                document.schedule_date_frm.memberOperate.value = numOperation;
                                document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
                                document.schedule_date_frm.submit();
                              }
                              //-->
                              </script>
                              <table width="650" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td valign="top" width="100" rowspan="3">
                                          <span class="fBlack10100">非参加者：</span>
                                        </td>
                                        <td width="200" rowspan="3">
                                          <select name="division" onChange="changeSelectMem(document.schedule_date_frm)">
<?php $JavaScriptSelect_DivEmpScheduleMember->printDefaultMainOption(); ?>
                                          </select><br>
<?php
if($JavaScriptSelect_DivEmpScheduleMember->getSelectedSubElementIndex() == 0){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="group_member1[]" size="5" multiple <?php echo $selectStyle; ?>>
<?php $JavaScriptSelect_DivEmpScheduleMember->printDefaultSubOption(); ?>
                                          </select>
                                        </td>
                                        <td valign="middle" width="50">
                                          <input type="button" name="cmdAddMenber" value="   追加 →" onClick="cmdAddMembers(1)">

                                          <input type="button" name="cmdAddMenber" value="← 削除   " onClick="cmdAddMembers(2)">
                                        </td>
                                        <td valign="top" width="100">
                                          <span class="fBlack10100">参加者：</span>
                                        </td>
                                        <td width="200">
<?php
$tmpMemberInfoArray = $this->scheduleEventInfo->getScheduleMemberInfoArray();
if(count($tmpMemberInfoArray) == 0){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="group_member2[]" multiple size="5" <?php echo $selectStyle; ?>>
<?php
if(count($tmpMemberInfoArray) != 0){
	foreach($tmpMemberInfoArray as $key => $tmpMemberInfo){
		if($tmpMemberInfo->getEnable() == "1"){
			echo "<option value=\"" . htmlSpecialEscape($tmpMemberInfo->getEmp_cd()) . "\">" . htmlSpecialEscape($tmpMemberInfo->getName()) . "</option>\n";
		}
	}
}
?>
                                          </select>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td valign="middle" width="50">
                                          <input type="button" name="cmdAddMenber" value="   追加 →" onClick="cmdAddMembers(3)">

                                          <input type="button" name="cmdAddMenber" value="← 削除   " onClick="cmdAddMembers(4)">
                                        </td>
                                        <td valign="top" width="100">
                                          <span class="fBlack10100">未回答者：</span>
                                        </td>
                                        <td width="200">
<?php
$tmpMemberInfoArray = $this->scheduleEventInfo->getScheduleMemberInfoArray();
if(count($tmpMemberInfoArray) == 0){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="group_member3[]" multiple size="5" <?php echo $selectStyle; ?>>
<?php
if(count($tmpMemberInfoArray) != 0){
	foreach($tmpMemberInfoArray as $key => $tmpMemberInfo){
		if($tmpMemberInfo->getEnable() == "2"){
			echo "<option value=\"" . htmlSpecialEscape($tmpMemberInfo->getEmp_cd()) . "\">" . htmlSpecialEscape($tmpMemberInfo->getName()) . "</option>\n";
		}
	}
}
?>
                                          </select>
                                          <input type="hidden" name="memberOperate">
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                              <script language="JavaScript">
                              <!--
<?php
		if(count($JavaScriptSelect_DivEmpScheduleMember->getSubElementArray()) >= 1){
?>
                                initSelectMem(document.schedule_date_frm);
<?php
		}
?>
                              //-->
                              </script>
                              
                            </td>
                          </tr>

                          <tr>
                            <td colspan="2">
                            <?php /*
                              <img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="10" alt="">
							*/ ?>
                            </td>
                          </tr>

<?php
  }

  /**
   *メンバーを参照する画面を表示する
   */
  function  printDetailMember() {
  }

  /**
   *オプションを入力する画面を表示する
   */
  function  printInsertOption() {
        require_once("./gw.php");

        switch($this->scheduleEventInfo->getEvent_mode()){
        case 0: 
?>
                          <tr>
                            <td colspan="2" align="center">
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            公開/非公開：
                                          </span>
                                        </td>
                                        <td width="150">
                                          <span class="fBlack10100">
                                            <input type="radio" name="public" value="t" checked>
                                            公開
                                            <input type="radio" name="public" value="f" <?php echo $this->scheduleEventInfo->isPublic() == "f" ?  "checked" : ""; ?>>
                                            非公開
                                          </span>
                                            &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
                                         <td width="100">
                                          <span class="fBlack10100">
                                            社外/社内: 
                                          </span>
                                        </td>
                                        <td width="300">
                                          <span class="fBlack10100">
                                            <input type="radio" name="outdoor" value="t" <?php echo $this->scheduleEventInfo->isOutdoor() == "t" ?  "checked" : ""; ?>>
                                            社外
                                            <input type="radio" name="outdoor" value="f" <?php echo $this->scheduleEventInfo->isOutdoor() != "t" ?  "checked" : ""; ?>>
                                            社内
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php
                break;
        case 1:
?>
                          <tr>
                            <td colspan="2" align="center">
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            公開/非公開：
                                          </span>
                                        </td>
                                        <td width="150">
                                          <span class="fBlack10100">
                                            <input type="radio" name="public" value="t" checked>
                                            公開
                                            <input type="radio" name="public" value="f" <?php echo $this->scheduleEventInfo->isPublic() == "f" ?  "checked" : ""; ?>>
                                            非公開
                                          </span>
                                            &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
                                         <td width="100">
                                          <span class="fBlack10100">
                                            社外/社内: 
                                          </span>
                                        </td>
                                        <td width="300">
                                          <span class="fBlack10100">
                                            <input type="radio" name="outdoor" value="t" <?php echo $this->scheduleEventInfo->isOutdoor() == "t" ?  "checked" : ""; ?>>
                                            社外
                                            <input type="radio" name="outdoor" value="f" <?php echo $this->scheduleEventInfo->isOutdoor() != "t" ?  "checked" : ""; ?>>
                                            社内
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php
                break;
        
        case 2:
?>
                          <tr>
                            <td colspan="2" align="center">
			                  <input type="hidden" name="public" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->isPublic()) ?>">
			                  <input type="hidden" name="outdoor" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->isOutdoor()) ?>">
                            </td>
                          </tr>

<?php
                break;
        case 3:
?>
                          <tr>
                            <td colspan="2" align="center">
			                  <input type="hidden" name="public" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->isPublic()) ?>">
			                  <input type="hidden" name="outdoor" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->isOutdoor()) ?>">
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
<?php
				if($this->getDate_mode() == "0"){
?>                                          
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            通知：
                                          </span>
                                        </td>
                                        <td width="550">
											<script language="JavaScript">
											<!--
											var strSelectValue = <?php echo $this->scheduleEventInfo->getCompulsion() != "" ?  $this->scheduleEventInfo->getCompulsion() : 1; ?>;
											function SetValue(objRadio)
											{
												strSelectValue = objRadio.value;
											}
											-->
											</script>
                                          <span class="fBlack10100">
                                            <input type="radio" name="compulsion" value="1" checked onClick="SetValue(this)">
                                            出欠を取る
                                            <input type="radio" name="compulsion" value="2" <?php echo $this->scheduleEventInfo->getCompulsion() == "2" ?  "checked" : ""; ?> onClick="SetValue(this)">
                                            通知する
                                            <input type="radio" name="compulsion" value="3" <?php echo $this->scheduleEventInfo->getCompulsion() == "3" ?  "checked" : ""; ?> onClick="SetValue(this)">
                                            通知しない
                                          </span>
                                        </td>
<?php
				}
				else{
?>				
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            通知：
                                          </span>
                                        </td>
                                        <td width="550">
											<script language="JavaScript">
											<!--
											var strSelectValue = <?php echo $this->scheduleEventInfo->getCompulsion() != "" ?  $this->scheduleEventInfo->getCompulsion() : 2; ?>;
											function SetValue(objRadio)
											{
												strSelectValue = objRadio.value;
											}
											-->
											</script>
                                          <span class="fBlack10100">
                                            <input type="radio" name="compulsion" value="2" checked onClick="SetValue(this)">
                                            通知する
                                            <input type="radio" name="compulsion" value="3" <?php echo $this->scheduleEventInfo->getCompulsion() == "3" ?  "checked" : ""; ?> onClick="SetValue(this)">
                                            通知しない
                                          </span>
                                        </td>
<?php
				}
?>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php
                break;
        case 4:
?>
                          <tr>
                            <td colspan="2" align="center">
			                  <input type="hidden" name="public" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->isPublic()) ?>">
			                  <input type="hidden" name="outdoor" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->isOutdoor()) ?>">
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
<?php
				if($this->getDate_mode() == "0"){
?>                                          
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            通知：
                                          </span>
                                        </td>
                                        <td width="550">
 											<script language="JavaScript">
											<!--
											var strSelectValue = <?php echo $this->scheduleEventInfo->getCompulsion() != "" ?  $this->scheduleEventInfo->getCompulsion() : 1; ?>;
											function SetValue(objRadio)
											{
												strSelectValue = objRadio.value;
											}
											-->
											</script>
                                          <span class="fBlack10100">
                                            <input type="radio" name="compulsion" value="1" checked onClick="SetValue(this)">
                                            出欠を取る
                                            <input type="radio" name="compulsion" value="2" <?php echo $this->scheduleEventInfo->getCompulsion() == "2" ?  "checked" : ""; ?> onClick="SetValue(this)">
                                            通知する
                                            <input type="radio" name="compulsion" value="3" <?php echo $this->scheduleEventInfo->getCompulsion() == "3" ?  "checked" : ""; ?> onClick="SetValue(this)">
                                            通知しない
                                          </span>
                                        </td>
<?php
				}
				else{
?>				
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            通知：
                                          </span>
                                        </td>
                                        <td width="550">
											<script language="JavaScript">
											<!--
											var strSelectValue = <?php echo $this->scheduleEventInfo->getCompulsion() != "" ?  $this->scheduleEventInfo->getCompulsion() : 2; ?>;
											function SetValue(objRadio)
											{
												strSelectValue = objRadio.value;
											}
											-->
											</script>
                                          <span class="fBlack10100">
                                            <input type="radio" name="compulsion" value="2" checked onClick="SetValue(this)">
                                            通知する
                                            <input type="radio" name="compulsion" value="3" <?php echo $this->scheduleEventInfo->getCompulsion() == "3" ?  "checked" : ""; ?> onClick="SetValue(this)">
                                            通知しない
                                          </span>
                                        </td>
<?php
				}
?>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php
                break;
        default:
?>
                          <tr>
                            <td colspan="2" align="center">
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            公開/非公開：
                                          </span>
                                        </td>
                                        <td width="150">
                                          <span class="fBlack10100">
                                            <input type="radio" name="public" value="t" checked>
                                            公開
                                            <input type="radio" name="public" value="f" <?php echo $this->scheduleEventInfo->isPublic() == "f" ?  "checked" : ""; ?>>
                                            非公開
                                          </span>
                                            &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
                                         <td width="100">
                                          <span class="fBlack10100">
                                            社外/社内: 
                                          </span>
                                        </td>
                                        <td width="300">
                                          <span class="fBlack10100">
                                            <input type="radio" name="outdoor" value="t" <?php echo $this->scheduleEventInfo->isOutdoor() == "t" ?  "checked" : ""; ?>>
                                            社外
                                            <input type="radio" name="outdoor" value="f" <?php echo $this->scheduleEventInfo->isOutdoor() != "t" ?  "checked" : ""; ?>>
                                            社内
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php
                break;
        }
  }

  /**
   *オプションを参照する画面を表示する
   */
  function  printDetailOption() {
  }

  /**
   *スケジュール登録画面を表示する
   */
  function  printScheduleInsert() {
  }

  /**
   *繰り返しスケジュール画面を表示する
   */
  function  printScheduleDetail() {
  }

  /**
   *スケジュール更新画面を表示する
   */
  function  printScheduleUpdate() {
  }
  
  /**
   * ボタン表示
   */
  function printButton(){
        switch($this->scheduleEventInfo->getEvent_mode()){
        case 1:
?>
                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
					  objFrm.sub.value = "登録";
					  objFrm.submit();
                    }

                    function nextSubmit(numOperation)
                    {
                      document.schedule_date_frm.event_mode.value = numOperation;
                      switch(numOperation)
                      {
                        case 2:
                          document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                        case 3:
                          document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                      }
                    }
                  -->
                  </script>
                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                      			<input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getEvent_mode()) ?>">
                                <input type="button" name="subBtn" value="登録" onClick="frmSubmit(document.schedule_date_frm)">
                      </td>
                      <td align="right">
                                <input type="button" name="nextButton" value="施設予約" onClick="nextSubmit(2)">
                                <input type="button" name="nextButton" value="メンバー登録" onClick="nextSubmit(3)">
                      </td>
                    </tr>
                  </table>
<?php
          break;
          
        case 2:
?>

                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
					  objFrm.sub.value = "登録";
					  objFrm.submit();
                    }

                    function nextSubmit(numOperation)
                    {
                      document.schedule_date_frm.event_mode.value = numOperation;
                      switch(numOperation)
                      {
                        case 4:
                          document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                      }
                    }
                  -->
                  </script>
                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                      			<input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getEvent_mode()) ?>">
                                <input type="button" name="subBtn" value="登録" onClick="frmSubmit(document.schedule_date_frm)">
                      </td>
                      <td align="right">
                                <input type="button" name="nextButton" value="メンバー登録" onClick="nextSubmit(4)">
                      </td>
                    </tr>
                  </table>

<?php
          break;
        case 3:
?>
                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
					  if(strSelectValue == 1 || strSelectValue == 2){
						  if(objFrm.elements['group_member2[]'].length == 0){
						  	
						  	alert("メンバーがいないので通知ができません");
						  	return false;
						  }
					  }
					  objFrm.sub.value = "登録";
					  objFrm.submit();
                    }
					  
                    function nextSubmit(numOperation)
                    {
                      document.schedule_date_frm.event_mode.value = numOperation;
                      switch(numOperation)
                      {
                        case 4:
                          document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                      }
                    }
                  -->
                  </script>
                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                      			<input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getEvent_mode()) ?>">
                                <input type="button" name="subBtn" value="登録" onClick="frmSubmit(document.schedule_date_frm)">
                      </td>
                      <td align="right">
                                <input type="button" name="nextButton" value="施設予約" onClick="nextSubmit(4)">
                      </td>
                    </tr>
                  </table>
<?php
          break;
        case 4:
?>               
                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
					  if(strSelectValue == 1 || strSelectValue == 2){
						  if(objFrm.elements['group_member2[]'].length == 0){
						  	
						  	alert("メンバーがいないので通知ができません");
						  	return false;
						  }
					  }
					  objFrm.sub.value = "登録";
					  objFrm.submit();
                    }
                  -->
                  </script>
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                      			<input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getEvent_mode()) ?>">
                                <input type="button" name="subBtn" value="登録" onClick="frmSubmit(document.schedule_date_frm)">
                      </td>
                    </tr>
                  </table>
<?php
          break;
        default:
?>
                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
					  objFrm.sub.value = "登録";
					  objFrm.submit();
                    }

                    function nextSubmit(numOperation)
                    {
                      document.schedule_date_frm.event_mode.value = numOperation;
                      switch(numOperation)
                      {
                        case 2:
                          document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                        case 3:
                          document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                      }
                    }
                  -->
                  </script>
                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                      			<input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="1">
                                <input type="button" name="subBtn" value="登録" onClick="frmSubmit(document.schedule_date_frm)">
                      </td>
                      <td align="right">
                                <input type="button" name="nextButton" value="施設予約" onClick="nextSubmit(2)">
                                <input type="button" name="nextButton" value="メンバー登録" onClick="nextSubmit(3)">
                      </td>
                    </tr>
                  </table>
<?php
      break;
        }
  }
  
  /**
   * Selectボックスを作成する
   * @param strObjName  Select 属性の Name プロパティ
   * @param strDefaultValue  デフォルト値 0以上
   * @param intInterval 各Option Value の増分値
   * @param intMinValue Option Value の最小値
   * @param intMaxValue Option Value の最大値
   * @param flgNoSelect Optionに「--」を表示するか
   **/
  function printSelect($strObjName, $strDefaultValue, $intInterval, $intMinValue, $intMaxValue, $flgNoSelect)
  {
?>
                                                                        <select name="<?php echo $strObjName ?>">
<?php
	if($flgNoSelect){
?>
                                                                          <option value="" <?php echo ($strDefaultValue == "" ? "selected" : "") ?>>--</option>
<?php
	}
?>

<?php
    for($i = $intMinValue; $i <= $intMaxValue; $i += $intInterval)
    {
    	$tmpI = substr("0" . $i, -1*(strlen($intMaxValue)));
?>
                                                                          <option value="<?php echo $tmpI ?>" <?php echo ($tmpI == $strDefaultValue) ? "selected" : "" ?>><?php echo $tmpI ?></option>
<?php
    }
?>
                                                                        </select>
<?php
  }

}

?>