<?php
/**
 *イベント管理表示用クラス
 *
 * @author hideki HARANAKA <hideki-h@syscon.co.jp>
 */
class ScheduleUpdateEventView {

  /**
   *クラス名称
   */
  var $classname = "ScheduleEventView";

  /**
   *イベントの状態を表すフラグ<br>
   *
   *<ol>
   *<li>自分のスケジュールのみ登録</li>
   *<li>自分のスケジュールと施設予約</li>
   *<li>自分のスケジュールとメンバーのスケジュール</li>
   *<li>自分のスケジュールと施設予約・メンバーのスケジュール</li>
   *</ol>
   */
  var $event_mode;

  /**
   * 日付の登録モード
   *
   * @param int date_mode <ul>
   * <li>0：日にち指定</li>
   * <li>1：曜日指定</li>
   * <li>2：週指定</li>
   * <li>3：月日指定</li>
   * <li>4：期間指定</li>
   * </ul>
   */
  var $date_mode;

  /**
   * 日付情報クラス
   * @see DateInfo
   */
  var $dateInfo;

  /**
   *イベント管理クラス
   *
   *@see ScheduleEventInfo
   */
  var  $scheduleEventInfo;
  
  /**
   * <ul>
   * 	<li>addScreen スケジュール登録</li>
   * 	<li>updateScreen 更新画面</li>
   * 	<li>updateDetailScreen 詳細画面</li>
   * </ul>
   */
  var $subScreenMode;
  
  /**
   * 
   */
  var $originScreenMode;

  /**
   * 呼び出し元のページ
   */
  var $refPage;
  
  /**
   * 参照配列番号
   */
  var $arrayIndexN;
  
  /**
   * 呼び出しもとのアプリケーション
   */
  var $refApplication;

  /**
   * 指定スケジュールの最大日付コード
   */
  var $maxScheduleDateCd;
  
  /**
   * イベントに日付が一日しか含まれないかどうか
   */
  var $bolOneDayInSchedule;
  
  /**
   *コンストラクタ
   */
  function  ScheduleUpdateEventView() {
  }

  /**
   * $maxScheduleDateCd 設定
   */
  function setMaxScheduleDateCd($maxScheduleDateCd){
	$this->maxScheduleDateCd = $maxScheduleDateCd;
  }
  
  /**
   * $maxScheduleDateCd 取得
   */
  function getMaxScheduleDateCd(){
	return $this->maxScheduleDateCd;
  }

  /**
   * refPage 設定
   */
  function setRefPage($refPage){
  	$this->refPage = $refPage;
  	switch($refPage){
  		case "scdlMonth":
  		case "scdlWeek":
  		case "scdlDay":
  			$this->refApplication = "schedule2.php";
  			break;
  		default:
  			$this->refApplication = "reserve.php";  		
  	}
  }
  
  /**
   * 参照配列番号設定
   */
  function setArrayIndexN($arrayIndexN){
	$this->arrayIndexN = $arrayIndexN;
  }
  
  /**
   * ScreenModeを設定する
   */
  function setSubScreenMode($subScreenMode){
  	$this->originScreenMode = $subScreenMode;
  	if($subScreenMode == "updateScreen"){
  		$subScreenMode = "updateScreen2";
  	}
  	if($subScreenMode == "addScheduleScreen"){
  		$subScreenMode = "addScheduleScreen2";
  	}
  	$this->subScreenMode = $subScreenMode;
  }
   
  /**
   *イベントモードを取得する
   */
  function  getEvent_mode() {
    return $this->event_mode;
  }

  /**
   *イベントモードを設定する
   */
  function  setEvent_mode( $event_mode) {
    $this->event_mode = $event_mode;
  }

  /**
   * 日付の登録モード
   *
   * @param int date_mode <ul>
   * <li>0：日にち指定</li>
   * <li>1：曜日指定</li>
   * <li>2：週指定</li>
   * <li>3：月日指定</li>
   * <li>4：期間指定</li>
   * </ul>
   */
  function setDate_mode($date_mode){
    $this->date_mode = $date_mode;
  }

  /**
   * 日付の登録モード
   *
   * @return int date_mode <ul>
   * <li>0：日にち指定</li>
   * <li>1：曜日指定</li>
   * <li>2：週指定</li>
   * <li>3：月日指定</li>
   * <li>4：期間指定</li>
   * </ul>
   */
  function getDate_mode(){
    return $this->date_mode;
  }

  /**
   * 日付情報クラス設定
   * @param DateInfo dateInfo 日付情報クラスインスタンス
   */
  function setDateInfo($dateInfo){
    $this->dateInfo = $dateInfo;
  }

  function setScheduleEventInfo($scheduleEventInfo){
        $this->scheduleEventInfo = $scheduleEventInfo;
//      print_r($this->scheduleEventInfo);
  }
  
  function setBolOneDayInSchedule($bolOneDayInSchedule){
	$this->bolOneDayInSchedule = $bolOneDayInSchedule;
  }

  function  printEventView() {
    require_once("./gw.php");
	if($this->refApplication == "schedule2.php"){
?>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr> 
                  <td valign="bottom"> <a href="<?php echo $this->refApplication . "?sub=monthScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_month_b.gif" width="240" height="29" alt="月で表示" border="0"></a></td>
                  <td valign="bottom"> 
                    <div align="center"><a href="<?php echo $this->refApplication . "?sub=weekScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_week_b.gif" width="240" height="29" alt="週で表示" border="0"></a></div>
                  </td>
                  <td valign="bottom"> 
                    <div align="right"><a href="<?php echo $this->refApplication . "?sub=dayScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_day_b.gif" width="240" height="29" alt="日で表示" border="0"></a></div>
                  </td>
                </tr>
              </table>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr>
                  <td valign="bottom" align="center" width="350"><a href="<?php echo $this->refApplication ?>?sub=updateScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&n=<?php echo $this->arrayIndexN ?>&refPage=<?php echo $this->refPage ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_a.gif" width="370" height="29" alt="スケジュール" border="0"></a></td>
                  <td valign="buttom" align="center" width="60">&nbsp;</td>
                  <td valign="bottom" align="center" width="350"><a href="<?php echo $this->refApplication ?>?sub=updateDetailScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&n=<?php echo $this->arrayIndexN ?>&refPage=<?php echo $this->refPage ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_group_b.gif" width="370" height="29" alt="スケジュールグループ" border="0"></a></td>
                </tr>
              </table>
            </td>
          </tr>
<?php
	}
	else{

?>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr>
                  <td valign="bottom" align="center" width="350"><a href="<?php echo $this->refApplication ?>?sub=updateScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&schedule_cd=<?php echo $this->scheduleEventInfo->getSchedule_cd() ?>&schedule_date_cd=<?php echo $this->scheduleEventInfo->getScheduleDate_cd() ?>&refPage=<?php echo $this->refPage ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_a.gif" width="370" height="29" alt="スケジュール" border="0"></a></td>
                  <td valign="buttom" align="center" width="60">&nbsp;</td>
                  <td valign="bottom" align="center" width="350"><a href="<?php echo $this->refApplication ?>?sub=updateDetailScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&schedule_cd=<?php echo $this->scheduleEventInfo->getSchedule_cd() ?>&schedule_date_cd=<?php echo $this->scheduleEventInfo->getScheduleDate_cd() ?>&refPage=<?php echo $this->refPage ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_group_b.gif" width="370" height="29" alt="スケジュールグループ" border="0"></a></td>
                </tr>
              </table>
            </td>
          </tr>
<?php
	}
?>
          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="15" alt=""></td>
            <td class="yellow">　</td>
            <td class="yellow">　</td>
          </tr>

          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="5" alt=""></td>
            <td></td>
            <td></td>
          </tr>

          <tr> 
            <td>　</td>
            <td colspan="2">
                <form name="schedule_date_frm" method="post" action="<?php echo $_ROOT_URL_ . $this->refApplication ?>">
                  <INPUT TYPE="hidden" NAME="trans_id" VALUE="<? echo mt_rand(); ?>">
                  <input type="hidden" name="emp_cd" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getOwner_emp_cd()) ?>">
				  <input type="hidden" name="n" value="<?php echo htmlSpecialEscape($this->arrayIndexN) ?>">
				  <input type="hidden" name="refPage" value="<?php echo htmlSpecialEscape($this->refPage) ?>">
				  <input type="hidden" name="originScreenMode" value="<?php echo htmlSpecialEscape($this->originScreenMode) ?>">
                  <!-- ↓スケジュール入力テーブル -->
                  <table border="0" cellspacing="3" cellpadding="0">
                    <tr>
                      <td>
                        <span class="fBlack10150"><b>■スケジュール編集</b></span>
                      </td>
                    </tr>

<?php
$this->printUpdateDate();

$this->printInsertNaiyou();

if($this->scheduleEventInfo->getEvent_mode() == "2" or $this->scheduleEventInfo->getEvent_mode() == "4"){
        $this->printInsertFacility();
}
if($this->scheduleEventInfo->getEvent_mode() == "3" or $this->scheduleEventInfo->getEvent_mode() == "4"){
        $this->printInsertMember();
}

$this->printInsertOption();
?>


                  </table>
                  <!-- ↑スケジュール入力テーブル -->
                  <img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="10" alt=""><br>

<?php
$this->printButton();
?>

                </form>
              </td>
            </tr>
<?php
  }

  function  printAddEventView() {
    require_once("./gw.php");
	if($this->refApplication == "schedule2.php"){
?>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr> 
                  <td valign="bottom"> <a href="<?php echo $this->refApplication . "?sub=monthScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_month_b.gif" width="240" height="29" alt="月で表示" border="0"></a></td>
                  <td valign="bottom"> 
                    <div align="center"><a href="<?php echo $this->refApplication . "?sub=weekScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_week_b.gif" width="240" height="29" alt="週で表示" border="0"></a></div>
                  </td>
                  <td valign="bottom"> 
                    <div align="right"><a href="<?php echo $this->refApplication . "?sub=dayScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_day_b.gif" width="240" height="29" alt="日で表示" border="0"></a></div>
                  </td>
                </tr>
              </table>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr>
                  <td valign="bottom" align="center" width="350"><a href="<?php echo $this->refApplication ?>?sub=updateScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&n=<?php echo $this->arrayIndexN ?>&refPage=<?php echo $this->refPage ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_a.gif" width="370" height="29" alt="スケジュール" border="0"></a></td>
                  <td valign="buttom" align="center" width="60">&nbsp;</td>
                  <td valign="bottom" align="center" width="350"><div align="right"><a href="<?php echo $this->refApplication ?>?sub=updateDetailScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&n=<?php echo $this->arrayIndexN ?>&refPage=<?php echo $this->refPage ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_group_b.gif" width="370" height="29" alt="スケジュールグループ" border="0"></a></div>
                  </td>
                </tr>
              </table>
            </td>
          </tr>
<?php
	}
	else{

?>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr>
                  <td valign="bottom" align="center" width="350"><a href="<?php echo $this->refApplication ?>?sub=updateScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&schedule_cd=<?php echo $this->scheduleEventInfo->getSchedule_cd() ?>&schedule_date_cd=<?php echo $this->scheduleEventInfo->getScheduleDate_cd() ?>&refPage=<?php echo $this->refPage ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_a.gif" width="370" height="29" alt="スケジュール" border="0"></a></td>
                  <td valign="buttom" align="center" width="60">&nbsp;</td>
                  <td valign="bottom" align="center" width="350"><div align="right"><a href="<?php echo $this->refApplication ?>?sub=updateDetailScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&schedule_cd=<?php echo $this->scheduleEventInfo->getSchedule_cd() ?>&schedule_date_cd=<?php echo $this->scheduleEventInfo->getScheduleDate_cd() ?>&refPage=<?php echo $this->refPage ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_group_b.gif" width="370" height="29" alt="スケジュールグループ" border="0"></a></div></td>
                </tr>
              </table>
            </td>
          </tr>
<?php
	}
?>
          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="15" alt=""></td>
            <td class="yellow">　</td>
            <td class="yellow">　</td>
          </tr>

          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="5" alt=""></td>
            <td></td>
            <td></td>
          </tr>

          <tr> 
            <td>　</td>
            <td colspan="2">
                <form name="schedule_date_frm" method="post" action="<?php echo $_ROOT_URL_ . $this->refApplication ?>">
				  <input type="hidden" name="schedule_cd" value="<? echo $this->scheduleEventInfo->getSchedule_cd() ?>">
				  <Input type="hidden" name="maxScheduleDateCd" value="<?php echo $this->getMaxScheduleDateCd() ?>">
                  <INPUT TYPE="hidden" NAME="trans_id" VALUE="<? echo mt_rand(); ?>">
                  <input type="hidden" name="emp_cd" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getOwner_emp_cd()) ?>">
				  <input type="hidden" name="n" value="<?php echo htmlSpecialEscape($this->arrayIndexN) ?>">
				  <input type="hidden" name="refPage" value="<?php echo htmlSpecialEscape($this->refPage) ?>">
				  <input type="hidden" name="originScreenMode" value="<?php echo htmlSpecialEscape($this->originScreenMode) ?>">
                  <!-- ↓スケジュール入力テーブル -->
                  <table border="0" cellspacing="3" cellpadding="0">
                    <tr>
                      <td>
                        <span class="fBlack10150"><b>■スケジュール編集</b></span>
                      </td>
                    </tr>

<?php
$this->printInsertDate();

$this->printInsertNaiyou();

if($this->scheduleEventInfo->getEvent_mode() == "2" or $this->scheduleEventInfo->getEvent_mode() == "4"){
        $this->printInsertFacility();
}
if($this->scheduleEventInfo->getEvent_mode() == "3" or $this->scheduleEventInfo->getEvent_mode() == "4"){
        $this->printInsertMember();
}

$this->printInsertOption();
?>


                  </table>
                  <!-- ↑スケジュール入力テーブル -->
                  <img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="10" alt=""><br>

<?php
$this->printAddScheduleButton();
?>

                </form>
              </td>
            </tr>
<?php
  }

  function  printNonPermitEventView() {
    require_once("./gw.php");
	if($this->refApplication == "schedule2.php"){
?>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr> 
                  <td valign="bottom"> <a href="<?php echo $this->refApplication . "?sub=monthScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_month_b.gif" width="240" height="29" alt="月で表示" border="0"></a></td>
                  <td valign="bottom"> 
                    <div align="center"><a href="<?php echo $this->refApplication . "?sub=weekScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_week_b.gif" width="240" height="29" alt="週で表示" border="0"></a></div>
                  </td>
                  <td valign="bottom"> 
                    <div align="right"><a href="<?php echo $this->refApplication . "?sub=dayScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_day_b.gif" width="240" height="29" alt="日で表示" border="0"></a></div>
                  </td>
                </tr>
              </table>
            </td>
          </tr>
          <tr>
            <td></td>
            <td colspan="2" valign="top">
		  </tr>
          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="15" alt=""></td>
            <td class="yellow">　</td>
            <td class="yellow">　</td>
          </tr>
<?php
	}

?>

          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="5" alt=""></td>
            <td></td>
            <td></td>
          </tr>

          <tr> 
            <td>　</td>
            <td colspan="2">
                <form name="schedule_date_frm" method="post" action="<?php echo $_ROOT_URL_ . $this->refApplication ?>">
                  <INPUT TYPE="hidden" NAME="trans_id" VALUE="<? echo mt_rand(); ?>">
                  <input type="hidden" name="emp_cd" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getOwner_emp_cd()) ?>">
				  <input type="hidden" name="n" value="<?php echo htmlSpecialEscape($this->arrayIndexN) ?>">
				  <input type="hidden" name="refPage" value="<?php echo htmlSpecialEscape($this->refPage) ?>">
				  <input type="hidden" name="originScreenMode" value="<?php echo htmlSpecialEscape($this->originScreenMode) ?>">
                  <!-- ↓スケジュール入力テーブル -->
                  <table border="0" cellspacing="3" cellpadding="0">
                    <tr>
                      <td>
                        <span class="fBlack10150"><b>■スケジュール編集</b></span>
                      </td>
                    </tr>

<?php
$this->printDetailDate();

$this->printDetailNaiyou();

if($this->scheduleEventInfo->getEvent_mode() == "2" or $this->scheduleEventInfo->getEvent_mode() == "4"){
        $this->printDetailFacility();
}
if($this->scheduleEventInfo->getEvent_mode() == "3" or $this->scheduleEventInfo->getEvent_mode() == "4"){
        $this->printDetailMember();
}
?>


                  </table>
                  <!-- ↑スケジュール入力テーブル -->
                  <img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="10" alt=""><br>

                </form>
              </td>
            </tr>
<?php
  }

  function  printNonPermitUpdateDetailScreen() {
    require_once("./gw.php");

	if($this->refApplication == "schedule2.php"){
?>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr> 
                  <td valign="bottom"> <a href="<?php echo $this->refApplication . "?sub=monthScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_month_b.gif" width="240" height="29" alt="月で表示" border="0"></a></td>
                  <td valign="bottom"> 
                    <div align="center"><a href="<?php echo $this->refApplication . "?sub=weekScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_week_b.gif" width="240" height="29" alt="週で表示" border="0"></a></div>
                  </td>
                  <td valign="bottom"> 
                    <div align="right"><a href="<?php echo $this->refApplication . "?sub=dayScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_day_b.gif" width="240" height="29" alt="日で表示" border="0"></a></div>
                  </td>
                </tr>
              </table>
            </td>
          </tr>
          <tr>
            <td></td>
            <td colspan="2" valign="top">
<?php
	}

?>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr>
                  <td valign="bottom" bgcolor="FF9900" align="center" width="350">
                              <a href="<?php echo $this->refApplication ?>?sub=updateScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&n=<?php echo $this->arrayIndexN ?>&refPage=<?php echo $this->refPage ?>">
                                      スケジュール
                              </a>
                      </td>
                      <td valign="buttom" bgcolor="FF9900" align="center" width="60">&nbsp;</td>
                  <td valign="bottom" bgcolor="FFCD35" align="center" width="350">
                    <a href="<?php echo $this->refApplication ?>?sub=updateDetailScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&n=<?php echo $this->arrayIndexN ?>&refPage=<?php echo $this->refPage ?>">
                                繰り返しスケジュール
                        </a>
                  </td>
                </tr>
              </table>
            </td>
          </tr>
          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="15" alt=""></td>
            <td class="yellow">　</td>
            <td class="yellow">　</td>
          </tr>

          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="5" alt=""></td>
            <td></td>
            <td></td>
          </tr>

          <tr> 
            <td>　</td>
            <td colspan="2">
			  <div class="fRed10100">参照権限がありません</div>
            </td>
          </tr>
<?php
  }

  /**
   * 編集画面を表示する(スケジュール)
   */
  function printUpdateDetailScreen(){
    require_once("./gw.php");

	if($this->refApplication == "schedule2.php"){
?>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr> 
                  <td valign="bottom"> <a href="<?php echo $this->refApplication . "?sub=monthScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_month_b.gif" width="240" height="29" alt="月で表示" border="0"></a></td>
                  <td valign="bottom"> 
                    <div align="center"><a href="<?php echo $this->refApplication . "?sub=weekScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_week_b.gif" width="240" height="29" alt="週で表示" border="0"></a></div>
                  </td>
                  <td valign="bottom"> 
                    <div align="right"><a href="<?php echo $this->refApplication . "?sub=dayScreen&year=" . $this->dateInfo->getStartYear() . "&month=" . $this->dateInfo->getStartMonth() . "&day=" . $this->dateInfo->getStartDay() ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_day_b.gif" width="240" height="29" alt="日で表示" border="0"></a></div>
                  </td>
                </tr>
              </table>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr>
                  <td valign="bottom" align="center" width="350"><a href="<?php echo $this->refApplication ?>?sub=updateScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&n=<?php echo $this->arrayIndexN ?>&refPage=<?php echo $this->refPage ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_b.gif" width="370" height="29" alt="スケジュール" border="0"></a></td>
                  <td valign="buttom" align="center" width="60">&nbsp;</td>
                  <td valign="bottom" align="center" width="350"><a href="<?php echo $this->refApplication ?>?sub=updateDetailScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&n=<?php echo $this->arrayIndexN ?>&refPage=<?php echo $this->refPage ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_group_a.gif" width="370" height="29" alt="スケジュールグループ" border="0"></a></td>
                </tr>
              </table>
            </td>
          </tr>
<?php
	}
	else{
?>
              <table width="760" border="0" cellspacing="0" cellpadding="0">
                <tr>
                  <td valign="bottom" align="center" width="350"><a href="<?php echo $this->refApplication ?>?sub=updateScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&schedule_cd=<?php echo $this->scheduleEventInfo->getSchedule_cd() ?>&schedule_date_cd=<?php echo $this->scheduleEventInfo->getScheduleDate_cd() ?>&refPage=<?php echo $this->refPage ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_b.gif" width="370" height="29" alt="スケジュール" border="0"></a></td>
                  <td valign="buttom" align="center" width="60">&nbsp;</td>
                  <td valign="bottom" align="center" width="350"><a href="<?php echo $this->refApplication ?>?sub=updateDetailScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&schedule_cd=<?php echo $this->scheduleEventInfo->getSchedule_cd() ?>&schedule_date_cd=<?php echo $this->scheduleEventInfo->getScheduleDate_cd() ?>&refPage=<?php echo $this->refPage ?>"><img src="<?php echo $_ROOT_URL_ ?>images/schedule_group_a.gif" width="370" height="29" alt="スケジュールグループ" border="0"></a></td>
                </tr>
              </table>
            </td>
          </tr>
<?php
	}
?>
          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="15" alt=""></td>
            <td class="yellow">　</td>
            <td class="yellow">　</td>
          </tr>

          <tr> 
            <td><img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="5" alt=""></td>
            <td></td>
            <td></td>
          </tr>

          <tr> 
            <td>　</td>
            <td colspan="2">
                <form name="schedule_date_frm" method="post" action="<?php echo $_ROOT_URL_ . $this->refApplication ?>">
                  <INPUT TYPE="hidden" NAME="trans_id" VALUE="<? echo mt_rand(); ?>">
                  <input type="hidden" name="emp_cd" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getOwner_emp_cd()) ?>">
				  <input type="hidden" name="schedule_cd" value="<?php echo $this->scheduleEventInfo->getSchedule_cd() ?>">
				  <input type="hidden" name="schedule_date_cd" value="<?php echo $this->scheduleEventInfo->getScheduleDate_cd() ?>">
				  <input type="hidden" name="public" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->isPublic()) ?>">
				  <input type="hidden" name="originScreenMode" value="<?php echo htmlSpecialEscape($this->originScreenMode) ?>">

                  <!-- ↓スケジュール入力テーブル -->
                  <table border="0" cellspacing="3" cellpadding="0">
                    <tr>
                      <td>
                        <span class="fBlack10150"><b>■スケジュール登録</b></span>
                      </td>
                    </tr>

<?php

$this->printUpdateDetailNaiyou();

$this->printScheduleDateArray();

?>


                  </table>
                  <!-- ↑スケジュール入力テーブル -->
                  <img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="10" alt=""><br>
<?php
$this->printDetailButton();
?>

                </form>
              </td>
            </tr>
<?php
  }
  /**
   *日付を入力する画面を表示する
   */
  function  printInsertDate() {
        require_once("./gw.php");

	if($this->subScreenMode != "addScreen"){
?>
                          <tr>
                            <td align="left">
                              <span class="fBlack10100"><b>日時：</b></span>
                            </td>
                            <td align="right">
                            </td>
                          </tr>
<?php
	}
?>
                          <tr>
                            <td colspan="2">
                      <script language="JavaScript">
                    <!--
                      function setTable()
                      {
                        document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                        document.schedule_date_frm.action = "<?php echo $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
                        document.schedule_date_frm.submit();
                      }
                    -->
                  </script>
                              <select name="date_mode" onChange="setTable()">
                                <option <?php echo $this->getDate_mode() == "0" ? "selected" : "" ?> value="0">当日のみ</option>
                                <option <?php echo $this->getDate_mode() == "1" ? "selected" : "" ?> value="1">曜日指定</option>
                                <option <?php echo $this->getDate_mode() == "2" ? "selected" : "" ?> value="2">週指定</option>
                                <option <?php echo $this->getDate_mode() == "3" ? "selected" : "" ?> value="3">日にち指定</option>
                                <option <?php echo $this->getDate_mode() == "4" ? "selected" : "" ?> value="4">期間指定</option>
                              </select>
                            </td>
                          </tr>
                          <tr>
                            <td colspan="2" align="center">
<?php
    switch($this->getDate_mode()){
    case 0:
?>
                              <table id="tbl1" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">日付：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日

<?php $this->printSelect("hour_s", $this->dateInfo->getStartHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_s", $this->dateInfo->getStartMinute(), 10, 0, 50,true); ?>分
〜
<?php $this->printSelect("hour_e", $this->dateInfo->getEndHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_e", $this->dateInfo->getEndMinute(), 10, 0, 50,true); ?>分
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>


<?php
        break;
    case 1:
?>
                              <table id="tbl2" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">日付：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日
〜
                                            <input type="text" name="year_e" size="4" maxlength="4" value="<?php echo $this->dateInfo->getEndYear() ?>">年
<?php $this->printSelect("month_e", $this->dateInfo->getEndMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("e");
$this->printSelect("day_e", $this->dateInfo->getEndDay(), 1, 1, 31,true); 
?>日
                                          </span>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">時間：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
<?php $this->printSelect("hour_s", $this->dateInfo->getStartHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_s", $this->dateInfo->getStartMinute(), 10, 0, 50,true); ?>分
〜
<?php $this->printSelect("hour_e", $this->dateInfo->getEndHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_e", $this->dateInfo->getEndMinute(), 10, 0, 50,true); ?>分
                                          </span>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100" valign="top">
                                          <span class="fBlack10100">曜日：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
<?php 
$arrWkCheckbox = array();
$arrWkCheckbox = $this->dateInfo->getWeek_day();
$flgCheck = array(0=>false, 1=>false, 2=>false, 3=>false, 4=>false, 5=>false, 6=>false );
if(is_array($arrWkCheckbox)){
	foreach($arrWkCheckbox as $key => $value){
		$flgCheck[$value] = true;
	}
}
?>
                                            <input type="checkbox" name="week_day[]" value="1" <?php echo ($flgCheck[1] ? "checked" : ""); ?>>月
                                            <input type="checkbox" name="week_day[]" value="2" <?php echo ($flgCheck[2] ? "checked" : ""); ?>>火
                                            <input type="checkbox" name="week_day[]" value="3" <?php echo ($flgCheck[3] ? "checked" : ""); ?>>水
                                            <input type="checkbox" name="week_day[]" value="4" <?php echo ($flgCheck[4] ? "checked" : ""); ?>>木
                                            <input type="checkbox" name="week_day[]" value="5" <?php echo ($flgCheck[5] ? "checked" : ""); ?>>金
                                            <input type="checkbox" name="week_day[]" value="6" <?php echo ($flgCheck[6] ? "checked" : ""); ?>>土
                                            <input type="checkbox" name="week_day[]" value="0" <?php echo ($flgCheck[0] ? "checked" : ""); ?>>日
                                            <br>
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>

<?php
        break;
    case 2:
?>
                              <table id="tbl3" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">日付：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日
〜
                                            <input type="text" name="year_e" size="4" maxlength="4" value="<?php echo $this->dateInfo->getEndYear() ?>">年
<?php $this->printSelect("month_e", $this->dateInfo->getEndMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("e");
$this->printSelect("day_e", $this->dateInfo->getEndDay(), 1, 1, 31,true); 
?>日
                                          </span>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">時間：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
<?php $this->printSelect("hour_s", $this->dateInfo->getStartHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_s", $this->dateInfo->getStartMinute(), 10, 0, 50,true); ?>分
〜
<?php $this->printSelect("hour_e", $this->dateInfo->getEndHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_e", $this->dateInfo->getEndMinute(), 10, 0, 50,true); ?>分
                                          </span>
                                        </td>
                                      </tr>

                                      <tr>
                                        <td width="100" valign="top">
                                          <span class="fBlack10100">週指定：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
<?php 
$arrWkCheckbox = array();
$arrWkCheckbox = $this->dateInfo->getMonth_of_week();
$flgCheck = array(0=>false, 1=>false, 2=>false, 3=>false, 4=>false, 5=>false, 6=>false );
if(is_array($arrWkCheckbox)){
	foreach($arrWkCheckbox as $key => $value){
		$flgCheck[$value] = true;
	}
}
?>
                                            <input type="checkbox" name="month_of_week[]" value="1" <?php echo ($flgCheck[1] ? "checked" : ""); ?>>第１
                                            <input type="checkbox" name="month_of_week[]" value="2" <?php echo ($flgCheck[2] ? "checked" : ""); ?>>第２
                                            <input type="checkbox" name="month_of_week[]" value="3" <?php echo ($flgCheck[3] ? "checked" : ""); ?>>第３
                                            <input type="checkbox" name="month_of_week[]" value="4" <?php echo ($flgCheck[4] ? "checked" : ""); ?>>第４
                                            <input type="checkbox" name="month_of_week[]" value="5" <?php echo ($flgCheck[5] ? "checked" : ""); ?>>第５
                                            <input type="checkbox" name="month_of_week[]" value="6" <?php echo ($flgCheck[6] ? "checked" : ""); ?>>最終
 <?php
$arrWkCheckbox = array();
$arrWkCheckbox = $this->dateInfo->getWeek_day();
$flgCheck = array(0=>false, 1=>false, 2=>false, 3=>false, 4=>false, 5=>false, 6=>false );
if(is_array($arrWkCheckbox)){
	foreach($arrWkCheckbox as $key => $value){
		$flgCheck[$value] = true;
	}
}
?>
                                            <select name="week_day[]">
                                              <option value="1" <?php echo ($flgCheck[1] ? "selected" : ""); ?>>月</option>
                                              <option value="2" <?php echo ($flgCheck[2] ? "selected" : ""); ?>>火</option>
                                              <option value="3" <?php echo ($flgCheck[3] ? "selected" : ""); ?>>水</option>
                                              <option value="4" <?php echo ($flgCheck[4] ? "selected" : ""); ?>>木</option>
                                              <option value="5" <?php echo ($flgCheck[5] ? "selected" : ""); ?>>金</option>
                                              <option value="6" <?php echo ($flgCheck[6] ? "selected" : ""); ?>>土</option>
                                              <option value="0" <?php echo ($flgCheck[0] ? "selected" : ""); ?>>日</option>
                                            </select>曜日
                                          </span>
                                        </td>
                                      </tr>

                                    </table>
                                  </td>
                                </tr>
                              </table>

<?php
        break;
    case 3:
?>
                              <table id="tbl4" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                       <td width="100">
                                          <span class="fBlack10100">日付：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日
〜
                                            <input type="text" name="year_e" size="4" maxlength="4" value="<?php echo $this->dateInfo->getEndYear() ?>">年
<?php $this->printSelect("month_e", $this->dateInfo->getEndMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("e");
$this->printSelect("day_e", $this->dateInfo->getEndDay(), 1, 1, 31,true); 
?>日
                                          </span>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">時間：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
<?php $this->printSelect("hour_s", $this->dateInfo->getStartHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_s", $this->dateInfo->getStartMinute(), 10, 0, 50,true); ?>分
〜
<?php $this->printSelect("hour_e", $this->dateInfo->getEndHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_e", $this->dateInfo->getEndMinute(), 10, 0, 50,true); ?>分
                                          </span>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100" valign="top">
                                          <span class="fBlack10100">日にち指定：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">毎月
<?php $this->printSelect("month_of_day", $this->dateInfo->getMonth_of_day(), 1, 1, 31,false); ?>日
                                           </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>

<?php
        break;
    case 4:
?>
                              <table id="tbl4" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">日付範囲：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日
〜
                                            <input type="text" name="year_e" size="4" maxlength="4" value="<?php echo $this->dateInfo->getEndYear() ?>">年
<?php $this->printSelect("month_e", $this->dateInfo->getEndMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("e");
$this->printSelect("day_e", $this->dateInfo->getEndDay(), 1, 1, 31,true); 
?>日
                                          </span>
                                        </td>
                                      </tr>

                                    </table>
                                  </td>
                                </tr>
                              </table>

<?php
        break;
    default:
?>
                              <table id="tbl1" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">日付：</span>
                                        </td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日

<?php $this->printSelect("hour_s", $this->dateInfo->getStartHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_s", $this->dateInfo->getStartMinute(), 10, 0, 50,true); ?>分
〜
<?php $this->printSelect("hour_e", $this->dateInfo->getEndHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_e", $this->dateInfo->getEndMinute(), 10, 0, 50,true); ?>分
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>


<?php
    }
    
?>

                            </td>
                          </tr>

<?php
  }
  /**
   *日付を入力する画面を表示する
   */
  function  printUpdateDate() {
?>
                          <tr>
                            <td align="center">

                              <table width="650" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100" valign="top"> <span class="fBlack10100">選択日時：</span></td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <?php 
                                            $arr_schedule_date = array();
                                            $arr_schedule_date  = $this->dateInfo->getScheduleDateArray();
	                                        if(count($arr_schedule_date) == 1){
												//print_r($arr_schedule_date);
												echo $arr_schedule_date[count($arr_schedule_date)-1]['year'] ."年" .
												$arr_schedule_date[count($arr_schedule_date)-1]['month'] ."月" .
												$arr_schedule_date[count($arr_schedule_date)-1]['day'] ."日";
												if($arr_schedule_date[count($arr_schedule_date)-1]['hour_s'] != ""){
													echo $arr_schedule_date[count($arr_schedule_date)-1]['hour_s'] ."時" .
														  $arr_schedule_date[count($arr_schedule_date)-1]['minute_s'] . "分";
													if($arr_schedule_date[count($arr_schedule_date)-1]['hour_e'] != ""){
														echo "〜" .
														$arr_schedule_date[count($arr_schedule_date)-1]['hour_e'] . "時" .
														$arr_schedule_date[count($arr_schedule_date)-1]['minute_e'] . "分";
													}
												}
	                                            echo "<input type=\"hidden\" name=\"schedule_date_cd_array[0]\" value=\"" . $arr_schedule_date[count($arr_schedule_date)-1]['schedule_date_cd'] . "\">";
	                                            /* 
												echo $this->dateInfo->getStartYear() ."年" . 
	                                            		$this->dateInfo->getStartMonth() . "月" . 
	                                            		$this->dateInfo->getStartDay() . "日" . 
	                                            		$this->dateInfo->getStartHour() . "時" .
	                                            		$this->dateInfo->getStartMinute() . "分〜" .
	                                            		$this->dateInfo->getEndHour() . "時" .
	                                            		$this->dateInfo->getEndMinute() . "分<br>";
	                                             */	                                            		
                                            ?>
                                            <br>
                                            <input type="text" name="year_s" size="4" maxlength="4" value="<?php echo $this->dateInfo->getStartYear() ?>">年
<?php $this->printSelect("month_s", $this->dateInfo->getStartMonth(), 1, 1, 12,true); ?>月
<?php 
$tmpLastMonth = $this->dateInfo->getLastMonth("s");
$this->printSelect("day_s", $this->dateInfo->getStartDay(), 1, 1, 31,true); 
?>日

<?php $this->printSelect("hour_s", $this->dateInfo->getStartHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_s", $this->dateInfo->getStartMinute(), 10, 0, 50,true); ?>分
〜
<?php $this->printSelect("hour_e", $this->dateInfo->getEndHour(), 1, 0, 23,true); ?>時
<?php $this->printSelect("minute_e", $this->dateInfo->getEndMinute(), 10, 0, 50,true); ?>分
											<?php
                                            }
                                            else{
                                            	echo "<select name=\"schedule_date_cd_array_dammy\" size=\"8\" multiple>\n";
                                            	foreach($arr_schedule_date as $key => $value){
		                                            echo "<option value=\"" . $value['schedule_date_cd'] . "\">" . 
		                                            $value['year'] ."年" . $value['month'] ."月" . $value['day'] ."日";
		                                            if($value['hour_s'] != ""){
														echo $value['hour_s'] ."時" . $value['minute_s'] . "分";
														if($value['hour_e'] != ""){
															echo "〜" .
																  $value['hour_e'] . "時" . $value['minute_e'] . "分";
														}
		                                            }
		                                            echo "</option>\n";
                                            	}
												echo "</select>\n";
                                            	foreach($arr_schedule_date as $key => $value){
		                                            echo "<input type=\"hidden\" name=\"schedule_date_cd_array[]\" value=\"" . $value['schedule_date_cd'] . "\">";
                                            	}
                                            }
											echo "<input type=\"hidden\" name=\"schedule_cd\" value=\"" . $this->scheduleEventInfo->getSchedule_cd() . "\">";
											?>
                                          </span>

                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php
  }

  /**
   *日付を表示する画面を表示する
   */
  function  printDetailDate() {
?>
                          <tr>
                            <td align="center">

                              <table width="650" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100" valign="top"> <span class="fBlack10100">選択日時：</span></td>
                                        <td width="550">
                                          <span class="fBlack10100">
                                            <?php 
                                            $arr_schedule_date = array();
                                            $arr_schedule_date  = $this->dateInfo->getScheduleDateArray();
                                            if(count($arr_schedule_date) == 1){
												//print_r($arr_schedule_date);
												echo $arr_schedule_date[count($arr_schedule_date)-1]['year'] ."年" .
												$arr_schedule_date[count($arr_schedule_date)-1]['month'] ."月" .
												$arr_schedule_date[count($arr_schedule_date)-1]['day'] ."日" .
												$arr_schedule_date[count($arr_schedule_date)-1]['hour_s'] ."時" .
												$arr_schedule_date[count($arr_schedule_date)-1]['minute_s'] . "分〜" .
												$arr_schedule_date[count($arr_schedule_date)-1]['hour_e'] . "時" .
												$arr_schedule_date[count($arr_schedule_date)-1]['minute_e'] . "分<br>\n";
                                            }
                                            ?>
                                          </span>

                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php
  }

  /**
   *内容を入力する画面を表示する
   */
  function  printInsertNaiyou() {
?>
                          <tr>
                            <td colspan="2" align="center">
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100" valign="top"> <span class="fBlack10100">予定：</span></td>
                                        <td width="550">
                                        <?php
                                        if($this->bolOneDayInSchedule){
                                        ?>
                                          <textarea name="plan" cols="64" rows="3" wrap="VIRTUAL"><?php echo htmlSpecialEscape(stripslashes($this->scheduleEventInfo->getPlan())) ?></textarea>
                                        <?php
                                        }
                                        else{
                                        ?>
                                          <input type="hidden" name="plan" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getPlan()) ?>"?>
                                          <span class="fBlack10100">
                                          <?php echo nl2br(htmlSpecialEscape($this->scheduleEventInfo->getPlan())) ?>
                                          </span>
                                        <?php
                                        }
                                        ?>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100" valign="top"> <span class="fBlack10100">備考：</span></td>
                                        <td width="550">
                                          <textarea name="remark" cols="64" rows="3" wrap="VIRTUAL"><?php echo htmlSpecialEscape(stripslashes($this->scheduleEventInfo->getRemark())) ?></textarea>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php  	
  }

  /**
   *内容を入力する画面を表示する
   */
  function  printDetailNaiyou() {
?>
                          <tr>
                            <td colspan="2" align="center">
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100" valign="top"> <span class="fBlack10100">予定：</span></td>
                                        <td width="550">
                                          <div class="fBlack10100">
                                          <?php echo nl2br(htmlSpecialEscape($this->scheduleEventInfo->getPlan())) ?>
                                          </div>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100" valign="top"> <span class="fBlack10100">備考：</span></td>
                                        <td width="550">
                                          <div class="fBlack10100">
                                          <?php echo htmlSpecialEscape($this->scheduleEventInfo->getRemark()) ?>
                                          </div>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php  	
  }
  
  /**
   *繰り返しスケジュールの詳細内容を表示する
   */
  function  printUpdateDetailNaiyou() {
?>
                          <tr>
                            <td colspan="2" align="center">
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100" valign="top"> <span class="fBlack10100">予定：</span></td>
                                        <td width="550">
                                          <textarea name="plan" cols="64" rows="3" wrap="VIRTUAL"><?php echo htmlSpecialEscape(stripslashes($this->scheduleEventInfo->getPlan())) ?></textarea>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td width="100" valign="top"> <span class="fBlack10100">ログ：</span></td>
                                        <td width="550">
                                          <textarea name="remark" cols="64" rows="3" wrap="VIRTUAL"><?php echo htmlSpecialEscape(stripslashes($this->scheduleEventInfo->getRemark())) ?></textarea>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

                          <tr>
                            <td colspan="2">
                              <img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="10" alt="">
                            </td>
                          </tr>
                          <tr>
                            <td colspan="2">
                             <script language="JavaScript">
			                  <!--
			                    function updateSubmit()
			                    {
		                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=updateDetailScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&n=<?php echo $this->arrayIndexN ?>&refPage=<?php echo $this->refPage ?>";
		                          document.schedule_date_frm.sub.value = "updateDetailScreen";
		                          document.schedule_date_frm.bolscheduleUpdateCmd.value = "update";		                         
		                          document.schedule_date_frm.submit();
			                    }
			                  -->
			                  </script>
			                  <input type="hidden" name="bolscheduleUpdateCmd" value="">
			                  <input type="button" name="scheduleUpdateCmd" value="更新" onClick="updateSubmit()">
                            </td>
                          </tr>
                          <tr>
                            <td colspan="2">
                              <img src="<?php echo $_ROOT_URL_ ?>images/spazio.gif" width="1" height="10" alt="">
                            </td>
                          </tr>

<?php  	
  }

  /**
   *施設を登録する画面を表示する
   */
  function  printInsertFacility() {
  	require_once("./gw.php");
?>

                          <tr>
                            <td colspan="2" align="center">
                             <script language="JavaScript">
                              <!--
<?php

        require_once($_ROOT_URL_ . "class/javascriptselect_cat_fac_schedule_facility.php");

        $JavaScriptSelect_CatFacScheduleFacility = $this->scheduleEventInfo->getJavaScriptSelect_CatFacScheduleFacility();
		if(count($JavaScriptSelect_CatFacScheduleFacility->getMainElementArray()) >= 1){
	        $JavaScriptSelect_CatFacScheduleFacility->printInitSelectFunction();
		    $JavaScriptSelect_CatFacScheduleFacility->printChangeSelectFunction();
		}
?>
                              function cmdAddFacilities(numOperation){
                                document.schedule_date_frm.facilityOperate.value = numOperation;
                                document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
							    document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                                document.schedule_date_frm.submit();
                              }
                              //-->
                              </script>
                              <table width="650" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td valign="top" width="100">
                                          <span class="fBlack10100">施設：</span>
                                        </td>
                                        <td width="200">
                                          <select name="fac_cat_cd" onChange="changeSelectFac(document.schedule_date_frm)">
<?php $JavaScriptSelect_CatFacScheduleFacility->printDefaultMainOption(); ?>
                                          </select><br>
<?php
if($JavaScriptSelect_CatFacScheduleFacility->getSelectedSubElementIndex() == 0){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="facilities1[]" size="5" multiple <?php echo $selectStyle; ?>>
<?php $JavaScriptSelect_CatFacScheduleFacility->printDefaultSubOption(); ?>
                                          </select>
                                        </td>
                                        <td valign="middle" width="50">
                                          <input type="button" name="cmdAddFacility" value="   追加 →" onClick="cmdAddFacilities(1)">

                                          <input type="button" name="cmdAddFacility" value="← 削除   " onClick="cmdAddFacilities(2)">
                                        </td>
                                        <td valign="top" width="100">
                                          <span class="fBlack10100">予約施設：</span>
                                        </td>
                                        <td width="200">
<?php
$tmpFacilityInfoArray = $this->scheduleEventInfo->getScheduleFacilityInfoArray();
if(count($tmpFacilityInfoArray) == 0){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="facilities2[]" multiple size="5" <?php echo $selectStyle; ?>>
<?php
if(count($tmpFacilityInfoArray) != 0){
	foreach($tmpFacilityInfoArray as $key => $tmpFacilityInfo){
		echo "<option value=\"" . $tmpFacilityInfo->getFac_cd() . "\">" . htmlSpecialEscape($tmpFacilityInfo->getFac_name()) . "</option>\n";
	}
}
?>
                                          </select>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                              <input type="hidden" name="facilityOperate">
                              <script language="JavaScript">
                              <!--
<?php
		if(count($JavaScriptSelect_CatFacScheduleFacility->getMainElementArray()) >= 1){
?>
                                initSelectFac(document.schedule_date_frm);
<?php
		}
?>
                              //-->
                              </script>
                            </td>
                          </tr>

<?php
  }
  
  /**
   *施設を登録する画面を表示する
   */
  function  printDetailFacility() {
  	require_once("./gw.php");
?>

                          <tr>
                            <td colspan="2" align="center">
                              <table width="650" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td valign="top" width="100">
                                          <span class="fBlack10100">予約施設：</span>
                                        </td>
                                        <td align="left" width="550">
<?php
$tmpFacilityInfoArray = $this->scheduleEventInfo->getScheduleFacilityInfoArray();
if(count($tmpFacilityInfoArray) == 0){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="facilities2[]" multiple size="5" <?php echo $selectStyle; ?>>
<?php
if(count($tmpFacilityInfoArray) != 0){
	foreach($tmpFacilityInfoArray as $key => $tmpFacilityInfo){
		echo "<option value=\"" . $tmpFacilityInfo->getFac_cd() . "\">" . htmlSpecialEscape($tmpFacilityInfo->getFac_name()) . "</option>\n";
	}
}
?>
                                          </select>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                              <input type="hidden" name="facilityOperate">
                            </td>
                          </tr>
<?php
  }

  /**
   *メンバーを登録する画面を表示する
   *@param String division 部門情報
   */
  function  printInsertMember() {
	require_once("./gw.php");
?>


                          <tr>
                            <td colspan="2" align="center">
                              <script language="JavaScript">
                              <!--
<?php

        require_once($_ROOT_URL_ . "class/javascriptselect_div_emp_schedule_member.php");

        $JavaScriptSelect_DivEmpScheduleMember = $this->scheduleEventInfo->getJavaScriptSelect_DivEmpScheduleMember();
		if(count($JavaScriptSelect_DivEmpScheduleMember->getSubElementArray()) >= 1){
	        $JavaScriptSelect_DivEmpScheduleMember->printInitSelectFunction();
	        $JavaScriptSelect_DivEmpScheduleMember->printChangeSelectFunction();
		}
?>
                              function cmdAddMembers(numOperation){
                                document.schedule_date_frm.memberOperate.value = numOperation;
                                document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  		document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                                document.schedule_date_frm.submit();
                              }
                              //-->
                              </script>
                              <table width="650" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td valign="top" width="100" rowspan="3">
                                          <span class="fBlack10100">非参加者：</span>
                                        </td>
                                        <td width="200" rowspan="3">
                                          <select name="division" onChange="changeSelectMem(document.schedule_date_frm)">
<?php $JavaScriptSelect_DivEmpScheduleMember->printDefaultMainOption(); ?>
                                          </select><br>
<?php
if($JavaScriptSelect_DivEmpScheduleMember->getSelectedSubElementIndex() == 0){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="group_member1[]" size="5" multiple <?php echo $selectStyle; ?>>
<?php $JavaScriptSelect_DivEmpScheduleMember->printDefaultSubOption(); ?>
                                          </select>
                                        </td>
                                        <td valign="middle" width="50">
                                          <input type="button" name="cmdAddMenber" value="   追加 →" onClick="cmdAddMembers(1)">

                                          <input type="button" name="cmdAddMenber" value="← 削除   " onClick="cmdAddMembers(2)">
                                        </td>
                                        <td valign="top" width="100">
                                          <span class="fBlack10100">参加者：</span>
                                        </td>
                                        <td width="200">
<?php
$tmpMemberInfoArray = $this->scheduleEventInfo->getScheduleMemberInfoArray();
$strOptionString = "";
if(count($tmpMemberInfoArray) != 0){
	foreach($tmpMemberInfoArray as $key => $tmpMemberInfo){
		if($tmpMemberInfo->getEnable() == "1"){
			$strOptionString .= "<option value=\"" . htmlSpecialEscape($tmpMemberInfo->getEmp_cd()) . "\">" . htmlSpecialEscape($tmpMemberInfo->getName()) . "</option>\n";
		}
	}
}
if($strOptionString == ""){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="group_member2[]" multiple size="5" <?php echo $selectStyle; ?>>
											<?php echo $strOptionString; ?>
                                          </select>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td valign="middle" colspan="3">
                                        	<div align="center">
	                                          <input type="button" name="cmdAddMenber" value="   追加 ↑" onClick="cmdAddMembers(3)">
	                                          <input type="button" name="cmdAddMenber" value="↓ 削除   " onClick="cmdAddMembers(4)">
											</div>
                                        </td>
                                      </tr>
                                      <tr>
                                        <td valign="middle" width="50">
                                          <input type="button" name="cmdAddMenber" value="   追加 →" onClick="cmdAddMembers(5)">

                                          <input type="button" name="cmdAddMenber" value="← 削除   " onClick="cmdAddMembers(6)">
                                        </td>
                                        <td valign="top" width="100">
                                          <span class="fBlack10100">未回答者：</span>
                                        </td>
                                        <td width="200">
<?php
$tmpMemberInfoArray = $this->scheduleEventInfo->getScheduleMemberInfoArray();
$strOptionString = "";
if(count($tmpMemberInfoArray) != 0){
	foreach($tmpMemberInfoArray as $key => $tmpMemberInfo){
		if($tmpMemberInfo->getEnable() == "2"){
			$strOptionString .= "<option value=\"" . htmlSpecialEscape($tmpMemberInfo->getEmp_cd()) . "\">" . htmlSpecialEscape($tmpMemberInfo->getName()) . "</option>\n";
		}
	}
}
if($strOptionString == ""){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="group_member3[]" multiple size="5" <?php echo $selectStyle; ?>>
											<?php echo $strOptionString; ?>
                                          </select>
                                          <input type="hidden" name="memberOperate">
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                              <script language="JavaScript">
                              <!--
<?php
		if(count($JavaScriptSelect_DivEmpScheduleMember->getSubElementArray()) >= 1){
?>
                                initSelectMem(document.schedule_date_frm);
<?php
		}
?>
                              //-->
                              </script>
                              
                            </td>
                          </tr>

<?php
  }

  /**
   *メンバーを登録する画面を表示する
   *@param String division 部門情報
   */
  function  printDetailMember() {
	require_once("./gw.php");
?>


                          <tr>
                            <td colspan="2" align="center">

                              <table width="650" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td valign="top" width="100">
                                          <span class="fBlack10100">参加者：</span>
                                        </td>
                                        <td align="left" width="550">
<?php
$tmpMemberInfoArray = $this->scheduleEventInfo->getScheduleMemberInfoArray();
$strOptionString = "";
if(count($tmpMemberInfoArray) != 0){
	foreach($tmpMemberInfoArray as $key => $tmpMemberInfo){
		if($tmpMemberInfo->getEnable() == "1"){
			$strOptionString .= "<option value=\"" . $tmpMemberInfo->getEmp_cd() . "\">" . htmlSpecialEscape($tmpMemberInfo->getName()) . "</option>\n";
		}
	}
}
if($strOptionString == ""){
	$selectStyle = "style=\"width: 10em;\"";
}
else{
	$selectStyle = "";
}
?>
                                          <select name="group_member2[]" multiple size="5" <?php echo $selectStyle; ?>>
											<?php echo $strOptionString; ?>
                                          </select>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>                              
                            </td>
                          </tr>


<?php
  }

  /**
   *オプションを入力する画面を表示する
   */
  function  printInsertOption() {
        require_once("./gw.php");

////		echo $this->scheduleEventInfo->getEvent_mode() . "<br>\n";

        switch($this->scheduleEventInfo->getEvent_mode()){
        case 0: 
?>
                          <tr>
                            <td colspan="2" align="center">
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            公開/非公開：
                                          </span>
                                        </td>
                                        <td width="150">
                                          <span class="fBlack10100">
                                            <input type="radio" name="public" value="t" checked>
                                            公開
                                            <input type="radio" name="public" value="f" <?php echo $this->scheduleEventInfo->isPublic() == "f" ?  "checked" : ""; ?>>
                                            非公開
                                          </span>
                                            &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
                                         <td width="100">
                                          <span class="fBlack10100">
                                            社外/社内: 
                                          </span>
                                        </td>
                                        <td width="300">
                                          <span class="fBlack10100">
                                            <input type="radio" name="outdoor" value="t" <?php echo $this->scheduleEventInfo->isOutdoor() == "t" ?  "checked" : ""; ?>>
                                            社外
                                            <input type="radio" name="outdoor" value="f" <?php echo $this->scheduleEventInfo->isOutdoor() != "t" ?  "checked" : ""; ?>>
                                            社内
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php
                break;
        case 1:
?>
                          <tr>
                            <td colspan="2" align="center">
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            公開/非公開：
                                          </span>
                                        </td>
                                        <td width="150">
                                          <span class="fBlack10100">
                                            <input type="radio" name="public" value="t" checked>
                                            公開
                                            <input type="radio" name="public" value="f" <?php echo $this->scheduleEventInfo->isPublic() == "f" ?  "checked" : ""; ?>>
                                            非公開
                                          </span>
                                            &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
                                         </td>
                                         <td width="100">
                                          <span class="fBlack10100">
                                            社外/社内: 
                                          </span>
                                        </td>
                                        <td width="300">
                                          <span class="fBlack10100">
                                            <input type="radio" name="outdoor" value="t" <?php echo $this->scheduleEventInfo->isOutdoor() == "t" ?  "checked" : ""; ?>>
                                            社外
                                            <input type="radio" name="outdoor" value="f" <?php echo $this->scheduleEventInfo->isOutdoor() != "t" ?  "checked" : ""; ?>>
                                            社内
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php
                break;
        
        case 2:
?>
                          <tr>
                            <td colspan="2" align="center">
	                            <input type="hidden" name="public" value="t" checked>
                            </td>
                          </tr>

<?php
                break;
        case 3:
?>
                          <tr>
                            <td colspan="2" align="center">
	                          <input type="hidden" name="public" value="t" checked>
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
<?php
				if($this->getDate_mode() == "0"){
?>                                          
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            通知：
                                          </span>
                                        </td>
                                        <td width="300">
											<script language="JavaScript">
											<!--
											var strSelectValue = <?php echo $this->scheduleEventInfo->getCompulsion() != "" ?  $this->scheduleEventInfo->getCompulsion() : 1; ?>;
											function SetValue(objRadio)
											{
												strSelectValue = objRadio.value;
											}
											-->
											</script>
                                          <span class="fBlack10100">
                                            <input type="radio" name="compulsion" value="1" checked onClick="SetValue(this)">
                                            出欠を取る
                                            <input type="radio" name="compulsion" value="2" <?php echo $this->scheduleEventInfo->getCompulsion() == "2" ?  "checked" : ""; ?> onClick="SetValue(this)">
                                            通知する
                                            <input type="radio" name="compulsion" value="3" <?php echo $this->scheduleEventInfo->getCompulsion() == "3" ?  "checked" : ""; ?> onClick="SetValue(this)">
                                            通知しない
                                          </span>
                                        </td>
                                         <td width="100">
                                          <span class="fBlack10100">
                                            社外/社内: 
                                          </span>
                                        </td>
                                        <td width="150">
                                          <span class="fBlack10100">
                                            <input type="radio" name="outdoor" value="t" <?php echo $this->scheduleEventInfo->isOutdoor() == "t" ?  "checked" : ""; ?>>
                                            社外
                                            <input type="radio" name="outdoor" value="f" <?php echo $this->scheduleEventInfo->isOutdoor() != "t" ?  "checked" : ""; ?>>
                                            社内
                                          </span>
                                        </td>
<?php
				}
				else{
?>				
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            通知：
                                          </span>
                                        </td>
                                        <td width="200">
											<script language="JavaScript">
											<!--
											var strSelectValue = <?php echo $this->scheduleEventInfo->getCompulsion() != "" ?  $this->scheduleEventInfo->getCompulsion() : 2; ?>;
											function SetValue(objRadio)
											{
												strSelectValue = objRadio.value;
											}
											-->
											</script>
                                          <span class="fBlack10100">
                                            <input type="radio" name="compulsion" value="2" checked onClick="SetValue(this)">
                                            通知する
                                            <input type="radio" name="compulsion" value="3" <?php echo $this->scheduleEventInfo->getCompulsion() == "3" ?  "checked" : ""; ?> onClick="SetValue(this)">
                                            通知しない
                                          </span>
                                        </td>
                                         <td width="100">
                                          <span class="fBlack10100">
                                            社外/社内: 
                                          </span>
                                        </td>
                                        <td width="150">
                                          <span class="fBlack10100">
                                            <input type="radio" name="outdoor" value="t" <?php echo $this->scheduleEventInfo->isOutdoor() == "t" ?  "checked" : ""; ?>>
                                            社外
                                            <input type="radio" name="outdoor" value="f" <?php echo $this->scheduleEventInfo->isOutdoor() != "t" ?  "checked" : ""; ?>>
                                            社内
                                          </span>
                                        </td>
<?php
				}
?>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php
                break;
        case 4:
?>
                          <tr>
                            <td colspan="2" align="center">
	                          <input type="hidden" name="public" value="t" checked>
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
<?php
				if($this->getDate_mode() == "0"){
?>                                          
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            通知：
                                          </span>
                                        </td>
                                        <td width="200">
                                          <span class="fBlack10100">
											<script language="JavaScript">
											<!--
											var strSelectValue = <?php echo $this->scheduleEventInfo->getCompulsion() != "" ?  $this->scheduleEventInfo->getCompulsion() : 1; ?>;
											function SetValue(objRadio)
											{
												strSelectValue = objRadio.value;
											}
											-->
											</script>
                                            <input type="radio" name="compulsion" value="1" checked onClick="SetValue(this)">
                                            出欠を取る
                                            <input type="radio" name="compulsion" value="2" <?php echo $this->scheduleEventInfo->getCompulsion() == "2" ?  "checked" : ""; ?> onClick="SetValue(this)">
                                            通知する
                                            <input type="radio" name="compulsion" value="3" <?php echo $this->scheduleEventInfo->getCompulsion() == "3" ?  "checked" : ""; ?> onClick="SetValue(this)">
                                            通知しない
                                          </span>
                                        </td>
                                         <td width="100">
                                          <span class="fBlack10100">
                                            社外/社内: 
                                          </span>
                                        </td>
                                        <td width="150">
                                          <span class="fBlack10100">
                                            <input type="radio" name="outdoor" value="t" <?php echo $this->scheduleEventInfo->isOutdoor() == "t" ?  "checked" : ""; ?>>
                                            社外
                                            <input type="radio" name="outdoor" value="f" <?php echo $this->scheduleEventInfo->isOutdoor() != "t" ?  "checked" : ""; ?>>
                                            社内
                                          </span>
                                        </td>
<?php
				}
				else{
?>				
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            通知：
                                          </span>
                                        </td>
                                        <td width="250">
                                          <span class="fBlack10100">
											<script language="JavaScript">
											<!--
											var strSelectValue = <?php echo $this->scheduleEventInfo->getCompulsion() != "" ?  $this->scheduleEventInfo->getCompulsion() : 2; ?>;
											function SetValue(objRadio)
											{
												strSelectValue = objRadio.value;
											}
											-->
											</script>
                                            <input type="radio" name="compulsion" value="2" checked onClick="SetValue(this)">
                                            通知する
                                            <input type="radio" name="compulsion" value="3" <?php echo $this->scheduleEventInfo->getCompulsion() == "3" ?  "checked" : ""; ?> onClick="SetValue(this)">
                                            通知しない
                                          </span>
                                        </td>
                                         <td width="100">
                                          <span class="fBlack10100">
                                            社外/社内: 
                                          </span>
                                        </td>
                                        <td width="300">
                                          <span class="fBlack10100">
                                            <input type="radio" name="outdoor" value="t" <?php echo $this->scheduleEventInfo->isOutdoor() == "t" ?  "checked" : ""; ?>>
                                            社外
                                            <input type="radio" name="outdoor" value="f" <?php echo $this->scheduleEventInfo->isOutdoor() != "t" ?  "checked" : ""; ?>>
                                            社内
                                          </span>
                                        </td>
<?php
				}
?>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php
                break;
        default:
?>
                          <tr>
                            <td colspan="2" align="center">
                              <table border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td width="100">
                                          <span class="fBlack10100">
                                            公開/非公開：
                                          </span>
                                        </td>
                                        <td width="150">
                                          <span class="fBlack10100">
                                            <input type="radio" name="public" value="t" checked>
                                            公開
                                            <input type="radio" name="public" value="f" <?php echo $this->scheduleEventInfo->isPublic() == "f" ?  "checked" : ""; ?>>
                                            非公開
                                          </span>
                                            &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
                                         <td width="100">
                                          <span class="fBlack10100">
                                            社外/社内: 
                                          </span>
                                        </td>
                                        <td width="300">
                                          <span class="fBlack10100">
                                            <input type="radio" name="outdoor" value="t" <?php echo $this->scheduleEventInfo->isOutdoor() == "t" ?  "checked" : ""; ?>>
                                            社外
                                            <input type="radio" name="outdoor" value="f" <?php echo $this->scheduleEventInfo->isOutdoor() != "t" ?  "checked" : ""; ?>>
                                            社内
                                          </span>
                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>
                            </td>
                          </tr>

<?php
                break;
        }
  }

  /**
   * 日付一覧を表示する
   */
  function  printScheduleDateArray() {
  	require_once("./gw.php");
?>

                          <tr>
                            <td align="center"　colspan="2">
			                  <script language="JavaScript">
			                  <!--
			                    function deleteSubmit()
			                    {
								  if(document.schedule_date_frm.elements['schedule_date_cd_array[]'].value == ""){
										alert("日付を選択してください");
										return false;
								  }
			                      if(confirm("指定したスケジュールを削除します\nよろしいですか？")){
			                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=updateDetailScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&n=<?php echo $this->arrayIndexN ?>&refPage=<?php echo $this->refPage ?>";
			                          document.schedule_date_frm.sub.value = "updateDetailScreen";
			                          document.schedule_date_frm.bolscheduleUpdateCmd.value = "delete";		                         
			                          document.schedule_date_frm.submit();
								  }
			                    }
			                    function nextSubmit(numOperation)
			                    {
			                      switch(numOperation)
			                      {
			                        case 1:
			                          if(document.schedule_date_frm.elements['schedule_date_cd_array[]'].value == ""){
			                            alert("日付を選択してください");
			                            return false;
			                          }
			                          document.schedule_date_frm.sub.value = "updateScreen2";
			                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=updateScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&n=<?php echo $this->arrayIndexN ?>&refPage=<?php echo $this->refPage ?>";
			                          document.schedule_date_frm.submit();
			                          break;
			                        case 2:
			                          document.schedule_date_frm.sub.value = "addScheduleScreen";
			                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=addScheduleScreen&emp_cd=<?php echo $this->scheduleEventInfo->getOwner_emp_cd() ?>&refPage=<?php echo $this->refPage ?>";
			                          document.schedule_date_frm.submit();
			                          break;
			                      }
			                    }
			                  -->
			                  </script>
                              <table width="650" border="0" cellspacing="1" cellpadding="0" class="gray">
                                <tr>
                                  <td>
                                    <table width="650" border="0" cellspacing="2" cellpadding="3" class="white">
                                      <tr>
                                        <td align="center">
<?php
                                        $arr_schedule_date = array();
                                        $arr_schedule_date  = $this->dateInfo->getScheduleDateArray();
                                        	echo "<select name=\"schedule_date_cd_array[]\" size=\"8\" multiple>\n";
                                        	foreach($arr_schedule_date as $key => $value){
	                                            echo "<option value=\"" . $value['schedule_date_cd'] . "\">" . 
	                                            $value['year'] ."年" . $value['month'] ."月" . $value['day'] ."日";
	                                            if($value['hour_s'] != ""){
													echo $value['hour_s'] ."時" . $value['minute_s'] . "分";
													if($value['hour_e'] != ""){
														echo "〜" . $value['hour_e'] . "時" . $value['minute_e'] . "分";
													}
	                                            }
	                                        	echo "</option>\n";
                                        	}
											echo "</select>\n";
?>
                                        </td>
                                        <td align="left">
										  <input type="hidden" name="maxScheduleDateCd" value="<?php echo $arr_schedule_date[count($arr_schedule_date)-1]["schedule_date_cd"] ?>">
                                          <input type="button" name="nextButton1" value="指定日の編集" onclick="nextSubmit(1);"><br>
                                          <input type="button" name="nextButton2" value="　日付追加　" onclick="nextSubmit(2);"><br>
                                          <input type="button" name="nextButton3" value="　日付削除　" onClick="deleteSubmit()"><br>



                                        </td>
                                      </tr>
                                    </table>
                                  </td>
                                </tr>
                              </table>


                            </td>
                          </tr>

<?php
  }

  /**
   * ボタン表示
   */
  function printButton(){
        switch($this->scheduleEventInfo->getEvent_mode()){
        case 1:
?>
                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
              		  objFrm.sub.value = "指定スケジュール更新";
					  objFrm.submit();
                    }
                    function frmSubmitDel(objFrm)
                    {
						if(confirm("指定したスケジュールを削除します\nよろしいですか？")){
	              			objFrm.sub.value = "指定スケジュール削除";
							objFrm.submit();
						}
                    }
                    function nextSubmit(numOperation)
                    {
                      document.schedule_date_frm.event_mode.value = numOperation;
                      switch(numOperation)
                      {
                        case 2:
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                        case 3:
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                      }
                    }
                  -->
                  </script>
                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                                <input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getEvent_mode()) ?>">
                                <input type="button" name="subCmd" value="指定スケジュール更新"  onClick="frmSubmit(document.schedule_date_frm)">
                                <input type="button" name="subCmddel" value="指定スケジュール削除"  onClick="frmSubmitDel(document.schedule_date_frm)">
                      </td>
                      <td align="right">
                                <input type="button" name="nextButton" value="施設予約" onClick="nextSubmit(2)">
                                <input type="button" name="nextButton" value="メンバー登録" onClick="nextSubmit(3)">
                      </td>
                    </tr>
                  </table>
<?php
          break;
          
        case 2:
?>

                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
              			objFrm.sub.value = "指定スケジュール更新";
						objFrm.submit();
                    }
                    function frmSubmitDel(objFrm)
                    {
						if(confirm("指定したスケジュールを削除します\nよろしいですか？")){
	              			objFrm.sub.value = "指定スケジュール削除";
							objFrm.submit();
						}
                    }
                    function nextSubmit(numOperation)
                    {
                      document.schedule_date_frm.event_mode.value = numOperation;
                      switch(numOperation)
                      {
                        case 4:
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                      }
                    }
                  -->
                  </script>
                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                                <input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getEvent_mode()) ?>">
                                <input type="button" name="subCmd" value="指定スケジュール更新"  onClick="frmSubmit(document.schedule_date_frm)">
                                <input type="button" name="subCmddel" value="指定スケジュール削除"  onClick="frmSubmitDel(document.schedule_date_frm)">
                      </td>
                      <td align="right">
                                <input type="button" name="nextButton" value="メンバー登録" onClick="nextSubmit(4)">
                      </td>
                    </tr>
                  </table>

<?php
          break;
        case 3:
?>
                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
					  if(strSelectValue == 1 || strSelectValue == 2){
						  if(objFrm.elements['group_member2[]'].length == 0 && 
						  	objFrm.elements['group_member3[]'].length == 0){
						  	
						  	alert("メンバーがいないので通知ができません");
						  	return false;
						  }
					  }
					  
                      if(objFrm.elements['compulsion'][1].checked){
                      	if(objFrm.elements['group_member3[]'].length > 0){
                      		if(confirm("未回答メンバへの参加可否を通知しません\nよろしいですか？")){
                      			objFrm.sub.value = "指定スケジュール更新";
								objFrm.submit();
                      		}
                      	}
                      	else{
	              			objFrm.sub.value = "指定スケジュール更新";
							objFrm.submit();
                      	}
                      }
                      else{
              			objFrm.sub.value = "指定スケジュール更新";
						objFrm.submit();
                      }
                    }
                    function frmSubmitDel(objFrm)
                    {
						if(confirm("指定したスケジュールを削除します\nよろしいですか？")){
	              			objFrm.sub.value = "指定スケジュール削除";
							objFrm.submit();
						}
                    }
                    function nextSubmit(numOperation)
                    {
                      document.schedule_date_frm.event_mode.value = numOperation;
                      switch(numOperation)
                      {
                        case 4:
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                      }
                    }
                  -->
                  </script>
                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                                <input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getEvent_mode()) ?>">
                                <input type="button" name="subCmd" value="指定スケジュール更新"  onClick="frmSubmit(document.schedule_date_frm)">
                                <input type="button" name="subCmddel" value="指定スケジュール削除"  onClick="frmSubmitDel(document.schedule_date_frm)">
                      </td>
                      <td align="right">
                                <input type="button" name="nextButton" value="施設予約" onClick="nextSubmit(4)">
                      </td>
                    </tr>
                  </table>
<?php
          break;
        case 4:
?>               
                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
					  if(strSelectValue == 1 || strSelectValue == 2){
						  if(objFrm.elements['group_member2[]'].length == 0 && 
						  	objFrm.elements['group_member3[]'].length == 0){
						  	
						  	alert("メンバーがいないので通知ができません");
						  	return false;
						  }
					  }
					  
                      if(objFrm.elements['compulsion'][1].checked){
                      	if(objFrm.elements['group_member3[]'].length > 0){
                      		if(confirm("未回答メンバへの参加可否を通知しません\nよろしいですか？")){
                      			objFrm.sub.value = "指定スケジュール更新";
								objFrm.submit();
                      		}
                      	}
                      	else{
	              			objFrm.sub.value = "指定スケジュール更新";
							objFrm.submit();
                      	}
                      }
                      else{
              			objFrm.sub.value = "指定スケジュール更新";
						objFrm.submit();
                      }
                    }
                    function frmSubmitDel(objFrm)
                    {
						if(confirm("指定したスケジュールを削除します\nよろしいですか？")){
	              			objFrm.sub.value = "指定スケジュール削除";
							objFrm.submit();
						}
                    }
                  -->
                  </script>
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                                <input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getEvent_mode()) ?>">
                                <input type="button" name="subCmd" value="指定スケジュール更新"  onClick="frmSubmit(document.schedule_date_frm)">
                                <input type="button" name="subCmddel" value="指定スケジュール削除"  onClick="frmSubmitDel(document.schedule_date_frm)">
                      </td>
                    </tr>
                  </table>
<?php
          break;
        default:
?>
                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
              			objFrm.sub.value = "指定スケジュール更新";
						objFrm.submit();
                    }
                    function frmSubmitDel(objFrm)
                    {
						if(confirm("指定したスケジュールを削除します\nよろしいですか？")){
	              			objFrm.sub.value = "指定スケジュール削除";
							objFrm.submit();
						}
                    }
                    function nextSubmit(numOperation)
                    {
                      document.schedule_date_frm.event_mode.value = numOperation;
                      switch(numOperation)
                      {
                        case 2:
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                        case 3:
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                      }
                    }
                  -->
                  </script>
                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                                <input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="1">
                                <input type="button" name="subCmd" value="指定スケジュール更新"  onClick="frmSubmit(document.schedule_date_frm)">
                                <input type="button" name="subCmddel" value="指定スケジュール削除"  onClick="frmSubmitDel(document.schedule_date_frm)">
                      </td>
                      <td align="right">
                                <input type="button" name="nextButton" value="施設予約" onClick="nextSubmit(2)">
                                <input type="button" name="nextButton" value="メンバー登録" onClick="nextSubmit(3)">
                      </td>
                    </tr>
                  </table>
<?php
      break;
        }
  }

  /**
   * ボタン表示
   */
  function printAddScheduleButton(){
        switch($this->scheduleEventInfo->getEvent_mode()){
        case 1:
?>
                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
                      if(objFrm.date_mode.value == "4"){
						if(objFrm.event_mode.value == "2" || objFrm.event_mode.value == "4"){
						  alert("期間指定と施設予約は同時に行えません");
						}
						else{
	              		  objFrm.sub.value = "スケジュール追加";
						  objFrm.submit();
						}
                      }
                      else{
	              		  objFrm.sub.value = "スケジュール追加";
						  objFrm.submit();
					  }
                    }
                    function nextSubmit(numOperation)
                    {
                      document.schedule_date_frm.event_mode.value = numOperation;
                      switch(numOperation)
                      {
                        case 2:
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                        case 3:
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                      }
                    }
                  -->
                  </script>
                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                                <input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getEvent_mode()) ?>">
                                <input type="button" name="subCmd" value="スケジュール追加"  onClick="frmSubmit(document.schedule_date_frm)">
                      </td>
                      <td align="right">
                                <input type="button" name="nextButton" value="施設予約" onClick="nextSubmit(2)">
                                <input type="button" name="nextButton" value="メンバー登録" onClick="nextSubmit(3)">
                      </td>
                    </tr>
                  </table>
<?php
          break;
          
        case 2:
?>

                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
<?php
		if($this->subScreenMode == "addScheduleScreen" or $this->subScreenMode == "addScheduleScreen2"){
?>
					  if(objFrm.elements['facilities2[]'].length == 0){
						alert("追加する施設がありません");
						return;
					  }
<?php
		}
?>
                    
                      if(objFrm.date_mode.value == "4"){
						if(objFrm.event_mode.value == "2" || objFrm.event_mode.value == "4"){
						  alert("期間指定と施設予約は同時に行えません");
						}
						else{
	              		  objFrm.sub.value = "スケジュール追加";
						  objFrm.submit();
						}
                      }
                      else{
	              		  objFrm.sub.value = "スケジュール追加";
						  objFrm.submit();
					  }
                    }
                    function nextSubmit(numOperation)
                    {
                      document.schedule_date_frm.event_mode.value = numOperation;
                      switch(numOperation)
                      {
                        case 4:
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                      }
                    }
                  -->
                  </script>
                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                                <input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getEvent_mode()) ?>">
                                <input type="button" name="subCmd" value="スケジュール追加"  onClick="frmSubmit(document.schedule_date_frm)">
                      </td>
                      <td align="right">
                                <input type="button" name="nextButton" value="メンバー登録" onClick="nextSubmit(4)">
                      </td>
                    </tr>
                  </table>

<?php
          break;
        case 3:
?>
                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
<?php
		if($this->subScreenMode == "addScheduleScreen" or $this->subScreenMode == "addScheduleScreen2"){
?>
					  if(objFrm.elements['group_member2[]'].length == 0 && objFrm.elements['group_member3[]'].length == 0){
						alert("追加するメンバーが一人もいません");
						return;
					  }
<?php
		}
?>
                      if(objFrm.date_mode.value == "4"){
						if(objFrm.event_mode.value == "2" || objFrm.event_mode.value == "4"){
						  alert("期間指定と施設予約は同時に行えません");
						  return false;
						}
                      }

					  if(strSelectValue == 1 || strSelectValue == 2){
						  if(objFrm.elements['group_member2[]'].length == 0 && 
						  	objFrm.elements['group_member3[]'].length == 0){
						  	
						  	alert("メンバーがいないので通知ができません");
						  	return false;
						  }
					  }
					  
                      if(objFrm.elements['compulsion'][1].checked){
                      	if(objFrm.elements['group_member3[]'].length > 0){
                      		if(confirm("未回答メンバへの参加可否を通知しません\nよろしいですか？")){
                      			objFrm.sub.value = "スケジュール追加";
								objFrm.submit();
                      		}
                      	}
                      	else{
	              			objFrm.sub.value = "スケジュール追加";
							objFrm.submit();
                      	}
                      }
                      else{
              			objFrm.sub.value = "スケジュール追加";
						objFrm.submit();
                      }
                    }
                    function nextSubmit(numOperation)
                    {
                      document.schedule_date_frm.event_mode.value = numOperation;
                      switch(numOperation)
                      {
                        case 4:
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                      }
                    }
                    
                  -->
                  </script>
                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                                <input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getEvent_mode()) ?>">
                                <input type="button" name="subCmd" value="スケジュール追加"  onClick="frmSubmit(document.schedule_date_frm)">
                      </td>
                      <td align="right">
                                <input type="button" name="nextButton" value="施設予約" onClick="nextSubmit(4)">
                      </td>
                    </tr>
                  </table>
<?php
          break;
        case 4:
?>               
                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
<?php
		if($this->subScreenMode == "addScheduleScreen" or $this->subScreenMode == "addScheduleScreen2"){
?>
					  if(objFrm.elements['group_member2[]'].length == 0 && objFrm.elements['group_member3[]'].length == 0 && objFrm.elements['facilities2[]'].length == 0){
						alert("メンバーも施設もないスケジュールは登録できません。");
						return;
					  }
<?php
		}
?>
                      if(objFrm.date_mode.value == "4"){
						if(objFrm.event_mode.value == "2" || objFrm.event_mode.value == "4"){
						  alert("期間指定と施設予約は同時に行えません");
						  return false;
						}
                      }

					  if(strSelectValue == 1 || strSelectValue == 2){
						  if(objFrm.elements['group_member2[]'].length == 0 && 
						  	objFrm.elements['group_member3[]'].length == 0){
						  	
						  	alert("メンバーがいないので通知ができません");
						  	return false;
						  }
					  }
					  
                      if(objFrm.elements['compulsion'][1].checked){
                      	if(objFrm.elements['group_member3[]'].length > 0){
                      		if(confirm("未回答メンバへの参加可否を通知しません\nよろしいですか？")){
                      			objFrm.sub.value = "スケジュール追加";
								objFrm.submit();
                      		}
                      	}
                      	else{
	              			objFrm.sub.value = "スケジュール追加";
							objFrm.submit();
                      	}
                      }
                      else{
              			objFrm.sub.value = "スケジュール追加";
						objFrm.submit();
                      }
                    }
                  -->
                  </script>
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                                <input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="<?php echo htmlSpecialEscape($this->scheduleEventInfo->getEvent_mode()) ?>">
                                <input type="button" name="subCmd" value="スケジュール追加"  onClick="frmSubmit(document.schedule_date_frm)">
                      </td>
                    </tr>
                  </table>
<?php
          break;
        default:
?>
                  <script language="JavaScript">
                  <!--
                    function frmSubmit(objFrm)
                    {
                      if(objFrm.date_mode.value == "4"){
						if(objFrm.event_mode.value == "2" || objFrm.event_mode.value == "4"){
						  alert("期間指定と施設予約は同時に行えません");
						}
						else{
	              		  objFrm.sub.value = "スケジュール追加";
						  objFrm.submit();
						}
                      }
                      else{
	              		  objFrm.sub.value = "スケジュール追加";
						  objFrm.submit();
					  }
                    }
                    function nextSubmit(numOperation)
                    {
                      document.schedule_date_frm.event_mode.value = numOperation;
                      switch(numOperation)
                      {
                        case 2:
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                        case 3:
                          document.schedule_date_frm.action = "<?php echo $_ROOT_URL_ . $this->refApplication ?>?sub=<?php echo $this->subScreenMode ?>";
						  document.schedule_date_frm.sub.value = "<?php echo $this->subScreenMode ?>";
                          document.schedule_date_frm.submit();
                          break;
                      }
                    }
                  -->
                  </script>
                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
                                <input type="hidden" name="sub" value="">
                                <input type="hidden" name="event_mode" value="1">
                                <input type="button" name="subCmd" value="スケジュール追加"  onClick="frmSubmit(document.schedule_date_frm)">
                      </td>
                      <td align="right">
                                <input type="button" name="nextButton" value="施設予約" onClick="nextSubmit(2)">
                                <input type="button" name="nextButton" value="メンバー登録" onClick="nextSubmit(3)">
                      </td>
                    </tr>
                  </table>
<?php
      break;
        }
  }

  /**
   * 詳細画面表示用ボタン表示
   */
  function printDetailButton(){
?>                    
                  <table width="700" border="0" cellspacing="2" cellpadding="3">
                    <tr>
                      <td align="left">
		                  <script language="JavaScript">
		                  <!--
		                    function deleteEventSubmit(objFrm)
		                    {
		                    	if(confirm("スケジュールを削除します\nよろしいですか？")){
			              			objFrm.sub.value = "削除";
									objFrm.submit();
								}
		                    }
		                  -->
		                  </script>
		                  <div align="left">
                            <input type="hidden" name="sub" value="">
		                    <input type="button" name="deleteEvent" value="スケジュール削除" onClick="deleteEventSubmit(document.schedule_date_frm)">
		                  </div>
                      </td>
                    </tr>
                  </table>
<?php
  }
  
  /**
   * Selectボックスを作成する
   * @param strObjName  Select 属性の Name プロパティ
   * @param strDefaultValue  デフォルト値 0以上
   * @param intInterval 各Option Value の増分値
   * @param intMinValue Option Value の最小値
   * @param intMaxValue Option Value の最大値
   * @param flgNoSelect Optionに「--」を表示するか
   **/
  function printSelect($strObjName, $strDefaultValue, $intInterval, $intMinValue, $intMaxValue, $flgNoSelect)
  {
?>
                                                                        <select name="<?php echo $strObjName ?>">
<?php
	if($flgNoSelect){
?>
                                                                          <option value="" <?php echo ($strDefaultValue == "" ? "selected" : "") ?>>--</option>
<?php
	}
?>
<?php
    for($i = $intMinValue; $i <= $intMaxValue; $i += $intInterval)
    {
    	$tmpI = substr("0" . $i, -1*(strlen($intMaxValue)));
?>
                                                                          <option value="<?php echo $tmpI ?>" <?php echo ($tmpI == $strDefaultValue) ? "selected" : "" ?>><?php echo $tmpI ?></option>
<?php
    }
?>
                                                                        </select>
<?php
  }

}

?>