<?php
/**
 * タスク管理用SQLクラス PostgreSQL用
 **/

include_once($_ROOT_DIR_ . "class/DBSqlPgsql.php");

class DBSqlPgsqlTask extends DBSqlPgsql
{
  /**
   * 管理者用に全てのグループを表示する
   **/
  function selectAllGroupList()
  {
    $sqlstr  = "SELECT DISTINCT ";
    $sqlstr .= "    group_master.group_cd, ";
    $sqlstr .= "    group_master.group_name ";
    $sqlstr .= "FROM ";
    $sqlstr .= "    group_master, ";
    $sqlstr .= "    group_relation ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "    group_master.group_cd = group_relation.group_cd ";
    $sqlstr .= "    AND group_master.public_flg = 't' ";
    $sqlstr .= "ORDER BY ";
    $sqlstr .= "    group_master.group_name;";

    return $sqlstr;
  }
  /**
   * EmpCdを使用してグループリストを取得する
   **/
  function selectGroupListWithEmpCd($emp_cd)
  {
    $this->argumentCheck("emp_cd", $emp_cd);

    $sqlstr  = "SELECT ";
    $sqlstr .= "    group_master.group_cd, ";
    $sqlstr .= "    group_master.group_name ";
    $sqlstr .= "FROM ";
    $sqlstr .= "    group_master, ";
    $sqlstr .= "    group_relation ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "    group_master.group_cd = group_relation.group_cd ";
    $sqlstr .= "    AND group_master.public_flg = 't' ";
    $sqlstr .= "    AND group_relation.emp_cd = '$emp_cd' ";
    $sqlstr .= "ORDER BY ";
    $sqlstr .= "    group_master.group_name;";
    
    return $sqlstr;
    //echo $sqlstr;
  }
  /**
   * GroupCdを使用してグループ名称を取得する
   **/
  function selectGroupNameWithEmpCd($group_cd)
  {
    $this->argumentCheck("group_cd", $group_cd);

    $sqlstr  = "SELECT ";
    $sqlstr .= "    group_master.group_cd, ";
    $sqlstr .= "    group_master.group_name ";
    $sqlstr .= "FROM ";
    $sqlstr .= "    group_master ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "    group_master.group_cd = '$group_cd' ";
    $sqlstr .= "    AND group_master.public_flg = 't';";
    
    return $sqlstr;
    //echo $sqlstr;
  }
  /**
   * group_cdを使用してカテゴリリストを取得する
   **/
  function selectCategoryListWithGroupCd($group_cd)
  {
    $this->argumentCheck("group_cd", $group_cd);

    $sqlstr  = "SELECT ";
    $sqlstr .= "  category_cd, ";
    $sqlstr .= "  category_name, ";
    $sqlstr .= "  description, ";
    $sqlstr .= "  readable ";
    $sqlstr .= "FROM ";
    $sqlstr .= "  task_category ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  task_category.group_cd = '$group_cd' ";
    $sqlstr .= "ORDER BY ";
    $sqlstr .= "  category_name;";

    return $sqlstr;
    //echo $sqlstr;
  }
  /**
   * 二重投稿されたカテゴリをチェックする
   **/
  function selectCategoryCheckDoubleInsert($cat_name, $cat_desc, $group_cd)
  {
    $sqlstr  = "SELECT ";
    $sqlstr .= "  COUNT(1) AS check_num ";
    $sqlstr .= "FROM ";
    $sqlstr .= "  task_category ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  category_name = '$cat_name' ";
    $sqlstr .= "  AND group_cd = '$group_cd' ";
    $sqlstr .= "  AND description = '$cat_desc';";

    return $sqlstr;
  }
  /**
   * 新規カテゴリを作成する
   **/
  function insertTaskCategory($cat_cd, $cat_name, $cat_desc, $group_cd, $readable)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("cat_name", $cat_name);
    //$this->argumentCheck("cat_desc", $cat_desc);
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("readable", $readable);

    $sqlstr  ="insert into task_category ";
    $sqlstr .= "  (category_cd, category_name, group_cd, description, readable)";
    $sqlstr .= "  values('$cat_cd', '$cat_name', '$group_cd', '$cat_desc', '$readable');";

    //echo $sqlstr;
    return $sqlstr;

  }
  /**
   * カテゴリ情報を取得する
   **/
  function selectCategoryWithGroupCdCatCd($cat_cd, $group_cd)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("group_cd", $group_cd);

    $sqlstr  = "SELECT ";
    $sqlstr .= "  category_cd, ";
    $sqlstr .= "  category_name, ";
    $sqlstr .= "  description, ";
    $sqlstr .= "  readable ";
    $sqlstr .= "FROM ";
    $sqlstr .= "  task_category ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  task_category.group_cd = '$group_cd' ";
    $sqlstr .= "  AND task_category.category_cd = '$cat_cd';";

    //echo $sqlstr;
    return $sqlstr;
  }
  /**
   * カテゴリ情報を更新する
   **/
  function updateTaskCategory($cat_cd, $cat_name, $cat_desc, $group_cd, $readable)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("cat_name", $cat_name);
    //$this->argumentCheck("cat_desc", $cat_desc);
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("readable", $readable);

    $sqlstr  = "UPDATE ";
    $sqlstr .= "  task_category ";
    $sqlstr .= "SET ";
    $sqlstr .= "  category_name = '$cat_name', ";
    $sqlstr .= "  description = '$cat_desc', ";
    $sqlstr .= "  readable = '$readable' ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  category_cd = '$cat_cd' ";
    $sqlstr .= "  AND group_cd = '$group_cd';";

    //echo $sqlstr;
    return $sqlstr;
  }
  /**
   * サブカテゴリ件数を取得する
   **/
  function countSubCategory($cat_cd, $group_cd)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("group_cd", $group_cd);

    $sqlstr  = "SELECT ";
    $sqlstr .= "  COUNT(sub_category_cd) AS num_sub_cat ";
    $sqlstr .= "FROM ";
    $sqlstr .= "  task_sub_category ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  task_sub_category.group_cd = '$group_cd' ";
    $sqlstr .= "  AND task_sub_category.category_cd = '$cat_cd';";

    //echo $sqlstr;
    return $sqlstr;
  }
  /**
   * カテゴリを削除する
   **/
  function deleteTaskCategory($cat_cd, $group_cd)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("group_cd", $group_cd);

    $sqlstr  = "DELETE FROM ";
    $sqlstr .= "  task_category ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  category_cd = '$cat_cd' ";
    $sqlstr .= "  AND group_cd = '$group_cd';";

    //echo $sqlstr;
    return $sqlstr;
  }
  /**
   * カテゴリ配下のサブカテゴリを一括削除する
   **/
  function deleteTaskAllSubCategory($cat_cd, $group_cd)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("group_cd", $group_cd);

    $sqlstr  = "DELETE FROM ";
    $sqlstr .= "  task_sub_category ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  category_cd = '$cat_cd' ";
    $sqlstr .= "  AND group_cd = '$group_cd';";

    //echo $sqlstr;
    return $sqlstr;
  }
  /**
   * カテゴリ配下のタスクを一括削除する
   **/
  function deleteTaskAllCategoryTask($cat_cd, $group_cd)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("group_cd", $group_cd);

    $sqlstr  = "DELETE FROM ";
    $sqlstr .= "  task ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  category_cd = '$cat_cd' ";
    $sqlstr .= "  AND group_cd = '$group_cd';";

    //echo $sqlstr;
    return $sqlstr;
  }
  /**
   * group_cdとcat_cdを使用してサブカテゴリリストを取得する
   **/
  function selectSubCategoryListWithGroupCdCatCd($group_cd,$cat_cd)
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);

    $sqlstr  = "SELECT ";
    $sqlstr .= "  sub_category_cd, ";
    $sqlstr .= "  sub_category_name, ";
    $sqlstr .= "  description, ";
    $sqlstr .= "  readable ";
    $sqlstr .= "FROM ";
    $sqlstr .= "  task_sub_category ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  task_sub_category.group_cd = '$group_cd' ";
    $sqlstr .= "  AND task_sub_category.category_cd = '$cat_cd' ";
    $sqlstr .= "ORDER BY ";
    $sqlstr .= "  sub_category_name;";

    //echo $sqlstr;
    return $sqlstr;
    
  }
  /**
   * 二重投稿されたサブカテゴリをチェックする
   **/
  function selectSubCatCheckDoubleInsert($cat_cd, $subcat_name, $subcat_desc, $group_cd)
  {
    $sqlstr  = "SELECT ";
    $sqlstr .= "  COUNT(1) AS check_num ";
    $sqlstr .= "FROM ";
    $sqlstr .= "  task_sub_category ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  category_cd = '$cat_cd' ";
    $sqlstr .= "  AND sub_category_name = '$subcat_name' ";
    $sqlstr .= "  AND group_cd = '$group_cd' ";
    $sqlstr .= "  AND description = '$subcat_desc';";

    return $sqlstr;
  }
  /**
   * 新規サブカテゴリを作成する
   **/
  function insertSubCategory($cat_cd, $subcat_cd, $subcat_name, $subcat_desc, $group_cd, $readable)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("subcat_name", $subcat_name);
    //$this->argumentCheck("subcat_desc", $subcat_desc);
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("readable", $readable);

    $sqlstr  ="insert into task_sub_category ";
    $sqlstr .= "  (category_cd, sub_category_cd, sub_category_name, group_cd, description, readable)";
    $sqlstr .= "  values('$cat_cd', '$subcat_cd', '$subcat_name', '$group_cd', '$subcat_desc', '$readable');";

    //echo $sqlstr;
    return $sqlstr;

  }
  /**
   * サブカテゴリ情報を取得する
   **/
  function selectSubCategoryWithGroupCdCatCd($cat_cd, $subcat_cd, $group_cd)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("group_cd", $group_cd);

    $sqlstr  = "SELECT ";
    $sqlstr .= "  sub_category_cd, ";
    $sqlstr .= "  sub_category_name, ";
    $sqlstr .= "  description, ";
    $sqlstr .= "  readable ";
    $sqlstr .= "FROM ";
    $sqlstr .= "  task_sub_category ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  task_sub_category.group_cd = '$group_cd' ";
    $sqlstr .= "  AND task_sub_category.category_cd = '$cat_cd' ";
    $sqlstr .= "  AND task_sub_category.sub_category_cd = '$subcat_cd';";

    //echo $sqlstr;
    return $sqlstr;
  }
  /**
   * サブカテゴリ情報を更新する
   **/
  function updateTaskSubCategory($cat_cd, $subcat_cd, $subcat_name, $subcat_desc, $group_cd, $readable)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("subcat_name", $subcat_name);
    //$this->argumentCheck("subcat_desc", $subcat_desc);
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("readable", $readable);

    $sqlstr  = "UPDATE ";
    $sqlstr .= "  task_sub_category ";
    $sqlstr .= "SET ";
    $sqlstr .= "  sub_category_name = '$subcat_name', ";
    $sqlstr .= "  description = '$subcat_desc', ";
    $sqlstr .= "  readable = '$readable' ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  category_cd = '$cat_cd' ";
    $sqlstr .= "  AND sub_category_cd = '$subcat_cd' ";
    $sqlstr .= "  AND group_cd = '$group_cd';";

    //echo $sqlstr;
    return $sqlstr;
  }
  /**
   * タスク件数を取得する
   **/
  function countTask($cat_cd, $subcat_cd, $group_cd)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("group_cd", $group_cd);

    $sqlstr  = "SELECT ";
    $sqlstr .= "  MAX(task_cd) AS num_task ";
    $sqlstr .= "FROM ";
    $sqlstr .= "  TASK ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  TASK.group_cd = '$group_cd' ";
    $sqlstr .= "  AND TASK.category_cd = '$cat_cd' ";
    $sqlstr .= "  AND TASK.sub_category_cd = '$subcat_cd';";

    //echo $sqlstr;
    return $sqlstr;
  }
  /**
   * サブカテゴリを削除する
   **/
  function deleteTaskSubCategory($cat_cd, $subcat_cd, $group_cd)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("group_cd", $group_cd);

    $sqlstr  = "DELETE FROM ";
    $sqlstr .= "  task_sub_category ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  category_cd = '$cat_cd' ";
    $sqlstr .= "  AND sub_category_cd = '$subcat_cd' ";
    $sqlstr .= "  AND group_cd = '$group_cd';";

    //echo $sqlstr;
    return $sqlstr;
  }
  /**
   * サブカテゴリ配下のタスクを一括削除する
   **/
  function deleteTaskAllTask($cat_cd, $subcat_cd, $group_cd)
  {
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("group_cd", $group_cd);

    $sqlstr  = "DELETE FROM ";
    $sqlstr .= "  task ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  category_cd = '$cat_cd' ";
    $sqlstr .= "  AND sub_category_cd = '$subcat_cd' ";
    $sqlstr .= "  AND group_cd = '$group_cd';";

    //echo $sqlstr;
    return $sqlstr;
  }
  /**
   * group_cdとcat_cdとsubcat_cdを使用してタスクリストを取得する
   **/
  function selectTaskListWithGroupCdCatCdSubcatCd($group_cd,$cat_cd,$subcat_cd,$intLimit,$intPageNo,$statusSearch,$pedateSort="asc",$prioritySort="asc",$sortjob="pedate")
  {

    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);

    $intOffset = $intLimit * ($intPageNo - 1);

    if(!$statusSearch or $statusSearch == "-3")
    {
      $strStatusSearch = "";
    }
    else if($statusSearch == "-2")
    {
      $strStatusSearch = " AND status IN ('1', '2') ";
    }
    else
    {
      $strStatusSearch = "  AND status = '$statusSearch' ";
    }

    
    $sqlstr  = "SELECT ";
    $sqlstr .= "  task.task_cd, "; 
    $sqlstr .= "  task.title,  ";
    $sqlstr .= "  task.description,   ";
    $sqlstr .= "  date_part('year'::text, task.plan_start_date) AS psyear,  ";
    $sqlstr .= "  date_part('month'::text, task.plan_start_date) AS psmonth,  ";
    $sqlstr .= "  date_part('day'::text, task.plan_start_date) AS psday,  ";
    $sqlstr .= "  lpad(date_part('hour'::text, task.plan_start_time)::text, 2, '0') AS pshour,   ";
    $sqlstr .= "  lpad(date_part('minutes'::text, task.plan_start_time)::text, 2, '0') AS psminutes,   ";
    $sqlstr .= "  date_part('year'::text, task.plan_end_date) AS peyear,   ";
    $sqlstr .= "  date_part('month'::text, task.plan_end_date) AS pemonth,   ";
    $sqlstr .= "  date_part('day'::text, task.plan_end_date) AS peday,   ";
    $sqlstr .= "  lpad(date_part('hour'::text, task.plan_end_time)::text, 2, '0') AS pehour,   ";
    $sqlstr .= "  lpad(date_part('minutes'::text, task.plan_end_time)::text, 2, '0') AS peminutes,   ";
    $sqlstr .= "  date_part('year'::text, task.result_start_date) AS rsyear,  ";
    $sqlstr .= "  date_part('month'::text, task.result_start_date) AS rsmonth,  ";
    $sqlstr .= "  date_part('day'::text, task.result_start_date) AS rsday,  ";
    $sqlstr .= "  lpad(date_part('hour'::text, task.result_start_time)::text, 2, '0') AS rshour,   ";
    $sqlstr .= "  lpad(date_part('minutes'::text, task.result_start_time)::text, 2, '0') AS rsminutes,   ";
    $sqlstr .= "  date_part('year'::text, task.result_end_date) AS reyear,   ";
    $sqlstr .= "  date_part('month'::text, task.result_end_date) AS remonth,   ";
    $sqlstr .= "  date_part('day'::text, task.result_end_date) AS reday,   ";
    $sqlstr .= "  lpad(date_part('hour'::text, task.result_end_time)::text, 2, '0') AS rehour,   ";
    $sqlstr .= "  lpad(date_part('minutes'::text, task.result_end_time)::text, 2, '0') AS reminutes,   ";
    $sqlstr .= "  task.priority_cd, ";
    $sqlstr .= "  mst_priority.priority_name, ";
    $sqlstr .= "  task.owner_emp_cd,   ";
    $sqlstr .= "  task.regist_emp_cd,   ";
    $sqlstr .= "  task.status,   ";
    $sqlstr .= "  task.schedule_flg  ";
    $sqlstr .= "FROM   ";
    $sqlstr .= "  task, ";
    $sqlstr .= "  mst_priority ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  mst_priority.priority_cd = task.priority_cd ";
    $sqlstr .= "  AND category_cd = '$cat_cd' ";
    $sqlstr .= "  AND sub_category_cd = '$subcat_cd' ";
    $sqlstr .= "  AND group_cd = '$group_cd' ";
    $sqlstr .= $strStatusSearch;
    $sqlstr .= "ORDER BY ";
    if($sortjob == "pedate")
    {
      $sqlstr .= "  task.plan_end_date $pedateSort, ";
      $sqlstr .= "  task.plan_end_time $pedateSort, ";
      $sqlstr .= "  task.priority_cd $prioritySort, ";
    }
    else if($sortjob == "priority")
    {
      $sqlstr .= "  task.priority_cd $prioritySort, ";
      $sqlstr .= "  task.plan_end_date $pedateSort, ";
      $sqlstr .= "  task.plan_end_time $pedateSort, ";
    }
    $sqlstr .= "  task.title ";
    $sqlstr .= "LIMIT $intLimit ";
    $sqlstr .= "OFFSET $intOffset;";
    //echo $sqlstr;
    return $sqlstr;
    
  }
  function selectTaskListPageNo($group_cd,$cat_cd,$subcat_cd,$intLimit,$statusSearch="-2")
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);

    if(!$statusSearch or $statusSearch == "-3")
    {
      $strStatusSearch = "";
    }
    else if($statusSearch == "-2")
    {
      $strStatusSearch = " AND status IN ('1', '2') ";
    }
    else
    {
      $strStatusSearch = "  AND status = '$statusSearch' ";
    }
    

    $sqlstr  = "SELECT ";
    $sqlstr .= "  TRUNC((COUNT(1)-1) / $intLimit,0) + 1 AS max_page_no ";
    $sqlstr .= "FROM ";
    $sqlstr .= "  task ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  category_cd = '$cat_cd' ";
    $sqlstr .= "  AND sub_category_cd = '$subcat_cd' ";
    $sqlstr .= "  AND group_cd = '$group_cd' ";
    $sqlstr .= $strStatusSearch;
    $sqlstr .= ";";

    //echo $sqlstr;
    return $sqlstr;
  }
  /**
   * 個人タスクリストを取得する
   **/
  function selectMyTaskListWithGroupCdCatCdSubcatCd($emp_cd,$intLimit, $intPageNo,$groupCdSearch="-2",$statusSearch="-2",$pedateSort="asc",$prioritySort="asc",$sortjob="pedate")
  {
    $this->argumentCheck("emp_cd", $emp_cd);
    /*
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    */

    $intOffset = $intLimit * ($intPageNo - 1);

    if(!$groupCdSearch or $groupCdSearch == "-2")
    {
      $strGroupCdSearch = "";
    }
    else
    {
      $strGroupCdSearch = "  AND group_cd = '$groupCdSearch' ";
    }

    if(!$statusSearch or $statusSearch == "-3")
    {
      $strStatusSearch = "";
    }
    else if($statusSearch == "-2")
    {
      $strStatusSearch = " AND status IN ('1', '2') ";
    }
    else
    {
      $strStatusSearch = "  AND status = '$statusSearch' ";
    }

    $sqlstr  = "SELECT ";
    $sqlstr .= "  task.category_cd, ";
    $sqlstr .= "  task.sub_category_cd, ";
    $sqlstr .= "  task.group_cd, ";
    $sqlstr .= "  task.task_cd, "; 
    $sqlstr .= "  task.title,  ";
    $sqlstr .= "  task.description,   ";
    $sqlstr .= "  date_part('year'::text, task.plan_start_date) AS psyear,  ";
    $sqlstr .= "  date_part('month'::text, task.plan_start_date) AS psmonth,  ";
    $sqlstr .= "  date_part('day'::text, task.plan_start_date) AS psday,  ";
    $sqlstr .= "  lpad(date_part('hour'::text, task.plan_start_time)::text, 2, '0') AS pshour,   ";
    $sqlstr .= "  lpad(date_part('minutes'::text, task.plan_start_time)::text, 2, '0') AS psminutes,   ";
    $sqlstr .= "  date_part('year'::text, task.plan_end_date) AS peyear,   ";
    $sqlstr .= "  date_part('month'::text, task.plan_end_date) AS pemonth,   ";
    $sqlstr .= "  date_part('day'::text, task.plan_end_date) AS peday,   ";
    $sqlstr .= "  lpad(date_part('hour'::text, task.plan_end_time)::text, 2, '0') AS pehour,   ";
    $sqlstr .= "  lpad(date_part('minutes'::text, task.plan_end_time)::text, 2, '0') AS peminutes,   ";
    $sqlstr .= "  date_part('year'::text, task.result_start_date) AS rsyear,  ";
    $sqlstr .= "  date_part('month'::text, task.result_start_date) AS rsmonth,  ";
    $sqlstr .= "  date_part('day'::text, task.result_start_date) AS rsday,  ";
    $sqlstr .= "  lpad(date_part('hour'::text, task.result_start_time)::text, 2, '0') AS rshour,   ";
    $sqlstr .= "  lpad(date_part('minutes'::text, task.result_start_time)::text, 2, '0') AS rsminutes,   ";
    $sqlstr .= "  date_part('year'::text, task.result_end_date) AS reyear,   ";
    $sqlstr .= "  date_part('month'::text, task.result_end_date) AS remonth,   ";
    $sqlstr .= "  date_part('day'::text, task.result_end_date) AS reday,   ";
    $sqlstr .= "  lpad(date_part('hour'::text, task.result_end_time)::text, 2, '0') AS rehour,   ";
    $sqlstr .= "  lpad(date_part('minutes'::text, task.result_end_time)::text, 2, '0') AS reminutes,   ";
    $sqlstr .= "  task.priority_cd, ";
    $sqlstr .= "  mst_priority.priority_name, ";
    $sqlstr .= "  task.owner_emp_cd,   ";
    $sqlstr .= "  task.regist_emp_cd,   ";
    $sqlstr .= "  task.status,   ";
    $sqlstr .= "  task.schedule_flg  ";
    $sqlstr .= "FROM   ";
    $sqlstr .= "  task, ";
    $sqlstr .= "  mst_priority ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  mst_priority.priority_cd = task.priority_cd ";
    $sqlstr .= "  AND task.owner_emp_cd = '$emp_cd' ";
    $sqlstr .= $strGroupCdSearch;
    $sqlstr .= $strStatusSearch;
    /*
    $sqlstr .= "  AND category_cd = '$cat_cd' ";
    $sqlstr .= "  AND sub_category_cd = '$subcat_cd' ";
    $sqlstr .= "  AND group_cd = '$group_cd' ";
    */
    $sqlstr .= "ORDER BY ";

    if($sortjob == "pedate")
    {
      $sqlstr .= "  task.plan_end_date $pedateSort, ";
      $sqlstr .= "  task.plan_end_time $pedateSort, ";
      $sqlstr .= "  task.priority_cd $prioritySort, ";
    }
    else if($sortjob == "priority")
    {
      $sqlstr .= "  task.priority_cd $prioritySort, ";
      $sqlstr .= "  task.plan_end_date $pedateSort, ";
      $sqlstr .= "  task.plan_end_time $pedateSort, ";
    }
    $sqlstr .= "  task.title ";
    $sqlstr .= "LIMIT $intLimit ";
    $sqlstr .= "OFFSET $intOffset;";

    //echo $sqlstr;
    return $sqlstr;
    
  }
  function selectMyTaskListPageNo($emp_cd,$intLimit, $groupCdSearch="-2",$statusSearch="-2")
  {
    $this->argumentCheck("emp_cd", $emp_cd);

    if(!$groupCdSearch or $groupCdSearch == "-2")
    {
      $strGroupCdSearch = "";
    }
    else
    {
      $strGroupCdSearch = "  AND group_cd = '$groupCdSearch' ";
    }

    if(!$statusSearch or $statusSearch == "-3")
    {
      $strStatusSearch = "";
    }
    else if($statusSearch == "-2")
    {
      $strStatusSearch = " AND status IN ('1', '2') ";
    }
    else
    {
      $strStatusSearch = "  AND status = '$statusSearch' ";
    }

    $sqlstr  = "SELECT ";
    $sqlstr .= "  TRUNC((COUNT(1)-1) / $intLimit,0) + 1 AS max_page_no ";
    $sqlstr .= "FROM ";
    $sqlstr .= "  task ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  task.owner_emp_cd = '$emp_cd' ";
    $sqlstr .= $strGroupCdSearch;
    $sqlstr .= $strStatusSearch;
    $sqlstr .= ";";

    //echo $sqlstr;
    return $sqlstr;
  }

  /**
   * group_cdとcat_cdとsubcat_cdを使用してタスクリストを取得する
   **/
  function selectTaskDetail($group_cd,$cat_cd,$subcat_cd,$task_cd)
  {

    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("task_cd", $task_cd);
    
    $sqlstr  = "SELECT ";
    $sqlstr .= "  task.task_cd, "; 
    $sqlstr .= "  task.title,  ";
    $sqlstr .= "  task.description,   ";
    $sqlstr .= "  date_part('year'::text, task.plan_start_date) AS psyear,  ";
    $sqlstr .= "  date_part('month'::text, task.plan_start_date) AS psmonth,  ";
    $sqlstr .= "  date_part('day'::text, task.plan_start_date) AS psday,  ";
    $sqlstr .= "  lpad(date_part('hour'::text, task.plan_start_time)::text, 2, '0') AS pshour,   ";
    $sqlstr .= "  lpad(date_part('minutes'::text, task.plan_start_time)::text, 2, '0') AS psminutes,   ";
    $sqlstr .= "  date_part('year'::text, task.plan_end_date) AS peyear,   ";
    $sqlstr .= "  date_part('month'::text, task.plan_end_date) AS pemonth,   ";
    $sqlstr .= "  date_part('day'::text, task.plan_end_date) AS peday,   ";
    $sqlstr .= "  lpad(date_part('hour'::text, task.plan_end_time)::text, 2, '0') AS pehour,   ";
    $sqlstr .= "  lpad(date_part('minutes'::text, task.plan_end_time)::text, 2, '0') AS peminutes,   ";
    $sqlstr .= "  date_part('year'::text, task.result_start_date) AS rsyear,  ";
    $sqlstr .= "  date_part('month'::text, task.result_start_date) AS rsmonth,  ";
    $sqlstr .= "  date_part('day'::text, task.result_start_date) AS rsday,  ";
    $sqlstr .= "  lpad(date_part('hour'::text, task.result_start_time)::text, 2, '0') AS rshour,   ";
    $sqlstr .= "  lpad(date_part('minutes'::text, task.result_start_time)::text, 2, '0') AS rsminutes,   ";
    $sqlstr .= "  date_part('year'::text, task.result_end_date) AS reyear,   ";
    $sqlstr .= "  date_part('month'::text, task.result_end_date) AS remonth,   ";
    $sqlstr .= "  date_part('day'::text, task.result_end_date) AS reday,   ";
    $sqlstr .= "  lpad(date_part('hour'::text, task.result_end_time)::text, 2, '0') AS rehour,   ";
    $sqlstr .= "  lpad(date_part('minutes'::text, task.result_end_time)::text, 2, '0') AS reminutes,   ";
    $sqlstr .= "  task.priority_cd, ";
    $sqlstr .= "  mst_priority.priority_name, ";
    $sqlstr .= "  task.owner_emp_cd,   ";
    $sqlstr .= "  task.regist_emp_cd,   ";
    $sqlstr .= "  task.status,   ";
    $sqlstr .= "  task.schedule_flg  ";
    $sqlstr .= "FROM   ";
    $sqlstr .= "  task, ";
    $sqlstr .= "  mst_priority ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  mst_priority.priority_cd = task.priority_cd ";
    $sqlstr .= "  AND category_cd = '$cat_cd' ";
    $sqlstr .= "  AND sub_category_cd = '$subcat_cd' ";
    $sqlstr .= "  AND group_cd = '$group_cd' ";
    $sqlstr .= "  AND task_cd = '$task_cd';";
    
    //echo $sqlstr;
    return $sqlstr;
    
  }
  /**
   * 優先度リストを取得する
   **/
  function selectPriorityList()
  {
    $sqlstr  = "SELECT ";
    $sqlstr .= "  priority_cd, ";
    $sqlstr .= "  priority_name ";
    $sqlstr .= "FROM ";
    $sqlstr .= "   mst_priority ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  enable = 't';";
    
    return $sqlstr;
  }
  /**
   * 二重投稿されたデータをチェックする
   **/
  function selectTaskCheckDoubleInsert($cat_cd, $subcat_cd, $group_cd, $task_title,$strDesc,$priority,$owner_emp_cd,$regist_emp_cd,$status)
  {
    $sqlstr  = "SELECT ";
    $sqlstr .= "  COUNT(1) AS check_num ";
    $sqlstr .= "FROM ";
    $sqlstr .= "  task ";
    $sqlstr .= "WHERE ";
    $sqlstr .= "  category_cd = '$cat_cd' "; 
    $sqlstr .= "  AND sub_category_cd = '$subcat_cd' "; 
    $sqlstr .= "  AND group_cd = '$group_cd' ";
    $sqlstr .= "  AND title = '$task_title' ";
    $sqlstr .= "  AND description = '$strDesc' ";
    $sqlstr .= "  AND priority_cd = '$priority' ";
    $sqlstr .= "  AND owner_emp_cd = '$owner_emp_cd' ";
    $sqlstr .= "  AND regist_emp_cd = '$regist_emp_cd' ";
    $sqlstr .= "  AND status = '$status';";

    return $sqlstr;
  }
  /**
   * 新規タスクを登録する
   **/
  function insertTask($cat_cd, $subcat_cd, $group_cd, $task_cd, $task_title,$strDesc,$psyear,$psmonth,$psday,$pshour,$psminute,$peyear,$pemonth,$peday,$pehour,$peminute,$priority,$owner_emp_cd,$regist_emp_cd,$status,$bolschedule_flg)
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("task_cd", $task_cd);
    $this->argumentCheck("task_title", $task_title);
    $this->argumentCheck("priority", $priority);
    $this->argumentCheck("owner_emp_cd", $owner_emp_cd);
    $this->argumentCheck("regist_emp_cd", $regist_emp_cd);
    $this->argumentCheck("status", $status);

    if($psyear != "" && $psmonth != "" && $psday != "" && $psmonth != "-1" && $psday != "-1")
    {
      $psdate = "'" . $psyear . "-" . $psmonth . "-" . $psday . "'";
      
      if($pshour != ""  && $psminute != "" && $pshour != "-1"  && $psminute != "-1")
      {
	$pstime = "'" . $pshour . ":" . $psminute . ":" . "00" . "'";
      }
      else
      {
	$pstime = "NULL";
      }
    }
    else
    {
      $psdate = "NULL";
      $pstime = "NULL";
    }

    if($peyear != "" && $pemonth != "" && $peday != "" && $pemonth != "-1" && $peday != "-1")
    {
      $pedate = "'" . $peyear . "-" . $pemonth . "-" . $peday . "'";

      if($pehour != ""  && $peminute != "" && $pehour != "-1"  && $peminute != "-1")
      {
	$petime = "'" . $pehour . ":" . $peminute . ":" . "00" . "'";
      }
      else
      {
	$petime = "NULL";
      }
    }
    else
    {
      $pedate = "NULL";
      $petime = "NULL";
    }

    if(isset($bolschedule_flg))
    {
      $schedule_flg = "t";
    }
    else
    {
      $schedule_flg = "f";
    }


    $strsql  = "INSERT INTO task ";
    $strsql .= "   (category_cd, sub_category_cd, group_cd, task_cd, title, description, ";
    $strsql .= "   plan_start_date, plan_start_time, plan_end_date, plan_end_time, ";
    $strsql .= "   priority_cd, owner_emp_cd, regist_emp_cd, status, schedule_flg) ";
    $strsql .= "  values( ";
    $strsql .= "   '$cat_cd', '$subcat_cd', '$group_cd', '$task_cd', '$task_title', '$strDesc', ";
    $strsql .= "   $psdate, $pstime, $pedate, $petime, ";
    $strsql .= "   '$priority', '$owner_emp_cd', '$regist_emp_cd', '$status', '$schedule_flg');";

    //echo $strsql;
    return $strsql;
  }
  /**
   * タスクステータス更新
   **/
  function updateTaskStatus($cat_cd, $subcat_cd, $group_cd, $task_cd, $status)
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("task_cd", $task_cd);    
    $this->argumentCheck("status", $status);    

    $strsql  = "UPDATE task  ";
    $strsql .= "SET status = '$status' ";
    $strsql .= "WHERE ";
    $strsql .= "  category_cd = '$cat_cd' ";
    $strsql .= "  AND sub_category_cd = '$subcat_cd' ";
    $strsql .= "  AND group_cd = '$group_cd' ";
    $strsql .= "  AND task_cd = '$task_cd';";

    //echo $strsql;
    return $strsql;
  }
  /**
   * 開始日実績設定
   **/
  function updateTaskStartDay($cat_cd, $subcat_cd, $group_cd, $task_cd, $start_date, $start_time)
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("task_cd", $task_cd);    
    $this->argumentCheck("start_date", $start_date);    
    $this->argumentCheck("start_time", $start_time);    

    $strsql  = "UPDATE task  ";
    $strsql .= "  SET result_start_date = '$start_date', "; 
    $strsql .= "      result_start_time = '$start_time' ";
    $strsql .= "WHERE ";
    $strsql .= "  category_cd = '$cat_cd' ";
    $strsql .= "  AND sub_category_cd = '$subcat_cd' ";
    $strsql .= "  AND group_cd = '$group_cd' ";
    $strsql .= "  AND task_cd = '$task_cd';";

    //echo $strsql;
    return $strsql;
  }
  /**
   * 終了実績設定
   **/
  function updateTaskEndDay($cat_cd, $subcat_cd, $group_cd, $task_cd, $end_date, $end_time)
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("task_cd", $task_cd);    
    $this->argumentCheck("end_date", $end_date);    
    $this->argumentCheck("end_time", $end_time);    

    $strsql  = "UPDATE task  ";
    $strsql .= "  SET result_end_date = '$end_date', "; 
    $strsql .= "      result_end_time = '$end_time' ";
    $strsql .= "WHERE ";
    $strsql .= "  category_cd = '$cat_cd' ";
    $strsql .= "  AND sub_category_cd = '$subcat_cd' ";
    $strsql .= "  AND group_cd = '$group_cd' ";
    $strsql .= "  AND task_cd = '$task_cd';";

    //echo $strsql;
    return $strsql;
  }
  /**
   * タスク情報更新
   **/
  function updateTask($cat_cd, $subcat_cd, $group_cd, $task_cd, $peyear,$pemonth,$peday,$pehour,$peminute,$intPriority,$intStatus,$bolScheduleFlg)
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("task_cd", $task_cd);
    $this->argumentCheck("intPriority", $intPriority);
    $this->argumentCheck("intStatus", $intStatus);
      
    if($peyear != "" && $pemonth != "" && $peday != "" && $pemonth != "-1" && $peday != "-1")
    {
      $pedate = "'" . $peyear . "-" . $pemonth . "-" . $peday . "'";

      if($pehour != ""  && $peminute != "" && $pehour != "-1"  && $peminute != "-1")
      {
	$petime = "'" . $pehour . ":" . $peminute . ":" . "00" . "'";
      }
      else
      {
	$petime = "NULL";
      }
    }
    else
    {
      $pedate = "NULL";
      $petime = "NULL";
    }

    if(isset($bolScheduleFlg))
    {
      $schedule_flg = "t";
    }
    else
    {
      $schedule_flg = "f";
    }

    $strsql  = "UPDATE task  ";
    $strsql .= "  SET plan_end_date = $pedate, ";
    $strsql .= "      plan_end_time = $petime, ";
    $strsql .= "      priority_cd = '$intPriority', ";
    $strsql .= "      status = '$intStatus',  ";
    $strsql .= "      schedule_flg = '$schedule_flg' ";
    $strsql .= "WHERE ";
    $strsql .= "  category_cd = '$cat_cd' ";
    $strsql .= "  AND sub_category_cd = '$subcat_cd' ";
    $strsql .= "  AND group_cd = '$group_cd' ";
    $strsql .= "  AND task_cd = '$task_cd';";
    
    //echo $strsql;
    return $strsql;
  }

  /**
   * タスク詳細情報更新
   **/
  function updateTaskDetail($cat_cd, $subcat_cd, $group_cd, $task_cd, $strTaskTitle,$strDesc,$psyear,$psmonth,$psday,$pshour,$psminute,$peyear,$pemonth,$peday,$pehour,$peminute,$rsyear,$rsmonth,$rsday,$rshour,$rsminute,$reyear,$remonth,$reday,$rehour,$reminute,$intPriority,$strOwnerEmpCd,$strRegistEmpCd,$intStatus,$bolScheduleFlg)
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("task_cd", $task_cd);
    $this->argumentCheck("strTaskTitle", $strTaskTitle);
    $this->argumentCheck("intPriority", $intPriority);
    $this->argumentCheck("owner_emp_cd", $strOwnerEmpCd);
    $this->argumentCheck("regist_emp_cd", $strRegistEmpCd);
    $this->argumentCheck("status", $intStatus);

    if($psyear != "" && $psmonth != "" && $psday != "" && $psmonth != "-1" && $psday != "-1")
    {
      $psdate = "'" . $psyear . "-" . $psmonth . "-" . $psday . "'";
      if($pshour != ""  && $psminute != "" && $pshour != "-1"  && $psminute != "-1")
      {
	$pstime = "'" . $pshour . ":" . $psminute . ":" . "00" . "'";
      }
      else
      {
	$pstime = "NULL";
      }
    }
    else
    {
      $psdate = "NULL";
      $pstime = "NULL";
    }
    
    if($peyear != "" && $pemonth != "" && $peday != "" && $pemonth != "-1" && $peday != "-1")
    {
      $pedate = "'" . $peyear . "-" . $pemonth . "-" . $peday . "'";

      if($pehour != ""  && $peminute != "" && $pehour != "-1"  && $peminute != "-1")
      {
	$petime = "'" . $pehour . ":" . $peminute . ":" . "00" . "'";
      }
      else
      {
	$petime = "NULL";
      }
    }
    else
    {
      $pedate = "NULL";
      $petime = "NULL";
    }

    if($rsyear != "" && $rsmonth != "" && $rsday != "" && $rsmonth != "-1" && $rsday != "-1")
    {
      $rsdate = "'" . $rsyear . "-" . $rsmonth . "-" . $rsday . "'";

      if($rshour != ""  && $rsminute != "" && $rshour != "-1"  && $rsminute != "-1")
      {
	$rstime = "'" . $rshour . ":" . $rsminute . ":" . "00" . "'";
      }
      else
      {
	$rstime = "NULL";
      }
    }
    else
    {
      $rsdate = "NULL";
      $rstime = "NULL";
    }
    
    if($reyear != "" && $remonth != "" && $reday != "" && $remonth != "-1" && $reday != "-1")
    {
      $redate = "'" . $reyear . "-" . $remonth . "-" . $reday . "'";
    
      if($rehour != ""  && $reminute != "" && $rehour != "-1"  && $reminute != "-1")
      {
	$retime = "'" . $rehour . ":" . $reminute . ":" . "00" . "'";
      }
      else
      {
	$retime = "NULL";
      }
    }
    else
    {
      $redate = "NULL";
      $retime = "NULL";
    }

    if(isset($bolScheduleFlg))
    {
      $schedule_flg = "t";
    }
    else
    {
      $schedule_flg = "f";
    }

    $strsql  = "UPDATE task  ";
    $strsql .= "  SET title = '$strTaskTitle', ";
    $strsql .= "      description = '$strDesc', ";
    $strsql .= "      plan_start_date = $psdate,  ";
    $strsql .= "      plan_start_time = $pstime,  ";
    $strsql .= "      plan_end_date = $pedate,  ";
    $strsql .= "      plan_end_time = $petime,  ";
    $strsql .= "      result_start_date = $rsdate,  ";
    $strsql .= "      result_start_time = $rstime,  ";
    $strsql .= "      result_end_date = $redate,  ";
    $strsql .= "      result_end_time = $retime,  ";
    $strsql .= "      priority_cd = '$intPriority',  ";
    $strsql .= "      owner_emp_cd = '$strOwnerEmpCd',  ";
    $strsql .= "      regist_emp_cd = '$strRegistEmpCd',  ";
    $strsql .= "      status = '$intStatus',  ";
    $strsql .= "      schedule_flg =  '$schedule_flg' ";
    $strsql .= "WHERE ";
    $strsql .= "  category_cd = '$cat_cd' ";
    $strsql .= "  AND sub_category_cd = '$subcat_cd' ";
    $strsql .= "  AND group_cd = '$group_cd' ";
    $strsql .= "  AND task_cd = '$task_cd';";

    //echo $strsql;
    return $strsql;
  }

  /**
   * タスク削除
   **/
  function deleteTaskDetail($cat_cd, $subcat_cd, $group_cd, $task_cd)
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    $this->argumentCheck("task_cd", $task_cd);
    
    $strsql  = "DELETE FROM task ";
    $strsql .= "WHERE ";
    $strsql .= "  category_cd = '$cat_cd' ";
    $strsql .= "  AND sub_category_cd = '$subcat_cd' ";
    $strsql .= "  AND group_cd = '$group_cd' ";
    $strsql .= "  AND task_cd = '$task_cd';";

    //echo $strsql;
    return $strsql;
  }

  /**
   * 終了済みのタスクをカウントする
   **/
  function countFinishedTaskWithGroupCat($cat_cd, $group_cd)
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);

    $strsql  = "SELECT ";
    $strsql .= "  COUNT(1) AS count_task, ";
    $strsql .= "  MAX(plan_end_date) AS max_pendday, ";
    $strsql .= "  MAX(plan_end_time) AS max_pendtime ";
    $strsql .= "FROM ";
    $strsql .= "  task ";
    $strsql .= "WHERE ";
    $strsql .= "  category_cd = '$cat_cd' ";
    $strsql .= "  and group_cd = '$group_cd' ";
    $strsql .= "  and status = '3';";

    return $strsql;
  }
  /**
   * 終了済みのタスクをカウントする
   **/
  function countTaskWithGroupCat($cat_cd, $group_cd)
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    
    $strsql  = "SELECT ";
    $strsql .= "  COUNT(1) AS count_task, ";
    $strsql .= "  MAX(plan_end_date) AS max_pendday, ";
    $strsql .= "  MAX(plan_end_time) AS max_pendtime ";
    $strsql .= "FROM ";
    $strsql .= "  task ";
    $strsql .= "WHERE ";
    $strsql .= "  category_cd = '$cat_cd' ";
    $strsql .= "  and group_cd = '$group_cd';";
    
    //echo $strsql;
    return $strsql;
  }
  /**
   * 終了済みのタスクをカウントする
   **/
  function countFinishedTaskWithGroupCatSubCat($cat_cd, $subcat_cd, $group_cd)
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);

    $strsql  = "SELECT ";
    $strsql .= "  COUNT(1) AS count_task, ";
    $strsql .= "  MAX(plan_end_date) AS max_pendday, ";
    $strsql .= "  MAX(plan_end_time) AS max_pendtime ";
    $strsql .= "FROM ";
    $strsql .= "  task ";
    $strsql .= "WHERE ";
    $strsql .= "  category_cd = '$cat_cd' ";
    $strsql .= "  and sub_category_cd = '$subcat_cd' ";
    $strsql .= "  and group_cd = '$group_cd' ";
    $strsql .= "  and status = '3';";

    return $strsql;
  }
  /**
   * 終了済みのタスクをカウントする
   **/
  function countTaskWithGroupCatSubCat($cat_cd, $subcat_cd, $group_cd)
  {
    $this->argumentCheck("group_cd", $group_cd);
    $this->argumentCheck("cat_cd", $cat_cd);
    $this->argumentCheck("subcat_cd", $subcat_cd);
    
    $strsql  = "SELECT ";
    $strsql .= "  COUNT(1) AS count_task, ";
    $strsql .= "  MAX(plan_end_date) AS max_pendday, ";
    $strsql .= "  MAX(plan_end_time) AS max_pendtime ";
    $strsql .= "FROM ";
    $strsql .= "  task ";
    $strsql .= "WHERE ";
    $strsql .= "  category_cd = '$cat_cd' ";
    $strsql .= "  and sub_category_cd = '$subcat_cd' ";
    $strsql .= "  and group_cd = '$group_cd';";
    
    return $strsql;
  }
  
}

?>
